# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox GeoAnalytics Desktop Tools"""
__all__ = ['AggregatePoints', 'CalculateDensity', 'CalculateField', 'ClipLayer',
           'CopyDatasetFromBDC', 'CreateBDC', 'CreateBuffers',
           'DescribeDataset', 'DetectIncidents', 'DissolveBoundaries',
           'DuplicateDatasetFromBDC', 'FindDwellLocations', 'FindHotSpots',
           'FindPointClusters', 'FindSimilarLocations', 'Forest',
           'GeneralizedLinearRegression', 'JoinFeatures', 'OverlayLayers',
           'PreviewDatasetFromBDC', 'ReconstructTracks', 'RefreshBDC',
           'RemoveDatasetFromBDC', 'SummarizeAttributes', 'SummarizeWithin',
           'UpdateBDCDatasetProperties']
__alias__ = 'gapro'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analyze Patterns toolset
@gptooldoc('CalculateDensity_gapro', None)
def CalculateDensity(input_layer=None, out_feature_class=None, bin_type=None, bin_size=None, weight=None, neighborhood_size=None, fields=None, area_unit_scale_factor=None, time_step_interval=None, time_step_repeat=None, time_step_reference=None):
    """CalculateDensity_gapro(input_layer, out_feature_class, bin_type, bin_size, weight, neighborhood_size, {fields;fields...}, {area_unit_scale_factor}, {time_step_interval}, {time_step_repeat}, {time_step_reference})

        Calculates a magnitude-per-unit area from point features that fall
        within a neighborhood around each cell.

     INPUTS:
      input_layer (Feature Layer):
          The points that will be used to calculate the density.
      bin_type (String):
          Specifies the bin shape that will be used in the analysis.

          * SQUARE-The bin shape will be square. This is the default.

          * HEXAGON-The bin shape will be hexagonal.
      bin_size (Linear Unit):
          The size of the bins used to aggregate input features. When generating
          bins for squares, the number and units specified determine the height
          and length of the square. For hexagons, the number and units specified
          determine the distance between parallel sides.
      weight (String):
          Specifies the weighting to be applied to the density function.

          * UNIFORM-A magnitude-per-area calculation in which each bin is
          equally weighted. This is the default.

          * KERNEL-A magnitude-per-area calculation with a smoothing algorithm
          applied (kernel) that weights bins closer to the points more heavily.
      neighborhood_size (Linear Unit):
          The search radius to be applied to density calculations.
      fields {Field}:
          One or more fields denoting population values for each feature. The
          population field is the count or quantity to be spread across the
          landscape to create a continuous surface.Values in the population
          field must be numeric. By default, the
          density of the count of input points will always be calculated.
      area_unit_scale_factor {String}:
          Specifies the area units of the output density values. The default
          unit is based on the units of the output spatial reference.

          * ACRES-Area in acres

          * HECTARES-Area in hectares

          * SQUARE_MILES-Area in square miles

          * SQUARE_KILOMETERS-Area in square kilometers

          * SQUARE_METERS-Area in square meters

          * SQUARE_FEET-Area in square feet

          * SQUARE_YARDS-Area in square yards
      time_step_interval {Time Unit}:
          A value that specifies the duration of the time step. This parameter
          is only available if the input points are time enabled and represent
          an instant in time.Time stepping can only be applied if time is
          enabled on the input.
      time_step_repeat {Time Unit}:
          A value that specifies how often the time-step interval occurs. This
          parameter is only available if the input points are time enabled and
          represent an instant in time.
      time_step_reference {Date}:
          A date that specifies the reference time with which to align the time
          steps. The default is January 1, 1970, at 12:00 a.m. This parameter is
          only available if the input points are time enabled and represent an
          instant in time.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class with calculated densities."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDensity_gapro(*gp_fixargs((input_layer, out_feature_class, bin_type, bin_size, weight, neighborhood_size, fields, area_unit_scale_factor, time_step_interval, time_step_repeat, time_step_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindHotSpots_gapro', None)
def FindHotSpots(point_layer=None, out_feature_class=None, bin_size=None, neighborhood_size=None, time_step_interval=None, time_step_alignment=None, time_step_reference=None):
    """FindHotSpots_gapro(point_layer, out_feature_class, {bin_size}, {neighborhood_size}, {time_step_interval}, {time_step_alignment}, {time_step_reference})

        Given a set of features, identifies statistically significant hot
        spots and cold spots using the Getis-Ord Gi* statistic.

     INPUTS:
      point_layer (Feature Layer):
          The point feature class for which hot spot analysis will be performed.
      bin_size {Linear Unit}:
          The distance interval that represents the bin size and units into
          which the point_layer will be aggregated. The distance interval must
          be a linear unit.
      neighborhood_size {Linear Unit}:
          The spatial extent of the analysis neighborhood. This value determines
          which features are analyzed together to assess local clustering.
      time_step_interval {Time Unit}:
          The interval that will be used for the time step. This parameter is
          only used if time is enabled for point_layer.
      time_step_alignment {String}:
          Specifies how time steps will be aligned. This parameter is only
          available if the input points are time enabled and represent an
          instant in time.

          * END_TIME-Time steps will align to the last time event and aggregate
          back in time.

          * START_TIME-Time steps will align to the first time event and
          aggregate forward in time. This is the default.

          * REFERENCE_TIME-Time steps will align to a specified date or time. If
          all points in the input features have a time stamp larger than the
          specified reference time (or it falls exactly on the start time of the
          input features), the time-step interval will begin with that reference
          time and aggregate forward in time (as occurs with the Start time
          alignment). If all points in the input features have a time stamp
          smaller than the specified reference time (or it falls exactly on the
          end time of the input features), the time-step interval will end with
          that reference time and aggregate backward in time (as occurs with the
          End time alignment). If the specified reference time is in the middle
          of the time extent of the data, a time-step interval will be created
          ending with the reference time provided (as occurs with the End time
          alignment); additional intervals will be created both before and after
          the reference time until the full time extent of the data is covered.
      time_step_reference {Date}:
          The time that will be used to align the time steps and time intervals.
          This parameter is only used if time is enabled for point_layer.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class with the z-score and p-value results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindHotSpots_gapro(*gp_fixargs((point_layer, out_feature_class, bin_size, neighborhood_size, time_step_interval, time_step_alignment, time_step_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindPointClusters_gapro', None)
def FindPointClusters(input_points=None, out_feature_class=None, clustering_method=None, minimum_points=None, search_distance=None, use_time=None, search_duration=None):
    """FindPointClusters_gapro(input_points, out_feature_class, clustering_method, minimum_points, {search_distance}, {use_time}, {search_duration})

        Finds clusters of point features in surrounding noise based on their
        spatial or spatiotemporal distribution.

     INPUTS:
      input_points (Feature Layer):
          The point feature class containing the point clusters.
      clustering_method (String):
          Specifies the method that will be used to define clusters.

          * DBSCAN-Uses a specified distance to separate dense clusters from
          sparser noise. DBSCAN is the fastest of the clustering methods but is
          only appropriate if there is a clear distance to use that works well
          to define all clusters that may be present. This results in clusters
          that have similar densities. This is the default.

          * HDBSCAN-Uses varying distances to separate clusters of varying
          densities from sparser noise. HDBSCAN is the most data-driven of the
          clustering methods and requires the least user input.
      minimum_points (Long):
          This parameter is used differently depending on the clustering method
          chosen as follows:

          * Defined distance (DBSCAN)-Specifies the number of features that must
          be found within a certain distance of a point for that point to start
          to form a cluster. The distance is defined using the Search Distance
          parameter.

          * Self-adjusting (HDBSCAN)-Specifies the number of features
          neighboring each point (including the point) that will be considered
          when estimating density. This number is also the minimum cluster size
          allowed when extracting clusters.
      search_distance {Linear Unit}:
          The maximum distance to be considered.The Minimum Features per Cluster
          specified must be found within this
          distance for cluster membership. Individual clusters will be separated
          by at least this distance. If a feature is located farther than this
          distance from the next closest feature in the cluster, it will not be
          included in the cluster.
      use_time {Boolean}:
          Specifies whether or not time will be used to discover clusters with
          DBSCAN.

          * TIME-Spatiotemporal clusters will be found using both a search
          distance and a search duration.

          * NO_TIME-Spatial clusters will be found using a search distance and
          time will be ignored. This is the default.
      search_duration {Time Unit}:
          When searching for cluster members, the specified minimum number of
          points must be found within this time duration to form a cluster.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class with the resulting point clusters."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindPointClusters_gapro(*gp_fixargs((input_points, out_feature_class, clustering_method, minimum_points, search_distance, use_time, search_duration), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Forest_gapro', None)
def Forest(prediction_type=None, in_features=None, output_trained_features=None, variable_predict=None, treat_variable_as_categorical=None, explanatory_variables=None, features_to_predict=None, variable_of_importance=None, output_predicted=None, explanatory_variable_matching=None, number_of_trees=None, minimum_leaf_size=None, maximum_tree_depth=None, sample_size=None, random_variables=None, percentage_for_validation=None):
    """Forest_gapro(prediction_type, in_features, output_trained_features, variable_predict, {treat_variable_as_categorical}, {explanatory_variables;explanatory_variables...}, {features_to_predict}, {variable_of_importance}, {output_predicted}, {explanatory_variable_matching;explanatory_variable_matching...}, {number_of_trees}, {minimum_leaf_size}, {maximum_tree_depth}, {sample_size}, {random_variables}, {percentage_for_validation})

        Creates models and generates predictions using an adaptation of Leo
        Breiman's random forest algorithm, which is a supervised machine
        learning method. Predictions can be performed for both categorical
        variables (classification) and continuous variables (regression).
        Explanatory variables can take the form of fields in the attribute
        table of the training features. In addition to validation of model
        performance based on the training data, predictions can be made to
        features.

     INPUTS:
      prediction_type (String):
          Specifies the operation mode of the tool. The tool can be run to train
          a model to only assess performance, predict features, or create a
          prediction surface.

          * TRAIN-A model will be trained, but no predictions will be generated.
          Use this option to assess the accuracy of your model before generating
          predictions. This option will output model diagnostics in the messages
          window and a chart of variable importance. This is the default

          * TRAIN_AND_PREDICT-Predictions or classifications will be generated
          for features. Explanatory variables must be provided for both the
          training features and the features to be predicted. The output of this
          option will be a feature class, model diagnostics in the messages
          window, and an optional table of variable importance.
      in_features (Table View):
          The feature class containing the variable_predict parameter and the
          explanatory training variables fields.
      variable_predict (Field):
          The variable from the in_features parameter containing the values to
          be used to train the model. This field contains known (training)
          values of the variable that will be used to predict at unknown
          locations.
      treat_variable_as_categorical {Boolean}:
          * CATEGORICAL-variable_predict is a categorical variable and the tool
          will perform classification.

          * NUMERIC-variable_predict is continuous and the tool will perform
          regression. This is the default.
      explanatory_variables {Value Table}:
          A list of fields representing the explanatory variables that help
          predict the value or category of variable_predict. Use the
          treat_variable_as_categorical parameter for any variables that
          represent classes or categories (such as land cover or presence or
          absence). Specify the variable as true for any that represent classes
          or categories such as land cover or presence or absence and false if
          the variable is continuous.
      features_to_predict {Table View}:
          A feature layer representing locations where predictions will be made.
          This feature layer must also contain any explanatory variables
          provided as fields that correspond to those used from the training
          data.
      explanatory_variable_matching {Value Table}:
          A list of explanatory_variables specified from in_features on the
          right and their corresponding fields from features_to_predict on the
          left, for example, [["LandCover2000", "LandCover2010"], ["Income",
          "PerCapitaIncome"]].
      number_of_trees {Long}:
          The number of trees to create in the forest model. More trees will
          generally result in more accurate model prediction, but the model will
          take longer to calculate. The default number of trees is 100.
      minimum_leaf_size {Long}:
          The minimum number of observations required to keep a leaf (that is,
          the terminal node on a tree without further splits). The default
          minimum for regression is 5, and the default for classification is 1.
          For very large data, increasing these numbers will decrease the run
          time of the tool.
      maximum_tree_depth {Long}:
          The maximum number of splits that will be made down a tree. Using a
          large maximum depth, more splits will be created, which may increase
          the chances of overfitting the model. The default is data driven and
          depends on the number of trees created and the number of variables
          included.
      sample_size {Long}:
          The percentage of in_features used for each decision tree. The default
          is 100 percent of the data. Samples for each tree are taken randomly
          from two-thirds of the data specified.Each decision tree in the forest
          is created using a random sample or
          subset (approximately two-thirds) of the training data available.
          Using a lower percentage of the input data for each decision tree
          increases the speed of the tool for very large datasets.
      random_variables {Long}:
          The number of explanatory variables used to create each decision
          tree.Each decision tree in the forest is created using a random subset
          of
          the explanatory variables specified. Increasing the number of
          variables used in each decision tree will increase the chances of
          overfitting your model, particularly if there is one or more dominant
          variables. A common practice is to use the square root of the total
          number of explanatory variables if variable_predict is numeric, or
          divide the total number of explanatory variables by 3 if
          variable_predict is categorical.
      percentage_for_validation {Long}:
          The percentage (between 10 percent and 50 percent) of in_features to
          reserve as the test dataset for validation. The model will be trained
          without this random subset of data, and the observed values for those
          features will be compared to the predicted value. The default is 10
          percent.

     OUTPUTS:
      output_trained_features (Feature Class / Table):
          The output feature layer name.
      variable_of_importance {Table}:
          A table containing information describing the importance of each
          explanatory variable to be used in the created model.
      output_predicted {Feature Class / Table}:
          The output feature class that will receive the results of the
          prediction results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Forest_gapro(*gp_fixargs((prediction_type, in_features, output_trained_features, variable_predict, treat_variable_as_categorical, explanatory_variables, features_to_predict, variable_of_importance, output_predicted, explanatory_variable_matching, number_of_trees, minimum_leaf_size, maximum_tree_depth, sample_size, random_variables, percentage_for_validation), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeneralizedLinearRegression_gapro', None)
def GeneralizedLinearRegression(input_features=None, dependent_variable=None, model_type=None, explanatory_variables=None, output_features=None, input_features_to_predict=None, explanatory_variables_to_match=None, dependent_variable_mapping=None, output_predicted_features=None, coefficient_table=None):
    """GeneralizedLinearRegression_gapro(input_features, dependent_variable, model_type, explanatory_variables;explanatory_variables..., output_features, {input_features_to_predict}, {explanatory_variables_to_match;explanatory_variables_to_match...}, {dependent_variable_mapping;dependent_variable_mapping...}, {output_predicted_features}, {coefficient_table})

        Performs generalized linear regression (GLR) to generate predictions
        or to model a dependent variable in terms of its relationship to a set
        of explanatory variables. This tool can be used to fit continuous
        (OLS), binary (logistic), and count (Poisson) models.

     INPUTS:
      input_features (Table View):
          The layer containing the dependent and independent variables.
      dependent_variable (Field):
          The numeric field containing the observed values to be modeled.
      model_type (String):
          Specifies the type of data that will be modeled.

          * CONTINUOUS-The dependent_variable is continuous. The Gaussian model
          will be used, and the tool will perform ordinary least squares
          regression. This is the default.

          * BINARY-The dependent_variable represents presence or absence. This
          can be either conventional 1s and 0s, or string values mapped to 0 or
          1s in the Match Explanatory Variables parameter. The Logistic
          Regression model will be used.

          * COUNT-The dependent_variable is discrete and represents events, for
          example, crime counts, disease incidents, or traffic accidents. The
          Poisson regression model will be used.
      explanatory_variables (Field):
          A list of fields representing independent explanatory variables in the
          regression model.
      input_features_to_predict {Table View}:
          A layer containing features representing locations where estimates
          should be computed. Each feature in this dataset should contain values
          for all the explanatory variables specified. The dependent variable
          for these features will be estimated using the model calibrated for
          the input layer data.
      explanatory_variables_to_match {Value Table}:
          Matches the explanatory variables in the input_features_to_predict
          parameter to corresponding explanatory variables from the
          input_features parameter-for example, [["LandCover2000",
          "LandCover2010"], ["Income", "PerCapitaIncome"]]
      dependent_variable_mapping {Value Table}:
          Two strings representing the values used to map to 0 (absence) and 1
          (presence) for binary regression. By default 0 and 1 will be used. For
          example, if you wanted to predict an arrest and had fields with values
          of Arrest and No Arrest, you would enter No Arrest for False Value (0)
          and Arrest for True Value (1).

     OUTPUTS:
      output_features (Table / Feature Class):
          The name of the feature class that will be created containing the
          dependent variable estimates and residuals.
      output_predicted_features {Table / Feature Class}:
          The output feature class with the dependent variable estimates for
          each input_features_to_predict.The output feature class with the
          dependent variable estimates for
          each Input Prediction Features.
      coefficient_table {Table}:
          The output feature class with the dependent variable estimates for
          each input_features_to_predict.The output feature class with the
          dependent variable estimates for
          each Input Prediction Features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeneralizedLinearRegression_gapro(*gp_fixargs((input_features, dependent_variable, model_type, explanatory_variables, output_features, input_features_to_predict, explanatory_variables_to_match, dependent_variable_mapping, output_predicted_features, coefficient_table), True)))
        return retval
    except Exception as e:
        raise e


# Find Locations toolset
@gptooldoc('DetectIncidents_gapro', None)
def DetectIncidents(input_layer=None, output=None, track_fields=None, start_condition=None, end_condition=None, output_mode=None, time_boundary_split=None, time_boundary_reference=None):
    """DetectIncidents_gapro(input_layer, output, track_fields;track_fields..., start_condition, {end_condition}, {output_mode}, {time_boundary_split}, {time_boundary_reference})

        Creates a layer that detects features that meet a given condition.

     INPUTS:
      input_layer (Table View):
          The input features that contain potential incidents.
      track_fields (Field):
          A field or fields that will be used to identify unique tracks.
      start_condition (Calculator Expression):
          The condition that will be used to identify incidents. Expressions are
          written in Arcade and can include [+ - * / ] operators and multiple
          fields.
      end_condition {Calculator Expression}:
          The condition that will be used to end incidents. If no end condition
          is specified, incidents will end when the start condition is no longer
          true.
      output_mode {String}:
          Specifies the features that will be returned.

          * ALL_FEATURES-All the input features will be returned. This is the
          default.

          * INCIDENTS-Only features that were found to be incidents will be
          returned.
      time_boundary_split {Time Unit}:
          A time span to split your input data into for analysis. A time
          boundary allows you to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, and set the time
          boundary reference to January 1, 1980, tracks will be will be split at
          the beginning of every day.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the entire span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970, is used.

     OUTPUTS:
      output (Feature Class / Table):
          A new output dataset that contains incidents."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DetectIncidents_gapro(*gp_fixargs((input_layer, output, track_fields, start_condition, end_condition, output_mode, time_boundary_split, time_boundary_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindDwellLocations_gapro', None)
def FindDwellLocations(input_features=None, output=None, track_fields=None, distance_method=None, distance_tolerance=None, time_tolerance=None, output_type=None, summary_statistics=None, time_boundary_split=None, time_boundary_reference=None):
    """FindDwellLocations_gapro(input_features, output, track_fields;track_fields..., distance_method, distance_tolerance, time_tolerance, output_type, {summary_statistics;summary_statistics...}, {time_boundary_split}, {time_boundary_reference})

        Finds locations where moving objects have stopped, or dwelled, using
        given time and distance thresholds.

     INPUTS:
      input_features (Feature Layer):
          The point tracks from which to find dwells. The input must be a time-
          enabled layer with features that represent instants in time.
      track_fields (Field):
          One or more fields that will be used to identify unique tracks.
      distance_method (String):
          Specifies how the distances between dwell features will be calculated.

          * GEODESIC-If the spatial reference can be panned, tracks will cross
          the international date line when appropriate. If the spatial reference
          cannot be panned, tracks will be limited to the coordinate system
          extent and may not wrap.

          * PLANAR-Planar distances will be used.
      distance_tolerance (Linear Unit):
          The maximum distance between points to be considered a single dwell
          location.
      time_tolerance (Time Unit):
          The minimum time duration to be considered a single dwell
          location.Both time and distance are considered when finding dwells.
          The
          Distance Tolerance parameter specifies distance.
      output_type (String):
          Specifies how the dwell features will be output.

          * DWELL_FEATURES-All of the input point features that are part of a
          dwell are returned.

          * DWELL_MEAN_CENTERS-Points representing the mean centers of each
          dwell group are returned. This is the default.

          * DWELL_CONVEX_HULLS-Polygons representing the convex hull of each
          dwell group are returned.

          * ALL_FEATURES-All of the input point features are returned.
      summary_statistics {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.

          * FIRST-The first value of a specified field in a track.

          * LAST-The last value of a specified field in a track.
      time_boundary_split {Time Unit}:
          A time span to split your input data into for analysis. A time
          boundary allows you to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, and set the time
          boundary reference to January 1, 1980, tracks will be will be split at
          the beginning of every day.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the entire span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970, is used.

     OUTPUTS:
      output (Feature Class):
          The output feature class with the resulting dwells."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindDwellLocations_gapro(*gp_fixargs((input_features, output, track_fields, distance_method, distance_tolerance, time_tolerance, output_type, summary_statistics, time_boundary_split, time_boundary_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindSimilarLocations_gapro', None)
def FindSimilarLocations(input_layer=None, search_layer=None, output=None, analysis_fields=None, most_or_least_similar=None, match_method=None, number_of_results=None, append_fields=None):
    """FindSimilarLocations_gapro(input_layer, search_layer, output, analysis_fields;analysis_fields..., {most_or_least_similar}, {match_method}, {number_of_results}, {append_fields;append_fields...})

        Identifies the candidate features that are most similar or dissimilar
        to one or more input features based on feature attributes.

     INPUTS:
      input_layer (Table View):
          The reference layer (or a selection on a layer) containing the
          features to be matched. The tool searches for other features similar
          to these features. When more than one feature is provided, matching is
          based on attribute averages.
      search_layer (Table View):
          The candidate layer (or a selection on a layer) containing candidate-
          matching features. The tool searches for features most similar (or
          dissimilar) to the input_layer parameter among these candidates.
      analysis_fields (String):
          A list of numeric attributes representing the matching criteria.
      most_or_least_similar {String}:
          Specifies whether the features to be found are most similar or least
          similar to the input_layer parameter.

          * MOST_SIMILAR-Finds the features that are most similar.

          * LEAST_SIMILAR-Finds the features that are least similar.

          * BOTH-Finds the features that are most similar and the features that
          are least similar.
      match_method {String}:
          Specifies whether matches will be based on values or cosine
          relationships.

          * ATTRIBUTE_VALUES-Similarity or dissimilarity will be based on the
          sum of squared standardized attribute value differences for all the
          analysis_fields attributes.

          * ATTRIBUTE_PROFILES-Similarity or dissimilarity will be computed as a
          function of cosine similarity for all the analysis_fields attributes.
      number_of_results {Long}:
          The number of solution matches to be found. Entering zero or a number
          larger than the total number of search_layer features will return
          rankings for all the candidate features, with a maximum of 10,000.
      append_fields {Field}:
          An optional list of attributes to include with the output. You can
          include a name identifier, categorical field, or date field for
          example. These fields are not used to determine similarity; they are
          only included in the output parameter attributes for your reference.
          By default, all fields are added.

     OUTPUTS:
      output (Feature Class / Table):
          The output dataset contains a record for each of the input_layer
          parameters and for all the solution-matching features found."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindSimilarLocations_gapro(*gp_fixargs((input_layer, search_layer, output, analysis_fields, most_or_least_similar, match_method, number_of_results, append_fields), True)))
        return retval
    except Exception as e:
        raise e


# Manage Data toolset
@gptooldoc('CalculateField_gapro', None)
def CalculateField(input_layer=None, output=None, field_to_calculate=None, field_name=None, existing_field=None, field_type=None, expression=None, track_aware=None, track_fields=None, time_boundary_split=None, time_boundary_reference=None):
    """CalculateField_gapro(input_layer, output, field_to_calculate, {field_name}, {existing_field}, {field_type}, expression, {track_aware}, {track_fields;track_fields...}, {time_boundary_split}, {time_boundary_reference})

        Creates a layer with calculated field values.

     INPUTS:
      input_layer (Table View):
          The input features that will have a field calculated.
      field_to_calculate (String):
          Specifies whether values will be calculated for a newly created field
          or an existing field.

          * NEW_FIELD-Values will be calculated for a newly created field.

          * EXISTING_FIELD-Values will be calculated for an existing field.
      field_name {String}:
          The new field that will have values calculated.
      existing_field {Field}:
          The existing field that will have values calculated.
      field_type {String}:
          Specifies the field type for the calculated field.

          * STRING-The new field will be of type text.

          * INTEGER-The new field will be of type integer.

          * FLOAT-The new field will be of type float.

          * DATE-The new field will be of type date.
      expression (Calculator Expression):
          Calculates values in the field. Expressions are written in Arcade and
          can include operators and multiple fields. Calculated values are
          applied in the units of the spatial reference of the input unless you
          are using a geographic coordinate system, in which case they will be
          in meters.
      track_aware {Boolean}:
          Specifies whether the expression will use a track-aware expression.

          * TRACK_AWARE-The expression will use a track-aware expression, and a
          track field must be specified.

          * NOT_TRACK_AWARE-The expression will not use a track-aware
          expression. This is the default.
      track_fields {Field}:
          One or more fields that will be used to identify unique tracks.
      time_boundary_split {Time Unit}:
          A time span to split your input data into for analysis. A time
          boundary allows you to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, and set the time
          boundary reference to January 1, 1980, tracks will be will be split at
          the beginning of every day.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the entire span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970, is used.

     OUTPUTS:
      output (Feature Class / Table):
          A new dataset with calculated fields."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateField_gapro(*gp_fixargs((input_layer, output, field_to_calculate, field_name, existing_field, field_type, expression, track_aware, track_fields, time_boundary_split, time_boundary_reference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ClipLayer_gapro', None)
def ClipLayer(input_layer=None, clip_layer=None, out_feature_class=None):
    """ClipLayer_gapro(input_layer, clip_layer, out_feature_class)

        Extracts input features from within specified polygons.

     INPUTS:
      input_layer (Feature Layer):
          The dataset containing the point, line, or polygon features to be
          clipped.
      clip_layer (Feature Layer):
          The dataset containing the polygon features used to clip the input
          features.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class with clipped features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ClipLayer_gapro(*gp_fixargs((input_layer, clip_layer, out_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DissolveBoundaries_gapro', None)
def DissolveBoundaries(input_layer=None, out_feature_class=None, multipart=None, dissolve_fields=None, fields=None, summary_fields=None):
    """DissolveBoundaries_gapro(input_layer, out_feature_class, {multipart}, {dissolve_fields}, {fields;fields...}, {summary_fields;summary_fields...})

        Finds polygons that intersect or have the same field values and merges
        them to form a single polygon.Which boundaries are merged can be
        controlled by specifying one or
        more fields. For example, if you have a layer of counties and each
        county has a State_Name field, you can dissolve boundaries using the
        State_Name field. Adjacent counties will be merged if they have the
        same value for State_Name. The result is a layer of state boundaries.

     INPUTS:
      input_layer (Feature Layer):
          The layer containing the polygon features that will be dissolved.
      multipart {Boolean}:
          Specifies whether multipart features will be created in the output
          feature class.

          * MULTI_PART-Multipart features will be created.

          * SINGLE_PART-Multipart features will not be created. Individual
          features will be created for each part instead. This is the default.
      dissolve_fields {Boolean}:
          Specifies whether features with the same field values will be
          dissolved.

          * NO_DISSOLVE_FIELDS-Polygons that share a common border (that is,
          they are adjacent) or polygons that overlap will be dissolved into one
          polygon. This is the default.

          * DISSOLVE_FIELDS-Polygons that have the same field value or values
          will be dissolved.
      fields {Field}:
          The field or fields that will be used to dissolve like features.
          Features with the same value for each field will be dissolved.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * Count-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * Sum-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * Mean-The mean of numeric values. The mean of [0, 2, null] is 1.

          * Min-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * Max-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * Standard Deviation-The standard deviation of a numeric field. The
          standard deviation of [1] is null. The standard deviation of [null,
          1,1,1] is null.

          * Variance-The variance of a numeric field in a track. The variance of
          [1] is null. The variance of [null, 1, 1, 1] is null.

          * Range-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * Any-A sample string from a field of type string.
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class with dissolved boundaries."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DissolveBoundaries_gapro(*gp_fixargs((input_layer, out_feature_class, multipart, dissolve_fields, fields, summary_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OverlayLayers_gapro', None)
def OverlayLayers(input_layer=None, overlay_layer=None, out_feature_class=None, overlay_type=None):
    """OverlayLayers_gapro(input_layer, overlay_layer, out_feature_class, overlay_type)

        Overlays the geometries from multiple layers into a single layer.
        Overlay can be used to combine, erase, modify, or update spatial
        features. Overlay is used to answer one of the most basic
        questions of
        geography, What is on top of what? The following are examples:

        * What parcels are within the 100-year floodplain? (Within is another
        way of saying on top of.)

        * What land use is on top of what soil type?

        * What mines are within abandoned military bases?

     INPUTS:
      input_layer (Feature Layer):
          The point, line, or polygon features that will be overlaid with the
          overlay layer.
      overlay_layer (Feature Layer):
          The features that will be overlaid with the input layer features.
      overlay_type (String):
          Specifies the type of overlay to be performed.

          * INTERSECT-Computes a geometric intersection of the input layers.
          Features or portions of features that overlap in both the input layer
          and overlay layer will be written to the output layer. This is the
          default.

          * ERASE-Only those features or portions of features in the overlay
          layer that are not within the features in the input layer are written
          to the output.

          * UNION-Computes a geometric union of the input layer and overlay
          layer. All features and their attributes will be written to the layer.

          * IDENTITY-Computes a geometric intersection of the input features
          and identity features. Features or portions of features that overlap
          in both input layer and overlay layer will be written to the output
          layer.

          * SYMMETRICAL_DIFFERENCE-Features or portions of features in the
          input layer and overlay layer that do not overlap will be written to
          the output layer.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class with overlaid features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OverlayLayers_gapro(*gp_fixargs((input_layer, overlay_layer, out_feature_class, overlay_type), True)))
        return retval
    except Exception as e:
        raise e


# Summarize Data toolset
@gptooldoc('AggregatePoints_gapro', None)
def AggregatePoints(point_layer=None, out_feature_class=None, polygon_or_bin=None, polygon_layer=None, bin_type=None, bin_size=None, time_step_interval=None, time_step_repeat=None, time_step_reference=None, summary_fields=None):
    """AggregatePoints_gapro(point_layer, out_feature_class, polygon_or_bin, {polygon_layer}, {bin_type}, {bin_size}, {time_step_interval}, {time_step_repeat}, {time_step_reference}, {summary_fields;summary_fields...})

        Aggregates points into polygon features or bins. A polygon is returned
        with a count of points as well as optional statistics at all locations
        where points exist.

     INPUTS:
      point_layer (Feature Layer):
          The point features to be aggregated into polygons or bins.
      polygon_or_bin (String):
          Specifies how the point_layer will be aggregated.

          * POLYGON-The point layer will be aggregated into a polygon dataset.

          * BIN-The point layer will be aggregated into square or hexagonal bins
          that are generated when the tool is run.
      polygon_layer {Feature Layer}:
          The polygon features into which the input points will be aggregated.
      bin_type {String}:
          Specifies the bin shape that will be generated to hold the aggregated
          points.

          * SQUARE-Square bins will be generated. in which bin_size represents
          the height of a square. This is the default.

          * HEXAGON-Hexagonal bins will be generated, in which bin_size
          represents the height between two parallel sides.
      bin_size {Linear Unit}:
          The distance interval that represents the bin size and units into
          which the point_layer will be aggregated. The distance interval must
          be a linear unit.
      time_step_interval {Time Unit}:
          A value that specifies the duration of the time step. This parameter
          is only available if the input points are time enabled and represent
          an instant in time.Time stepping can only be applied if time is
          enabled on the input.
      time_step_repeat {Time Unit}:
          A value that specifies how often the time-step interval occurs. This
          parameter is only available if the input points are time enabled and
          represent an instant in time.
      time_step_reference {Date}:
          A date that specifies the reference time with which to align the time
          steps. The default is January 1, 1970, at 12:00 a.m. This parameter is
          only available if the input points are time enabled and represent an
          instant in time.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class with the aggregated polygon results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AggregatePoints_gapro(*gp_fixargs((point_layer, out_feature_class, polygon_or_bin, polygon_layer, bin_type, bin_size, time_step_interval, time_step_repeat, time_step_reference, summary_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DescribeDataset_gapro', None)
def DescribeDataset(input_layer=None, output=None, sample_features=None, sample_layer=None, extent_layer=None):
    """DescribeDataset_gapro(input_layer, output, {sample_features}, {sample_layer}, {extent_layer})

        Summarizes features into calculated field statistics, sample features,
        and extent boundaries.

     INPUTS:
      input_layer (Table View):
          The point, line, polygon, or tabular features to be described.
      sample_features {Long}:
          The number of features that will be included in the output sample
          layer. No sample is returned if you select 0 features or don't provide
          a number. By default, no sample layer is returned.

     OUTPUTS:
      output (Table):
          A new table with the summary information.
      sample_layer {Table / Feature Class}:
          A new feature class with a sample of the input data.
      extent_layer {Feature Class}:
          A new feature class with the spatial and temporal extent of the input
          data."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DescribeDataset_gapro(*gp_fixargs((input_layer, output, sample_features, sample_layer, extent_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('JoinFeatures_gapro', None)
def JoinFeatures(target_layer=None, join_layer=None, output=None, join_operation=None, spatial_relationship=None, spatial_near_distance=None, temporal_relationship=None, temporal_near_distance=None, attribute_relationship=None, summary_fields=None, join_condition=None):
    """JoinFeatures_gapro(target_layer, join_layer, output, join_operation, {spatial_relationship}, {spatial_near_distance}, {temporal_relationship}, {temporal_near_distance}, {attribute_relationship;attribute_relationship...}, {summary_fields;summary_fields...}, {join_condition})

        Joins attributes from one layer to another based on spatial, temporal,
        or attribute relationships, or a combination of those relationships.

     INPUTS:
      target_layer (Table View):
          Contains the target features. The attributes from the target features
          and the attributes from the joined features will be transferred to the
          output.
      join_layer (Table View):
          Contains the join features. The attributes from the join features will
          be joined to the attributes of the target features. See the
          explanation of the Join Operation (join_operation in Python) parameter
          for details about how the aggregation of joined attributes are
          affected by the type of join operation.
      join_operation (String):
          Specifies how joins between the target_layer and join_layer will be
          handled in the output feature if multiple join features are found that
          have the same spatial relationship with a single target feature.

          * JOIN_ONE_TO_ONE-The attributes from the multiple join features will
          be aggregated. For example, if a point target feature is found within
          two separate polygon join features, the attributes from the two
          polygons will be aggregated before being transferred to the output
          point feature class. If one polygon has an attribute value of 3 and
          the other has a value of 7, and the summary statistic sum is specified
          for that field, the aggregated value in the output feature class will
          be 10. This is the default, and only the count statistic is returned.

          * JOIN_ONE_TO_MANY-The output feature class will contain multiple
          copies (records) of the target feature. For example, if a single-point
          target feature is found within two separate polygon join features, the
          output feature class will contain two copies of the target feature:
          one record with the attributes of one polygon and another record with
          the attributes of the other polygon. There are no summary statistics
          available with this method.
      spatial_relationship {String}:
          Specifies the criteria that will be used to spatially join features.

          * INTERSECTS-The features in the join features will be matched if they
          intersect a target feature. This is the default.

          * EQUALS-The features in the join features will be matched if they
          are the same geometry as a target feature.

          * NEAR-The features in the join features will be matched if they are
          within a specified distance of a target feature. The distance is
          measured using planar distance. Specify a distance in the
          spatial_near_distance parameter.

          * NEAR_GEODESIC-The features in the join features will be matched if
          they are within a specified distance of a target feature. The distance
          is measured geodesically. Specify a distance in the
          spatial_near_distance parameter.

          * CONTAINS-The features in the join features will be matched if a
          target feature contains them. The target features must be polygons or
          polylines. The join features can only be polygons when the target
          features are also polygons. Polygon can contain any feature type.
          Polyline can contain only polyline and point. Point cannot contain any
          feature, not even a point. If the join feature is entirely on the
          boundary of the target feature (no part is properly inside or
          outside), the feature will not be matched.

          * WITHIN-The features in the join features will be matched if a target
          feature is within them. It is the opposite of the contains
          relationship. For this option, the target features can only be
          polygons when the join features are also polygons. Point can be a join
          feature only if point is also a target feature. If the entirety of the
          feature in the join features is on the boundary of the target feature,
          the feature will not be matched.

          * TOUCHES-The features in the join features will be matched if they
          have a boundary that touches a target feature. When the target and
          join features are lines or polygons, the boundary of the join feature
          can only touch the boundary of the target feature, and no part of the
          join feature can cross the boundary of the target feature.

          * CROSSES-The features in the join features will be matched if a
          target feature is crossed by their outline. The join and target
          features must be lines or polygons. If polygons are used for the join
          or target features, the polygon's boundary (line) will be used. Lines
          that cross at a point will be matched, but lines that share a line
          segment will not.

          * OVERLAPS-The features in the join features will be matched if they
          overlap a target feature.
      spatial_near_distance {Linear Unit}:
          The distance from a target feature within which join features will be
          considered for the spatial join. A search radius is only valid when
          the spatial_relationship parameter value is NEAR or NEAR_GEODESIC.
      temporal_relationship {String}:
          Specifies the time criteria that will be used to match features.

          * MEETS-When a target time interval end is equal to the join time
          interval start, the target time meets the join time.

          * MET_BY-When a target time interval start is equal to the join time
          interval end, the target time is met by the join time.

          * OVERLAPS-When a target time interval starts and ends before the
          start and end of the join time interval, the target time overlaps the
          join time.

          * OVERLAPPED_BY-When a target time interval starts and ends after the
          start and end time of the join time interval, the target time is
          overlapped by the join time.

          * DURING-When a target time occurs between the start and end of the
          join time interval, the target time is during the join time.

          * CONTAINS-When a join feature time occurs between the start and end
          of the target time interval, the target time contains the join time.

          * EQUALS-Two times are considered equal if their instants or intervals
          are identical.

          * FINISHES-When a target time ends at the same time as a join time,
          and the target time started after the join time, the target time
          finishes the join time.

          * FINISHED_BY-When a join feature time ends at the same time as a
          target time, and the join time started after the target time, the
          target time is finished by the join time.

          * STARTS-When a target time starts at the same time as the join time
          interval start and ends before the join time interval ends, the target
          time starts the join time.

          * STARTED_BY-When a target interval time starts at the same time as
          the join time and ends after the join time, the target time is started
          by the join time.

          * INTERSECTS-When any part of a target time occurs at the same time as
          the join time, the target time intersects the join time.

          * NEAR-When a target time is within a specified range of time from the
          join time, the target time is near the join time.

          * NEAR_BEFORE-When a target time is before the join time but within a
          specified range of time from the join time, the target time is near
          before the join time.

          * NEAR_AFTER-When a target time is before the join time but within a
          specified range of time from the join time, the target time is near
          before the join time.
      temporal_near_distance {Time Unit}:
          The distance in time from a target feature within which join features
          will be considered for the spatial join. A time is only valid when the
          temporal_relationship parameter value is NEAR, NEAR_BEFORE, or
          NEAR_AFTER and both feature are time enabled.
      attribute_relationship {Value Table}:
          Joins features based on values in an attribute field. Specify
          the attribute field from the target layer that matches an attribute
          field from the join layer.

          * Target Field-An attribute field from the target layer containing
          values to match.

          * Join Field-An attribute field from the join layer containing values
          to match.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      join_condition {String}:
          Applies a condition to specified fields. Only features with fields
          that meet these conditions will be joined.For example, you could apply
          a join condition to features in which the
          HealthSpending attribute in the join layer is more than 20 percent of
          the Income attribute in the target layer. Use an Arcade expression
          such as $join["HealthSpending"] > $target["Income"] * .2.

     OUTPUTS:
      output (Feature Class / Table):
          The new feature class containing the target layer features with joined
          features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.JoinFeatures_gapro(*gp_fixargs((target_layer, join_layer, output, join_operation, spatial_relationship, spatial_near_distance, temporal_relationship, temporal_near_distance, attribute_relationship, summary_fields, join_condition), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReconstructTracks_gapro', None)
def ReconstructTracks(input_layer=None, out_feature_class=None, track_fields=None, method=None, buffer_type=None, buffer_field=None, buffer_expression=None, time_split=None, distance_split=None, time_boundary_split=None, time_boundary_reference=None, summary_fields=None):
    """ReconstructTracks_gapro(input_layer, out_feature_class, track_fields;track_fields..., method, {buffer_type}, {buffer_field}, {buffer_expression}, {time_split}, {distance_split}, {time_boundary_split}, {time_boundary_reference}, {summary_fields;summary_fields...})

        Creates line or polygon tracks from time-enabled input data.

     INPUTS:
      input_layer (Feature Layer):
          The points or polygons to be reconstructed to tracks. The input must
          be a time-enabled layer that represents an instant in time.
      track_fields (Field):
          One or more fields that will be used to identify unique tracks.
      method (String):
          Specifies the criteria that will be used to reconstruct tracks. If a
          buffer is used, method determines the type of buffer.

          * GEODESIC-If the spatial reference can be panned, tracks will cross
          the date line when appropriate. If the spatial reference cannot be
          panned, tracks will be limited to the coordinate system extent and may
          not wrap.

          * PLANAR-The tracks will never cross the date line.
      buffer_type {String}:
          Specifies how the buffer distance will be defined.

          * FIELD-A single field will be used to define the buffer distance.

          * EXPRESSION-An equation using fields and mathematical operators will
          be used to define the buffer distance.
      buffer_field {Field}:
          The field that will be used to buffer the input features. Field values
          are applied in the units of the spatial reference of the input unless
          you are using a geographic coordinate system, in which case they will
          be in meters.
      buffer_expression {Calculator Expression}:
          The expression that will be used to buffer input features. Fields must
          be numeric, and the expression can include [+ - * / ] operators and
          multiple fields. Calculated values are applied in the units of the
          spatial reference of the input unless you are using a geographic
          coordinate system, in which case they will be in meters.Use Arcade
          expressions such as as_kilometers($feature.distance) * 2 +
          as_meters(15).
      time_split {Time Unit}:
          Features that are farther apart in time than the time-split duration
          will be split into separate tracks.
      distance_split {Linear Unit}:
          Features that are farther apart in distance than the distance split
          value will be split into separate tracks.
      time_boundary_split {Time Unit}:
          A time span to split your input data into for analysis. A time
          boundary allows you to analyze values within a defined time span. For
          example, if you use a time boundary of 1 day, and set the time
          boundary reference to January 1, 1980, tracks will be will be split at
          the beginning of every day.
      time_boundary_reference {Date}:
          The reference time used to split your input data into for analysis.
          Time boundaries will be created for the entire span of the data, and
          the reference time does not need to occur at the start. If no
          reference time is used, January 1, 1970, is used.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.

          * FIRST-The first value of a specified field in a track.

          * LAST-The last value of a specified field in a track.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class with the resulting tracks."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReconstructTracks_gapro(*gp_fixargs((input_layer, out_feature_class, track_fields, method, buffer_type, buffer_field, buffer_expression, time_split, distance_split, time_boundary_split, time_boundary_reference, summary_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SummarizeAttributes_gapro', None)
def SummarizeAttributes(input_layer=None, out_table=None, fields=None, summary_fields=None):
    """SummarizeAttributes_gapro(input_layer, out_table, {fields;fields...}, {summary_fields;summary_fields...})

        Calculates summary statistics for fields in a feature class.

     INPUTS:
      input_layer (Table View):
          The point, polyline, or polygon layer to be summarized.
      fields {Field}:
          A field or fields used to summarize similar features. For example, if
          you choose a single field called PropertyType with the values of
          commercial and residential, all of the fields with the value
          residential fields will be summarized together, with summary
          statistics calculated, and all of the fields with the value commercial
          will be summarized together. This example will results in two rows in
          the output, one for commercial, and one for residential summary
          values.You can optionally select no fields and summarize all features
          in a
          single summary result.
      summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.

     OUTPUTS:
      out_table (Table):
          A new table with the summarized attributes."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeAttributes_gapro(*gp_fixargs((input_layer, out_table, fields, summary_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SummarizeWithin_gapro', None)
def SummarizeWithin(summarized_layer=None, out_feature_class=None, polygon_or_bin=None, bin_type=None, bin_size=None, summary_polygons=None, sum_shape=None, shape_units=None, standard_summary_fields=None, weighted_summary_fields=None, group_by_field=None, add_minority_majority=None, add_percentages=None, group_by_summary=None):
    """SummarizeWithin_gapro(summarized_layer, out_feature_class, {polygon_or_bin}, {bin_type}, {bin_size}, {summary_polygons}, {sum_shape}, {shape_units}, {standard_summary_fields;standard_summary_fields...}, {weighted_summary_fields;weighted_summary_fields...}, {group_by_field}, {add_minority_majority}, {add_percentages}, {group_by_summary})

        Overlays a polygon layer with another layer to summarize the number of
        points, length of the lines, or area of the polygons within each
        polygon and calculates attribute field statistics about those features
        within the polygons. The following are example scenarios using
        Summarize Within:

        * Given watershed boundaries and land-use boundaries by land-use type,
        calculate total acreage of land-use type for each watershed.

        * Given county parcels and city boundaries, summarize the average
        value of vacant parcels within each city boundary.

        * Given counties and roads, summarize the total mileage of roads by
        road type within each county.

     INPUTS:
      summarized_layer (Feature Layer):
          The point, line, or polygon features that will be summarized by either
          polygons or bins.
      polygon_or_bin {String}:
          Specifies whether summarized_layer will be summarized by polygons or
          bins.

          * POLYGON-The summarized layer will be aggregated into a polygon
          dataset.

          * BIN-The summarized layer will be aggregated into square or hexagonal
          bins.
      bin_type {String}:
          Specifies the bin shape that will be generated to summarize features.

          * SQUARE-bin_size represents the height of a square. This is the
          default.

          * HEXAGON-bin_size represents the height between two parallel sides.
      bin_size {Linear Unit}:
          The distance interval that represents the bin size and units by which
          the input features will be summarized.
      summary_polygons {Feature Layer}:
          The polygons used to summarize the features in the input summarized
          layer.
      sum_shape {Boolean}:
          Specifies whether the length of lines or area of polygons within the
          summary layer (polygon or bin) will be calculated. The count of
          points, lines, and polygons intersecting the summary shape will always
          be included.

          * ADD_SUMMARY-Summary shape values will be calculated. This is the
          default.

          * NO_SUMMARY-Summary shape values will not be calculated.
      shape_units {String}:
          Specifies the unit to be used to calculate shape summary attributes.
          If the input summarized_layer is points, no shape unit is necessary,
          since only the count of points within each input polygon is added. If
          the input summary features are lines, specify a linear unit. If the
          input summary features are polygons, specify an areal unit.

          * METERS-The shape units will be meters.

          * KILOMETERS-The shape units will be kilometers.

          * FEET-The shape units will be feet.

          * YARDS-The shape units will be yards.

          * MILES-The shape units will be miles.

          * ACRES-The shape units will be acres.

          * HECTARES-The shape units will be hectares.

          * SQUARE_METERS-The shape units will be square meters.

          * SQUARE_KILOMETERS-The shape units will be square kilometers.

          * SQUARE_FEET-The shape units will be square feet.

          * SQUARE_YARDS-The shape units will be square yards.

          * SQUARE_MILES-The shape units will be square miles.
      standard_summary_fields {Value Table}:
          The statistics that will be calculated on specified fields.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      weighted_summary_fields {Value Table}:
          Specifies the weighted statistics that will be calculated on specified
          fields.

          * COUNT-The count of each field will be calculated, multiplied by the
          proportion of the summarized layer within the polygons.

          * SUM-The sum of weighted values in each field will be calculated, in
          which the weight applied is the proportion of the summarized layer
          within the polygons.

          * MEAN-The mean of weighted values in each field will be calculated,
          in which the weight applied is the proportion of the summarized layer
          within the polygons.

          * MIN-The minimum of weighted values in each field will be calculated,
          in which the weight applied is the proportion of the summarized layer
          within the polygons.

          * MAX-The maximum of weighted values in each field will be calculated,
          in which the weight applied is the proportion of the summarized layer
          within the polygons.

          * RANGE-The difference between MIN and MAX will be calculated.
      group_by_field {Field}:
          A field from the input summary features that will be used to calculate
          statistics for each unique attribute value. For example, the input
          summary features contain point locations of businesses that store
          hazardous materials, and one of the fields is HazardClass, containing
          codes that describe the type of hazardous material stored. To
          calculate summaries by each unique value of HazardClass, use it as the
          group by field.
      add_minority_majority {Boolean}:
          Specifies whether minority (least dominant) and majority (most
          dominant) attribute values for each group field within each boundary
          will be added. If they are, two new fields are added to the output
          layer prefixed with Majority_ and Minority_. This parameter only
          applies when the group_by_field parameter is used.

          * NO_MIN_MAJ-Minority and majority fields will not be added. This is
          the default.

          * ADD_MIN_MAJ-Minority and majority fields will be added.
      add_percentages {Boolean}:
          Specifies whether percentage fields will be added. If they are, the
          percentage of each unique group value is calculated for each input
          polygon. This parameter only applies when the group_by_field and
          add_minority_majority parameters are used.

          * NO_PERCENT-Percentage fields will not be added. This is the default.

          * ADD_PERCENT-Percentage fields will be added.

     OUTPUTS:
      out_feature_class (Feature Class):
          The name of the output feature class that will contain the
          intersecting geometries and attributes.
      group_by_summary {Table}:
          The output table that will contain the group by summaries."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeWithin_gapro(*gp_fixargs((summarized_layer, out_feature_class, polygon_or_bin, bin_type, bin_size, summary_polygons, sum_shape, shape_units, standard_summary_fields, weighted_summary_fields, group_by_field, add_minority_majority, add_percentages, group_by_summary), True)))
        return retval
    except Exception as e:
        raise e


# Use Proximity toolset
@gptooldoc('CreateBuffers_gapro', None)
def CreateBuffers(input_layer=None, out_feature_class=None, method=None, buffer_type=None, buffer_field=None, buffer_distance=None, buffer_expression=None, dissolve_option=None, dissolve_fields=None, summary_fields=None, multipart=None):
    """CreateBuffers_gapro(input_layer, out_feature_class, method, buffer_type, {buffer_field}, {buffer_distance}, {buffer_expression}, {dissolve_option}, {dissolve_fields;dissolve_fields...}, {summary_fields;summary_fields...}, {multipart})

        Creates buffers around input features to a specified distance.

     INPUTS:
      input_layer (Feature Layer):
          The point, polyline, or polygon features to be buffered.
      method (String):
          Specifies the method that will be used to create the buffer.

          * GEODESIC-Buffers are created using a shape-preserving geodesic
          buffer method regardless of the input coordinate system. This is the
          default.

          * PLANAR-If the input features are in a projected coordinate system,
          Euclidean buffers are created. If the input features are in a
          geographic coordinate system, geodesic buffers are created. The Output
          Coordinate System environment setting can be used to specify a
          coordinate system.
      buffer_type (String):
          Specifies how the buffer distance will be defined.

          * DISTANCE-Apply the same linear distance to all features.

          * FIELD-Select a numeric or string field to represent the buffer
          distance.

          * EXPRESSION-Build an equation using fields, constants, and
          mathematical operations to represent the buffer distance.
      buffer_field {Field}:
          The field that contains the buffer distance for each feature. If a
          field value is a number, it is assumed that the distance is in the
          linear unit of the input_layer spatial reference, unless the
          input_layer is in a geographic coordinate system, in which case, the
          value is assumed to be in meters. If the linear unit specified in the
          field values is invalid or not recognized, the linear unit of the
          input features' spatial reference will be used by default.
      buffer_distance {Linear Unit}:
          The distance around the input features that will be buffered. Distance
          can be expressed in meters, kilometers, feet, yards, miles, or
          nautical miles.
      buffer_expression {Calculator Expression}:
          An equation using fields and mathematical operators that will be
          applied as a buffer to each feature. Fields must be numeric, and the
          expression can include [+ - * / ] operators and multiple fields.
          Calculated values are applied in meters unless otherwise specified.
          For example, apply a buffer that multiples a numeric field named
          distance in kilometers by 2 and adds 15 meters.Use an Arcade
          expression such as as_kilometers($feature["distance"]) *
          2 + as_meters(15).
      dissolve_option {String}:
          Specifies the dissolve option that will be used to remove buffer
          overlap.

          * NONE-An individual buffer for each feature will be maintained
          regardless of overlap. This is the default.

          * ALL-All buffers will be dissolved together into a single feature,
          removing any overlap.

          * LIST-Any buffers sharing attribute values in the listed fields
          (carried over from the input features) will be dissolved.
      dissolve_fields {Field}:
          A list of one or more fields from the input features on which output
          buffers will be dissolved. Any buffers sharing attribute values in the
          listed fields will be dissolved. This option is only required when
          dissolve_option is LIST.
      summary_fields {Value Table}:
          Specifies statistics that can be applied to numeric and string fields.
          If left empty, only count will be calculated. These statistics are
          only applied when dissolve_option is LIST or ALL.

          * COUNT-The number of nonnull values. It can be used on numeric fields
          or strings. The count of [null, 0, 2] is 2.

          * SUM-The sum of numeric values in a field. The sum of [null, null, 3]
          is 3.

          * MEAN-The mean of numeric values. The mean of [0,2, null] is 1.

          * MIN-The minimum value of a numeric field. The minimum of [0, 2,
          null] is 0.

          * MAX-The maximum value of a numeric field. The maximum value of [0,
          2, null] is 2.

          * STDDEV-The standard deviation of a numeric field. The standard
          deviation of [1] is null. The standard deviation of [null, 1,1,1] is
          null.

          * VAR-The variance of a numeric field in a track. The variance of [1]
          is null. The variance of [null, 1,1,1] is null.

          * RANGE-The range of a numeric field. This is calculated as the
          minimum value subtracted from the maximum value. The range of [0,
          null, 1] is 1. The range of [null, 4] is 0.

          * ANY-A sample string from a field of type string.
      multipart {Boolean}:
          Specifies whether multipart features will be created.

          * MULTI_PART-Output multipart features will be created where
          appropriate.

          * SINGLE_PART-Instead of creating multipart features, individual
          features will be created for each part. This is the default.

     OUTPUTS:
      out_feature_class (Feature Class):
          A new feature class of buffered results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateBuffers_gapro(*gp_fixargs((input_layer, out_feature_class, method, buffer_type, buffer_field, buffer_distance, buffer_expression, dissolve_option, dissolve_fields, summary_fields, multipart), True)))
        return retval
    except Exception as e:
        raise e


# Utilities\Big Data Connections toolset
@gptooldoc('CopyDatasetFromBDC_gapro', None)
def CopyDatasetFromBDC(input_layer=None, output=None):
    """CopyDatasetFromBDC_gapro(input_layer, output)

        Copies a dataset from a big data connection (BDC) to a feature class.

     INPUTS:
      input_layer (Table View):
          The point, line, polygon, or table dataset to be copied.

     OUTPUTS:
      output (Feature Class / Table):
          The output dataset to be copied from a big data connection."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyDatasetFromBDC_gapro(*gp_fixargs((input_layer, output), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateBDC_gapro', None)
def CreateBDC(bdc_location=None, bdc_name=None, connection_type=None, data_source_folder=None, visible_geometry=None, visible_time=None):
    """CreateBDC_gapro(bdc_location, bdc_name, connection_type, {data_source_folder}, {visible_geometry}, {visible_time})

        Creates a big data connection file (.bdc) and item. Datasets
        registered in a big data connection (BDC) can be used as input to
        GeoAnalytics Desktop tools and other geoprocessing tools.

     INPUTS:
      bdc_location (Folder):
          The folder where the .bdc file will be created.
      bdc_name (String):
          The name of the .bdc file to be created.
      connection_type (String):
          Specifies the type of connection to be created.

          * FOLDER-Connect to a file system location. This is the default.
      data_source_folder {Folder}:
          The folder containing the datasets to be registered with the BDC.
      visible_geometry {Boolean}:
          Specifies whether the fields used to specify the geometry will be
          visible as fields when the BDC file is used as input to other
          geoprocessing tools. When the geometry fields are not visible,
          geometry is still applied to the dataset. The geometry visibility
          setting can be modified in the BDC.

          * GEOMETRY_VISIBLE-Geometry fields will be included as fields for
          analysis. This is the default.

          * GEOMETRY_NOT_VISIBLE-Geometry fields will not be included as fields
          for analysis.
      visible_time {Boolean}:
          Specifies whether the fields used to specify the time will be visible
          as fields when the BDC file is used as input to other geoprocessing
          tools. When the time fields are not visible, time is still applied to
          the dataset. The time visibility setting can be modified in the BDC.

          * TIME_VISIBLE-Time fields will be included as fields for analysis.
          This is the default.

          * TIME_NOT_VISIBLE-Time fields will not be included as fields for
          analysis."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateBDC_gapro(*gp_fixargs((bdc_location, bdc_name, connection_type, data_source_folder, visible_geometry, visible_time), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DuplicateDatasetFromBDC_gapro', None)
def DuplicateDatasetFromBDC(bdc_dataset=None, duplicate_name=None):
    """DuplicateDatasetFromBDC_gapro(bdc_dataset, {duplicate_name})

        Creates a duplicate of a big data connection (BDC) dataset.

     INPUTS:
      bdc_dataset (Table View):
          The BDC dataset to be duplicated.
      duplicate_name {String}:
          The name of the output BDC dataset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DuplicateDatasetFromBDC_gapro(*gp_fixargs((bdc_dataset, duplicate_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PreviewDatasetFromBDC_gapro', None)
def PreviewDatasetFromBDC(bdc_dataset=None, out_preview_file=None):
    """PreviewDatasetFromBDC_gapro(bdc_dataset, {out_preview_file})

        Creates a preview of the first ten features in a big data connection
        (BDC) dataset.

     INPUTS:
      bdc_dataset (Table View):
          The dataset to preview from the BDC file.

     OUTPUTS:
      out_preview_file {File}:
          The output .csv file that represents a preview of your BDC dataset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PreviewDatasetFromBDC_gapro(*gp_fixargs((bdc_dataset, out_preview_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RefreshBDC_gapro', None)
def RefreshBDC(bdc_file=None, visible_geometry=None, visible_time=None):
    """RefreshBDC_gapro(bdc_file, {visible_geometry}, {visible_time})

        Refreshes an existing big data connection (BDC) and registers any new
        datasets that have been added to the source location.

     INPUTS:
      bdc_file (File):
          The BDC file to refresh.
      visible_geometry {Boolean}:
          Specifies whether the fields used to identify the geometry will be
          included (visible) as fields for analysis when the BDC file is used in
          other geoprocessing tools. When geometry fields are not visible,
          geometry is still applied to the dataset. The geometry visibility
          setting can be modified in the BDC.

          * GEOMETRY_VISIBLE-Geometry fields will be included as fields for
          analysis. This is the default.

          * GEOMETRY_NOT_VISIBLE-Geometry fields will not be included as fields
          for analysis.
      visible_time {Boolean}:
          Specifies whether the fields used to indicate the time will be
          included (visible) as fields for analysis when the BDC file is used in
          other geoprocessing tools. When time fields are not visible, time is
          still applied to the dataset. The time visibility setting can be
          modified in the BDC.

          * TIME_VISIBLE-Time fields will be included as fields for analysis.
          This is the default.

          * TIME_NOT_VISIBLE-Time fields will not be included as fields for
          analysis."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RefreshBDC_gapro(*gp_fixargs((bdc_file, visible_geometry, visible_time), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveDatasetFromBDC_gapro', None)
def RemoveDatasetFromBDC(bdc_datasets=None):
    """RemoveDatasetFromBDC_gapro(bdc_datasets;bdc_datasets...)

        Removes one or more datasets from an existing big data connection
        (BDC). This tool only removes the dataset from the BDC file, the
        source data is not modified.

     INPUTS:
      bdc_datasets (Table View):
          The datasets to remove from the .bdc file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveDatasetFromBDC_gapro(*gp_fixargs((bdc_datasets,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateBDCDatasetProperties_gapro', None)
def UpdateBDCDatasetProperties(bdc_dataset=None, expression=None, field_properties=None, geometry_type=None, spatial_reference=None, geometry_format_type=None, geometry_field=None, x_field=None, y_field=None, z_field=None, time_type=None, time_zone=None, start_time_format=None, end_time_format=None, file_extension=None, field_delimiter=None, record_terminator=None, quote_character=None, has_header_row=None, encoding=None):
    """UpdateBDCDatasetProperties_gapro(bdc_dataset, {expression}, {field_properties;field_properties...}, {geometry_type}, {spatial_reference}, {geometry_format_type}, {geometry_field}, {x_field}, {y_field}, {z_field}, {time_type}, {time_zone}, {start_time_format;start_time_format...}, {end_time_format;end_time_format...}, {file_extension}, {field_delimiter}, {record_terminator}, {quote_character}, {has_header_row}, {encoding})

        Updates the properties of a big data connection (BDC) dataset. This
        tool modifies field, geometry, time, and file settings for a specified
        BDC dataset.

     INPUTS:
      bdc_dataset (Table View):
          The BDC dataset to update. The options for editing will differ
          depending on the source data (shapefile, delimited file, ORC, or
          parquet file).
      expression {SQL Expression}:
          An expression used to limit the features that will be used in
          analysis.
      field_properties {Value Table}:
          Specifies the field names and properties to modify.

          * SHORT-The field will be type short.

          * LONG-The field will be type long

          * DOUBLE-The field will be type double.

          * FLOAT-The field will be type float.

          * STRING-The field will be type string.

          * DATE-The field will be type date.

          * BLOB-The field will be type BLOB.
          Specifies whether fields will be visible or hidden.

          * TRUE-The fields will be visible and available for use in
          geoprocessing tools. This is the default.

          * FALSE-The fields will be hidden and cannot be used as input to
          geoprocessing tools.
      geometry_type {String}:
          Specifies the type of geometry that will be used to spatially
          represent the dataset. The geometry cannot be modified for shapefile-
          sourced datasets.

          * POINT-The geometry type is point.

          * LINE-The geometry type is polyline.

          * POLYGON-The geometry type is polygon.

          * NONE-No geometry type.
      spatial_reference {String}:
          The WKID value or WKT string that will be used for the spatial
          reference of the dataset. The default is WKID 4326 (WGS84). The
          spatial reference cannot be modified for shapefile-sourced data.
      geometry_format_type {String}:
          Specifies how the geometry will be formatted. The geometry cannot be
          modified for shapefile-sourced data.

          * XYZ-Two or more fields will represent x, y, and optionally z.

          * WKT-The geometry will be represented by a single field in a well-
          known text field.

          * WKB-The geometry will be represented by a single field in a well-
          known binary field.

          * GEOJSON-The geometry will be represented by a single field in
          GeoJSON format.

          * ESRIJSON-The geometry will be represented by a single field in
          EsriJSON format.
      geometry_field {String}:
          A single field used to represent the geometry. This field is used when
          the geometry format is WKT, WKB, GeoJSON, or EsriJSON.
      x_field {String}:
          The field used to represent the x-location. If you have more than one
          field representing the x-location, modify the .bdc file manually.
      y_field {String}:
          The field used to represent the y-location. If you have more than one
          field representing the y-location, modify the .bdc file manually.
      z_field {String}:
          The field used to represent the z-location. If you have more than one
          field representing the z-location, modify the .bdc file manually.
      time_type {String}:
          Specifies the time type used to temporally represent the dataset.

          * INTERVAL-The time type will represent a duration of time with a
          start and end time.

          * INSTANT-The time type will represent an instant in time.

          * NONE-Time is not enabled.
      time_zone {String}:
          The time zone of the dataset.
      start_time_format {Value Table}:
          The fields used to define the start time and the time formatting.
      end_time_format {Value Table}:
          The fields used to define the end time and the time formatting.
      file_extension {String}:
          The file extension of the source dataset. The parameter value cannot
          be modified.
      field_delimiter {String}:
          The field delimiter used in the source dataset.
      record_terminator {String}:
          The record terminator used in the source dataset.
      quote_character {String}:
          The quote character used in the source dataset.
      has_header_row {Boolean}:
          Specifies whether the source dataset includes a header row.

          * HAS_HEADER-The source dataset includes a header row.

          * NO_HEADER-The source dataset does not include a header row.
      encoding {String}:
          The type of encoding used by the source dataset. By default UTF-8 is
          used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateBDCDatasetProperties_gapro(*gp_fixargs((bdc_dataset, expression, field_properties, geometry_type, spatial_reference, geometry_format_type, geometry_field, x_field, y_field, z_field, time_type, time_zone, start_time_format, end_time_format, file_extension, field_delimiter, record_terminator, quote_character, has_header_row, encoding), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject