# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Geocoding Tools"""
__all__ = ['ConsolidateLocator', 'CreateAddressLocator',
           'CreateCompositeAddressLocator', 'CreateFeatureLocator',
           'CreateLocator', 'GeocodeAddresses', 'GeocodeFile',
           'GeocodeLocationsFromTable', 'PackageLocator',
           'RebuildAddressLocator', 'RematchAddresses', 'ReverseGeocode',
           'StandardizeAddresses']
__alias__ = 'geocoding'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy import _geocoding
from arcpy._geocoding import *
__all__ += _geocoding.__all__

# Tools
@gptooldoc('ConsolidateLocator_geocoding', None)
def ConsolidateLocator(in_locator=None, output_folder=None, copy_arcsde_locator=None):
    """ConsolidateLocator_geocoding(in_locator, output_folder, {copy_arcsde_locator})

        Consolidate Locator

     INPUTS:
      in_locator (Address Locator):
          Input Locator
      copy_arcsde_locator {Boolean}:
          Composite locator only: copy participating locators in ArcSDE database instead of referencing them

     OUTPUTS:
      output_folder (Folder):
          Output Folder"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConsolidateLocator_geocoding(*gp_fixargs((in_locator, output_folder, copy_arcsde_locator), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateCompositeAddressLocator_geocoding', None)
def CreateCompositeAddressLocator(in_address_locators=None, in_field_map=None, in_selection_criteria=None, out_composite_address_locator=None):
    """CreateCompositeAddressLocator_geocoding(in_address_locators;in_address_locators..., in_field_map, {in_selection_criteria;in_selection_criteria...}, out_composite_address_locator)

        Creates a composite address locator. A composite locator consists of
        two or more individual locators that allow addresses to be matched
        against the multiple locators.

     INPUTS:
      in_address_locators (Value Table):
          The order of the participating address locators determines how
          candidates are searched and an address is matched. When you geocode a
          single address, the address will be matched against all participating
          address locators unless the locator is specified with a selection
          criterion. All the found candidates will be displayed based on the
          order of the listed participating address locators. If you geocode a
          table of addresses, addresses are matched automatically to the first
          best candidate found from the first participating address locators. If
          the address fails to match, it will fall back to the subsequent
          locator in the list.A reference name for each participating locator is
          required. This is
          the name of the locator referred to by the composite locator. The name
          should contain no space or special symbols. The maximum length of the
          name is 14 characters.
      in_field_map (Field Mappings):
          The mapping of input fields used by each participating locator to the
          input fields of the composite address locator.
      in_selection_criteria {Value Table}:
          Selection criteria for each participating locator. Only one selection
          criterion is supported for each participating address locator.Using
          selection criteria will disqualify participating address
          locators that do not meet the criteria on a particular address so that
          the geocoding process will be more efficient. Refer to the topic
          Fundamentals of combining multiple locators into a composite locator
          to learn more about the use of selection criteria in the geocoding
          process.

     OUTPUTS:
      out_composite_address_locator (Address Locator):
          The composite address locator to create. ArcGIS Pro only supports
          saving locators in a file folder."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateCompositeAddressLocator_geocoding(*gp_fixargs((in_address_locators, in_field_map, in_selection_criteria, out_composite_address_locator), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateFeatureLocator_geocoding', None)
def CreateFeatureLocator(in_features=None, search_fields=None, output_locator=None, locator_fields=None):
    """CreateFeatureLocator_geocoding(in_features, search_fields, output_locator, {locator_fields})

        Creates a locator using reference data that contains a unique name or
        value for every feature stored in a single field. A locator created
        with this tool has broad applications. It can be used to search for
        names or unique attributes of your features, such as water meters,
        short place names, cell towers, or alphanumeric strings used to
        identify locations (for example, N1N115).Locators created by this tool
        will use the indexed values in a single
        field to search for values in the single field and return them as a
        collection of points, or identify features near a point location.
        Tables of addresses that can be geocoded using a locator created with
        this tool must also contain a single field with the same unique name
        or value that can be used to identify the locations.Locators created
        by this tool can be used in ArcGIS Pro 2.5 or later,
        Enterprise 10.8 or later, and as a locator service in ArcMap. Locators
        created by this tool cannot be used as a local locator in ArcMap. To
        use a locator locally in ArcMap, use the Create Address Locator tool
        with either the General - Gazetteer or General - Single Field address
        locator style.

     INPUTS:
      in_features (Feature Layer):
          The reference data feature class or feature layer that will be used to
          create the locator.Feature classes represented as services are
          supported data types for
          use as reference data.When a definition query is defined for the
          reference data or there are
          selected features, only the queried and selected features are included
          when the locator is created.When creating a locator with reference
          data that contains millions of
          features, you must have at least three to four times the size of the
          data in free disk space on the drive containing your temp directory,
          as files used to build the locator are written to this location before
          the locator is copied to the output location. If you do not have
          enough disk space, the tool will fail when it runs out of space. Also,
          when creating large locators, your machine must have enough RAM to
          handle large memory-intensive processes.
      search_fields (Field Info):
          Maps the reference data field to the field used for search in the
          in_features parameter. The search_fields mapping is done in the
          following format, in which <locator field name> is the name of the
          field supported by the locator role, and <data field name> is the name
          of the field used for search in the in_features parameter.# <locator
          field name> <data field name> # This shows an example:
          reference_data_field_map = ''' "'Name' AssetName" '''The selected
          field will be indexed and used for search. Map the
          relevant field for the reference data in the in_features parameter.
      locator_fields {Field Info}:
          Maps additional fields for extent and rank if they exist in your data.
          The Rank field is used to sort results for ambiguous queries or
          candidates that have the same name and score. The extent fields help
          set the map extent for displaying geocoded results. The locator_fields
          mapping is done in the following format:# <additional locator field
          name> <additional data field name> # This
          shows an example: additional_fields_map = ''' "'Rank' RANK;'Min X'
          Xmin; 'Max X' Xmax;'Min Y' Ymin; 'Max Y' Ymax" '''The <additional
          locator field name> field is the name of the
          additional fields supported by the locator, and the <additional data
          field name> field is the name of the field in the in_features
          parameter. Map the relevant fields for the reference data in the
          in_features parameter.

     OUTPUTS:
      output_locator (Address Locator):
          The output locator file to be created in a file folder. Once the
          locator is created, additional properties and options can be modified
          in the locator's settings."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateFeatureLocator_geocoding(*gp_fixargs((in_features, search_fields, output_locator, locator_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateLocator_geocoding', None)
def CreateLocator(country_code=None, primary_reference_data=None, field_mapping=None, out_locator=None, language_code=None, alternatename_tables=None, alternate_field_mapping=None, custom_output_fields=None, precision_type=None):
    """CreateLocator_geocoding(country_code, primary_reference_data;primary_reference_data..., field_mapping;field_mapping..., out_locator, language_code, {alternatename_tables;alternatename_tables...}, {alternate_field_mapping;alternate_field_mapping...}, {custom_output_fields;custom_output_fields...}, {precision_type})

        Creates a locator that can find the location of an address or a place,
        convert a table of addresses or places into a collection of point
        features, or identify the address of a point location.Locators created
        by this tool can be used in ArcGIS Pro 2.2 or later,
        Enterprise 10.6.1 or later, and as a locator service in ArcMap. Not
        all locator functionality may be supported prior to Enterprise 10.7.
        This will apply as additional functionality is added to newer versions
        of the software. Locators created by this tool cannot be used as a
        local locator in ArcMap.

     INPUTS:
      country_code (String):
          Specifies where country-specific geocoding logic will be applied to
          the reference data for the locator.It can be specified by
          AS_DEFINED_IN_DATA and a value can be mapped
          from primary_reference_data in field_mapping, or it can be applied to
          the entire dataset by specifying the Three-character country code name
          such as USA, CAN, or PRI.It provides a country template containing the
          expected field names
          that are available for use by the field_mapping parameter for the
          specified country of the locator to be created.

          * AS_DEFINED_IN_DATA-Three-character country code value defined in the
          reference data for each feature

          * ASM-American Samoa

          * AUS-Australia

          * AUT-Austria

          * BEL-Belgium

          * CAN-Canada

          * CHE-Switzerland

          * DEU-Germany

          * ESP-Spain

          * FRA-France

          * GBR-Great Britain

          * GUM-Guam

          * MNP-Northern Mariana Islands

          * NLD-Netherlands

          * PRI-Puerto Rico

          * VIR-U.S. Virgin Islands

          * USA-United States

          * UMI-Minor Outlying Islands of the United States
      primary_reference_data (Value Table):
          The reference data feature classes and their roles that will be used
          to create the locator. Only one primary table can be used per
          role.Feature classes represented as services are supported data types
          for
          use as primary reference data.When a definition query is defined for
          the primary reference data or
          there are selected features, only the queried and selected features
          are included when the locator is created.When creating a locator with
          reference data that contains millions of
          features, you must have at least three to four times the size of the
          data in free disk space on the drive containing your temp directory,
          as files used to build the locator are written to this location before
          the locator is copied to the output location. If you do not have
          enough disk space, the tool will fail when it runs out of space. Also,
          when creating large locators, your machine must have enough RAM to
          handle large memory-intensive processes.
      field_mapping (String):
          The mapping of primary reference dataset fields to the fields
          supported by the locator role. Each field mapping in this parameter is
          in the following format in which <role name> is the locator role name,
          <locator role field name> is the name of the field supported by the
          locator role, <primary data> is the name of the data used in the
          primary_reference_data parameter, and <primary data field name> is the
          name of the field in the primary reference dataset. # <role
          name>.<locator role field name> <primary data>.<primary
          data field name> # This shows an example:
          primary_reference_data_field_map =
          "'StreetAddress.HOUSE_NUMBER_FROM_LEFT streets.L_F_ADD';"\\
          "'StreetAddress.HOUSE_NUMBER_TO_LEFT streets.L_T_ADD';"\\
          "'StreetAddress.HOUSE_NUMBER_FROM_RIGHT streets.R_F_ADD';"\\
          "'StreetAddress.HOUSE_NUMBER_TO_RIGHT streets.R_T_ADD';"\\
          "'StreetAddress.STREET_PREFIX_DIR streets.PREFIX';"\\
          "'StreetAddress.STREET_PREFIX_TYPE streets.PRE_TYPE';"\\
          "'StreetAddress.STREET_NAME streets.NAME';"\\
          "'StreetAddress.STREET_SUFFIX_TYPE streets.TYPE';"\\
          "'StreetAddress.STREET_SUFFIX_DIR streets.SUFFIX';"\\
          "'StreetAddress.CITY_LEFT streets.CITYL';"\\ "'StreetAddress.CITY_RIGHT
          streets.CITYR';"\\ "'StreetAddress.REGION_LEFT streets.STATE_ABBR';"\\
          "'StreetAddress.REGION_RIGHT streets.STATE_ABBR';"\\
          "'StreetAddress.POSTAL_LEFT streets.ZIPL';"\\
          "'StreetAddress.POSTAL_RIGHT streets.ZIPR'"       The following is an
          example of primary field_mapping.Map the relevant fields for each
          table in the primary_reference_data
          parameter. If you choose not to map an optional reference data field
          used by the locator role to a field in a reference dataset, it is not
          necessary to specify that there is no mapping using <None> in place of
          a field name.To determine the <locator role field name> for a
          reference data field
          used by a locator role, open the Create Locator tool in ArcGIS Pro and
          choose the locator role. The name that appears in the Field Name
          column of the Field Mapping parameter is the field's role field
          name.If you are using an alternate name table, map Join ID in
          primary_reference_data.To add custom output fields, the names of the
          fields must be defined
          in the custom_output_fields parameter as well as the field_mapping
          parameter. The field_mapping parameter will use the format '<locator
          role field name> <primary data field name>', in which <locator role
          field name> is defined as 'RoleName.CustomFieldName', and <primary
          data field name> is the name of the field in the primary reference
          dataset as shown in the mapped fields in the example above. If a
          custom field is added to a Street Address role, you will need to map
          'StreetAddress.CustomFieldName_Left' and
          'StreetAddress.CustomFieldName_Right' for each side of the street.
      language_code (String):
          Specifies where language-specific geocoding logic will be applied to
          the reference data for the locator.If a language code field exists in
          the primary reference data,
          providing a language code can improve the results of the geocoding.It
          can be specified by setting AS_DEFINED_IN_DATA as the language_code
          and mapping a value from primary_reference_data in field_mapping, or
          it can be applied to the entire dataset by specifying a language using
          the three-character language code representing the language of the
          address, such as ENG.

          * AS_DEFINED_IN_DATA-Three-character language code value defined in
          the reference data for each feature

          * BAQ-Basque

          * CAT-Catalan

          * DUT-Dutch

          * ENG-English

          * FRE-French

          * GER-German

          * GLG-Galician

          * ITA-Italian

          * SPA-Spanish
      alternatename_tables {Value Table}:
          The tables that contain alternate names for the features in the
          primary role tables.Tables represented as services are supported data
          types for use as
          alternate name tables.When a definition query is defined for the
          alternate name table or
          there are selected records, only the queried and selected records are
          included when the locator is created.
      alternate_field_mapping {String}:
          Maps alternate name table fields to the alternate data fields
          supported by the locator role. Each field mapping should use the
          following format, in which <alternate name table role> is the name of
          the alternate name table role,<locator role alternate field name> is
          the name of the alternate data field supported by the alternate name
          table locator role, <alternate data table> is the name of the
          alternate name table, and <alternate data table field name> is the
          name of the field in the alternate name table. Map the relevant fields
          for each table in alternatename_tables. # <alternate name table
          role>.<locator role alternate field
          name> <alternate data table>.<alternate data table field name> # This
          shows an example: alternate_data__table_field_map =
          "'AlternateStreetName.STREET_NAME_JOIN_ID altname.JOINID';"\\
          "'AlternateStreetName.STREET_PREFIX_DIR altname.PRE_DIR';"\\
          "'AlternateStreetName.STREET_PREFIX_TYPE altname.PRE_TYPE';"\\
          "'AlternateStreetName.STREET_NAME altname.ST_NAME';"\\
          "'AlternateStreetName.STREET_SUFFIX_TYPE altname.ST_TYPE';"\\
          "'AlternateStreetName.STREET_SUFFIX_DIR altname.SUF_DIR'"       The
          following is an example of alternate_field_mapping for
          alternatename_tables.If the data is normalized and the primary table
          does not contain city
          name values but the alternate name table does, the Primary Name
          Indicator field can be mapped to a field in the alternate name table
          that contains a value that indicates whether the record is the primary
          field (for example, true/false or Yes/No). If this field is not
          mapped, the first record in the alternate name table will be used as
          the primary value.
      custom_output_fields {String}:
          Adds output fields to the geocode result. The values specified for
          this parameter will define the names of the output fields that will be
          returned by the geocode result; however, each new field must be mapped
          to a field in your reference data. This new output field will apply
          for all roles that were used in the locator. If the locator role has a
          left and right side, _left and _right will be appended to the end of
          the field name.You must first include the custom output field names in
          the
          field_mapping parameter; then list the names in the
          custom_output_fields parameter.
      precision_type {String}:
          Specifies the precision of the locator.Locators created with
          GLOBAL_EXTRA_HIGH or LOCAL_EXTRA_HIGH precision
          can be used in ArcGIS Pro 2.6 or later, Enterprise 10.8.1 or later.

          * GLOBAL_EXTRA_HIGH-Approximately 1 centimeter precision, consistent
          globally.

          * GLOBAL_HIGH-Approximately 0.5 meter precision, consistent globally.
          This is the default.

          * LOCAL_EXTRA_HIGH-Increased precision for local areas.

     OUTPUTS:
      out_locator (Address Locator):
          The output address locator file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateLocator_geocoding(*gp_fixargs((country_code, primary_reference_data, field_mapping, out_locator, language_code, alternatename_tables, alternate_field_mapping, custom_output_fields, precision_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeocodeAddresses_geocoding', None)
def GeocodeAddresses(in_table=None, address_locator=None, in_address_fields=None, out_feature_class=None, out_relationship_type=None, country=None, location_type=None, category=None):
    """GeocodeAddresses_geocoding(in_table, address_locator, in_address_fields, out_feature_class, {out_relationship_type}, {country;country...}, {location_type}, {category;category...})

        Geocodes a table of addresses. This process requires a table that
        stores the addresses you want to geocode and an address locator or a
        composite address locator. This tool matches the addresses against the
        locator and saves the result for each input record in a new point
        feature class. When using the ArcGIS World Geocoding Service, this
        operation may consume credits.Performing geocoding operations using
        the ArcGIS World Geocoding
        Service requires an ArcGIS Online organizational subscription and
        consumes credits. The organizational account must have enough credits
        to complete the entire geocoding request.

     INPUTS:
      in_table (Table View):
          The table of addresses to geocode.
      address_locator (Address Locator):
          The address locator to use to geocode the table of addresses.
          Including the .loc extension after the locator name at the end of the
          locator path is optional.
      in_address_fields (Field Info):
          Each field mapping in this parameter is in the format
          input_address_field, table_field_name where input_address_field is the
          name of the input address field specified by the address locator, and
          table_field_name is the name of the corresponding field in the table
          of addresses you want to geocode.You can specify one single input
          field that stores the complete
          address, for example, 303 Peachtree St NE, Atlanta, GA 30308.
          Alternatively, you can specify multiple fields if the input addresses
          are split into multiple fields such as Address, City, State, and ZIP
          for a general United States address.Some locators support multiple
          input address fields, such as Address,
          Address2, and Address3. In this case, the address component can be
          separated into multiple fields, and the address fields will be
          concatenated at the time of geocoding. For example, 100, Main st, and
          Apt 140 across three fields, or 100 Main st and Apt 140 across two
          fields, both become 100 Main st Apt 140 when geocoding.If you choose
          not to map an optional input address field used by the
          address locator to a field in the input table of addresses, specify
          that there is no mapping using <None> in place of the field name.
      out_relationship_type {Boolean}:
          This parameter has no effect in ArcGIS Pro. It remains to support
          backward compatibility with ArcGIS Desktop.In ArcGIS Pro, the only
          permissible value is STATIC.

          * STATIC-A static copy of the fields input address table is created in
          the output feature class. This is the only permissible value.

          * DYNAMIC-This option is not applicable in ArcGIS Pro. See ArcGIS
          Desktop help for this tool.
      country {String}:
          This parameter is available for locators that support a country
          parameter and will limit geocoding to the selected countries. Making a
          country selection will improve the accuracy of geocoding in most
          cases. If a field representing countries in the Input Table is mapped
          to the Country field in Input Address Fields, the country value from
          the Input Table will override the Country parameter.This is limited to
          the selected country or countries. When no country
          is specified, geocoding is performed against all supported countries
          of the locator. The input value should be specified as ISO 3166-1
          3-character country codes.Country is not supported for all locators.
      location_type {String}:
          Specifies the preferred output geometry for POINT_ADDRESS matches. The
          options for this parameter are ROUTING_LOCATION, the side of street
          location, which can be used for routing, or ADDRESS_LOCATION, the
          location that represents the rooftop, parcel centroid for the address,
          or front door. If the preferred location does not exist in the data,
          the default location of ROUTING_LOCATION will be returned instead. For
          geocode results with Addr_type = PointAddress, the x,y attribute
          values describe the coordinates of the address along the street, while
          the DisplayX and DisplayY values describe the rooftop or building
          centroid coordinates. See the REST API web help for additional details
          about the locationType parameter for reverseGeocode.This parameter is
          not supported for all locators.

          * ADDRESS_LOCATION-Geometry for geocode results that represent an
          address location such as rooftop location, parcel centroid, or front
          door is returned.

          * ROUTING_LOCATION-Geometry for geocode results that represent a
          location close to the side of the street, which can be used for
          vehicle routing, is returned. This is the default.
      category {String}:
          Limits the types of places the locator searches, which
          eliminates false positive matches and potentially speeds up the search
          process. When no category is used, geocoding is performed against all
          supported categories. Not all category values are supported for all
          locations and countries. In general, the parameter can be used for the
          following:

          * Limit matches to specific place types or address levels

          * Avoid fallback matches to unwanted address levels

          * Disambiguate coordinate searches
          This parameter is not supported for all locators.See the REST API web
          help for details about category filtering.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output geocoded feature class or shapefile."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeocodeAddresses_geocoding(*gp_fixargs((in_table, address_locator, in_address_fields, out_feature_class, out_relationship_type, country, location_type, category), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PackageLocator_geocoding', None)
def PackageLocator(in_locator=None, output_file=None, copy_arcsde_locator=None, additional_files=None, summary=None, tags=None):
    """PackageLocator_geocoding(in_locator, output_file, {copy_arcsde_locator}, {additional_files;additional_files...}, {summary}, {tags})

        Package Locator

     INPUTS:
      in_locator (Address Locator):
          Input Locator
      copy_arcsde_locator {Boolean}:
          Composite locator only: copy participating locators in ArcSDE database instead of referencing them
      additional_files {File}:
          Additional Files
      summary {String}:
          Summary
      tags {String}:
          Tags

     OUTPUTS:
      output_file (File):
          Output File"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PackageLocator_geocoding(*gp_fixargs((in_locator, output_file, copy_arcsde_locator, additional_files, summary, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RebuildAddressLocator_geocoding', None)
def RebuildAddressLocator(in_address_locator=None):
    """RebuildAddressLocator_geocoding(in_address_locator)

        Rebuilds an address locator to update the locator with the current
        reference data. Because a locator contains a snapshot of the reference
        data when it was created, it will not geocode addresses with the
        updated data when the geometry and attributes of the reference data
        are changed. To geocode addresses with the current version of the
        reference data, the locator must be rebuilt if you want to update the
        changes in the locator.

     INPUTS:
      in_address_locator (Address Locator):
          The address locator to rebuild."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RebuildAddressLocator_geocoding(*gp_fixargs((in_address_locator,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RematchAddresses_geocoding', None)
def RematchAddresses(in_geocoded_feature_class=None, in_where_clause=None):
    """RematchAddresses_geocoding(in_geocoded_feature_class, {in_where_clause})

        Rematches addresses in a geocoded feature class.

     INPUTS:
      in_geocoded_feature_class (Feature Class):
          The geocoded feature class to be rematched.
      in_where_clause {SQL Expression}:
          An SQL expression used to select a subset of features. For more
          information on SQL syntax see the help topic SQL reference for
          elements used in query expressions."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RematchAddresses_geocoding(*gp_fixargs((in_geocoded_feature_class, in_where_clause), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReverseGeocode_geocoding', None)
def ReverseGeocode(in_features=None, in_address_locator=None, out_feature_class=None, address_type=None, search_distance=None, feature_type=None, location_type=None):
    """ReverseGeocode_geocoding(in_features, in_address_locator, out_feature_class, {address_type}, search_distance, {feature_type;feature_type...}, {location_type})

        Creates addresses from point locations in a feature class. The reverse
        geocoding process searches for the nearest address or intersection for
        the point location based on the specified search distance. When using
        the ArcGIS World Geocoding Service, this operation may consume
        credits.Performing geocoding operations using the ArcGIS World
        Geocoding
        Service requires an ArcGIS Online organizational subscription and
        consumes credits. The organizational account must have enough credits
        to complete the entire geocoding request.

     INPUTS:
      in_features (Feature Layer):
          A point feature class or layer from which addresses are returned based
          on the features' point location.
      in_address_locator (Address Locator):
          The address locator to use to reverse geocode the input feature class
          or layer.
      address_type {String}:
          Specifies whether addresses for the points will be returned as street
          addresses or intersection addresses if the address locator supports
          intersection matching.

          * ADDRESS-Addresses will be returned as street addresses or in the
          format defined by the input address locator. This is the default
          option.

          * INTERSECTION-Addresses will be returned as intersection addresses.
          This option is available if the address locator supports matching
          intersection addresses.
      search_distance (Linear Unit):
          The distance used to search for the nearest address or intersection
          for the point location. Some locators use optimized distance values
          that do not support overriding the search distance parameter. Locators
          created with the Create Address Locator tool have a default search
          distance of 100 meters.
      feature_type {String}:
          Specifies the possible match types returned. A single value or
          multiple values can be selected. If a single value is selected, the
          search tolerance for the input feature type is 500 meters. If multiple
          values are included, the default search distances specified in the
          feature type hierarchy table are applied. See the REST API web help
          for more details about the featureTypes parameter for
          reverseGeocode.This parameter is not supported for all locators.

          * POINT_ADDRESS-The match is limited to a street address based on
          points that represent house and building locations.

          * PARCEL-The match is limited to a plot of land that is considered
          real property and can include one or more homes or other structures.
          This match type typically has an address and a parcel identification
          number assigned to it.

          * STREET_ADDRESS-The match is limited to a street address that differs
          from POINT_ADDRESS because the house number is interpolated from a
          range of numbers. STREET_ADDRESS matches include the house number
          range for the matching street segment rather than the interpolated
          house number value.

          * STREET_INTERSECTION-The match is limited to a street address
          consisting of a street intersection along with city and optional state
          and postal code information. This is derived from STREET_ADDRESS
          reference data, for example, Redlands Blvd & New York St, Redlands,
          CA, 92373.

          * STREET_NAME-The match is limited to a street address similar to
          STREET_ADDRESS but without house numbers along with administrative
          divisions and optional postal code, for example, W Olive Ave,
          Redlands, CA, 92373 .

          * LOCALITY-The match is limited to a place-name representing a
          populated place.

          * POSTAL-The match is limited to a postal code. Reference data is
          postal code points, for example, 90210 USA.

          * POINT_OF_INTEREST-The match is limited to a point of interest.
          Reference data consists of administrative division place-names,
          businesses, landmarks, and geographic features, for example,
          Starbucks.

          * DISTANCE_MARKER-The match is limited to a street address that
          represents the linear distance along a street, typically in kilometers
          or miles, from a designated origin location, for example, Mile 25 I-5
          N, San Diego, CA.
      location_type {String}:
          Specifies the preferred output geometry for POINT_ADDRESS matches. The
          options for this parameter are ROUTING_LOCATION, the side of street
          location, which can be used for routing, or ADDRESS_LOCATION, the
          location that represents the rooftop, parcel centroid for the address,
          or front door. If the preferred location does not exist in the data,
          the default location of ROUTING_LOCATION will be returned instead. For
          geocode results with Addr_type = "PointAddress", the x,y attribute
          values describe the coordinates of the address along the street, while
          the DisplayX and DisplayY values describe the rooftop or building
          centroid coordinates. See the REST API web help for more details about
          the locationType parameter for reverseGeocode.This parameter is not
          supported for all locators.

          * ADDRESS_LOCATION-Geometry for geocode results that represent an
          address location such as rooftop, building centroid, or front door is
          returned.

          * ROUTING_LOCATION-Geometry for geocode results that represent a
          location close to the side of the street, which can be used for
          vehicle routing, is returned. This is the default.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReverseGeocode_geocoding(*gp_fixargs((in_features, in_address_locator, out_feature_class, address_type, search_distance, feature_type, location_type), True)))
        return retval
    except Exception as e:
        raise e


# Legacy toolset
@gptooldoc('CreateAddressLocator_geocoding', None)
def CreateAddressLocator(in_address_locator_style=None, in_reference_data=None, in_field_map=None, out_address_locator=None, config_keyword=None, enable_suggestions=None):
    """CreateAddressLocator_geocoding(in_address_locator_style, in_reference_data;in_reference_data..., in_field_map, out_address_locator, {config_keyword}, {enable_suggestions})

        Creates an address locator. The address locator can be used to find
        the location of an address, geocode a table of addresses, or get the
        address of a point location.ArcGIS Pro 2.6 is the last release that
        will support the Create
        Address Locator tool. The next major release after ArcGIS Pro 2.6 will
        no longer support building locators with this tool. It is recommended
        that you prepare for this change by using the Create Locator tool to
        build locators.

     INPUTS:
      in_address_locator_style (Address Locator Style):
          The address locator style on which to base the new address locator.

          * US Address-Dual Ranges-Use when the reference data is a line feature
          class that contains house number ranges on both sides of a street
          segment, and you want to search for an address on a specific side of
          the street or a street intersection.

          * US Address-One Range-Use when the reference data is a line feature
          class with one house number range for each road segment, and you want
          to search for an address (where side is not needed) or a street
          intersection.

          * US Address-Single House-Use when the reference data is a point or
          polygon feature class where each feature represents a single address,
          and you want to search for an exact address for a parcel, building, or
          address point.

          * US Address-Single House Subadress-Use when the reference data is a
          point or polygon feature class where each feature represents a single
          address with optional subaddress elements, and you want to search for
          apartment units, townhouses, duplexes, or stores in a shopping plaza.

          * US Address-Streen Name-Use when the reference data is a line feature
          class, and you want to search for addresses using only the street
          name. Address range information is not required.

          * US Address-City State-Use when the reference data is a point or
          polygon feature class, and you want to search for a specific city in a
          state.

          * US Address-ZIP 5 Digit-Use when the reference data is a point or
          polygon feature class where each feature represents a ZIP Code
          centroid or geographic area, and you want to search for a specific ZIP
          Code location.

          * General-Gazetteer-Use when the reference data is a point or polygon
          feature class where each feature represents any unique feature, and
          you want to search for a place-name, landmark, water meter, or any
          unique value.
      in_reference_data (Value Table):
          The reference data feature classes and tables, along with their
          roles, to be used by the address locator.

          * Primary table-Defines the primary reference dataset feature class
          for a locator, such as a street centerline feature class. This is a
          required table.

          * Alternate City Name table-Defines an alternate city name table that
          contains alternate names for the city or place-name. The table is
          required to have a JoinID that can be used to join to the primary
          table. This table is optional

          * Alternate Name table-Defines an alternate street name table that
          contains alternate names for the street or point features. The table
          is required to have a JoinID that can be used to join to the primary
          table. This table is optional.

          * Alias table-Defines a place-name alias table that contains place-
          names and actual addresses for the names. Users can find the location
          using either the place-name, such as Field Museum, or the address,
          such as 1400 S Lakeshore Drive Chicago, IL 60605. This table is
          optional.
          Feature classes and tables represented as services are not supported
          data types for use as reference data.Custom locator styles or locator
          styles provided by third parties may
          define a different set of roles for reference datasets.When creating a
          locator with reference data that contains millions of
          features, you must have at least three to four times the size of the
          data in free disk space on the drive containing your temp directory,
          as files used to build the locator are written to this location before
          the locator is copied to the output location. If you do not have
          enough disk space, the tool will fail when it runs out of space. Also,
          when creating large locators, your machine must have enough RAM to
          handle large memory-intensive processes.
      in_field_map (Field Info):
          The mapping of reference data fields used by the address locator style
          to fields in the reference datasets. Each field mapping in this
          parameter is in the following format:# <locator field alias> <dataset
          field name> # This shows as an
          example: reference_data_field_map = ''' "'Feature ID' FeatureID;'*From
          Left' L_F_ADD; '*To Left' L_T_ADD;'*From Right' R_F_ADD; '*To Right'
          R_T_ADD;'Prefix Direction' PREFIX; 'Prefix Type' PRE_TYPE;'*Street
          Name' NAME; 'Suffix Type' TYPE;'Suffix Direction' SUFFIX; 'Left City
          or Place' CITYL;'Right City or Place' CITYR;'Left ZIP Code'
          ZIPL;'Right ZIP Code' ZIPR;'Left State' State_Abbr;'Right State'
          State_Abbr" '''where <locator field alias> is the alias name for the
          reference data
          field used by the address locator, and <dataset field name> is the
          name of the field in the reference dataset. Fields with an asterisk
          (*) next to their names are required by the address locator style.If
          you choose not to map an optional reference data field used by the
          address locator style to a field in a reference dataset, specify that
          there is no mapping by using <None> in place of a field name.To
          determine the alias name for a reference data field used by a
          locator style, open the Create Address Locator tool and choose the
          locator style. The name that appears in the Field Name column of the
          Field Map parameter is the field's alias name.
      config_keyword {String}:
          This parameter has no effect in ArcGIS Pro. It remains to support
          backward compatibility.
      enable_suggestions {Boolean}:
          Specifies whether character-by-character autocomplete suggestions will
          be generated for user input in a client application. This capability
          facilitates the interactive search user experience by reducing the
          number of characters that must be typed before a suggested match is
          obtained. The idea is that a client application can provide a list of
          suggestions that is updated with each character entered by a user
          until the place they are looking for is returned in the list.Only the
          locator styles provided by Esri can be used to build locators
          with suggestions enabled. The suggestion functionality is only exposed
          when such a locator is shared to your portal.

          * ENABLED-Suggestions are enabled for the locator.

          * DISABLED-Suggestions are not enabled for the locator. This is the
          default.

     OUTPUTS:
      out_address_locator (Address Locator):
          The locator to create in a file folder. Saving the locator to a file
          folder allows you to take advantage of performance improvements,
          multithreading capabilities, and suggestions support. Once the locator
          is created, additional properties and options can be modified in the
          locator's settings."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateAddressLocator_geocoding(*gp_fixargs((in_address_locator_style, in_reference_data, in_field_map, out_address_locator, config_keyword, enable_suggestions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StandardizeAddresses_geocoding', None)
def StandardizeAddresses(in_address_data=None, in_input_address_fields=None, in_address_locator_style=None, in_output_address_fields=None, out_address_data=None, in_relationship_type=None):
    """StandardizeAddresses_geocoding(in_address_data, in_input_address_fields;in_input_address_fields..., in_address_locator_style, in_output_address_fields;in_output_address_fields..., out_address_data, {in_relationship_type})

        Standardizes the address information in a table or feature
        class.Standardizing the address components in your reference data into
        multiple address fields was a necessary step before building an
        address locator prior to ArcGIS Desktop 10.0. This step is no longer
        required because the standardization process occurs when the address
        locator is built regardless of whether the address components are
        stored in a single field or split across multiple fields.
        Standardizing the reference data and normalizing abbreviations and
        periods is not recommended at ArcGIS Desktop 10.0 and later because
        they will not improve geocoding performance or quality and they are
        now done during the geocoding process.Addresses are often presented in
        different forms that may contain
        various abbreviations of words, such as W for WEST or ST for STREET.
        Based on an address style you select, the address can be split into
        multiple parts, such as House Number, Prefix Direction, Prefix Type,
        Street Name Suffix Type, Unit Type, and Unit Number. The address style
        specifies the components of an address and determines how the
        components are ordered and standardized; however, there is no
        guarantee how the data will be standardized based on the logic in the
        address locator style and the input data. Depending on the
        application, some address styles may expand the value of a word
        instead of abbreviating it.The input address you want to standardize
        can be stored in a single
        field. If the address information has already been split into multiple
        fields in the input feature class or table, this tool can concatenate
        the fields on the fly and standardize the information.

     INPUTS:
      in_address_data (Table View):
          The table or feature class containing address information that you
          want to standardize.
      in_input_address_fields (String):
          The set of fields in the input table or feature class that, when
          concatenated, forms the address to be standardized.
      in_address_locator_style (Address Locator Style):
          The address locator style to use to standardize the address
          information in the input table or feature class.
      in_output_address_fields (String):
          The set of standardized address fields to include in the output table
          or feature class.
      in_relationship_type {Boolean}:
          Indicates whether to create a static or dynamic output dataset.

          * Static-Creates an output table or feature class that contains a copy
          of the rows or features in the input table and the standardized
          address fields. This is the default.

          * Dynamic-Creates a table containing the standardized address
          fields and a relationship class that joins to the input table or
          feature class. The option is only supported if both the input
          and output datasets are
          stored in the same geodatabase workspace.

     OUTPUTS:
      out_address_data (Dataset):
          The output table or feature class to create containing the
          standardized address fields."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StandardizeAddresses_geocoding(*gp_fixargs((in_address_data, in_input_address_fields, in_address_locator_style, in_output_address_fields, out_address_data, in_relationship_type), True)))
        return retval
    except Exception as e:
        raise e


# Portal toolset
@gptooldoc('GeocodeFile_geocoding', None)
def GeocodeFile(in_table=None, locator=None, address_fields=None, output_type=None, output_location=None, output_name=None, country=None, location_type=None, category=None):
    """GeocodeFile_geocoding(in_table, locator, address_fields, output_type, output_location, output_name, {country;country...}, {location_type}, {category;category...})

        Converts large local tables of addresses or places into points in a
        feature class or as a stand-alone .csv or .xls table. This tool uses
        locators hosted on an ArcGIS Enterprise portal.This tool is designed
        to work in ArcGIS Pro 2.4 or later in
        conjunction with an ArcGIS Enterprise 10.7 or later portal.

     INPUTS:
      in_table (Record Set):
          The input table that contains addresses or places to geocode in CSV,
          XLS, or XLSX format, or a file geodatabase table.
      locator (Address Locator):
          The portal locator that will be used to geocode the table.A populated
          list of locators is on the active portal. You can select a
          locator from this list or browse the active portal for other available
          locators. Locators that have been set as utility services on the
          active portal will be available by default.The ArcGIS World Geocoding
          Service is disabled for this tool. Use the
          Geocode Addresses tool if you want to use the ArcGIS World Geocoding
          Service.
      address_fields (Field Info):
          Each field mapping in this parameter is in the format
          input_locator_field, table_field_name where input_locator_field is the
          name of the input address field specified by the locator, and
          table_field_name is the name of the corresponding field in the table
          of addresses you want to geocode.You can specify a single input field
          that stores the complete address,
          for example, 303 Peachtree St NE, Atlanta, GA 30308. Alternatively,
          you can specify multiple fields if the input addresses are divided
          into multiple fields such as Address, City, State, and ZIP for a
          general United States address.Some locators support multiple input
          addresses fields such as Address,
          Address2, and Address3. In this case, the address component can be
          separated into multiple fields and the address fields will be
          concatenated at the time of geocoding. For example, 100, Main St, Apt
          140 across three fields or 100 Main St and Apt 140 across two fields
          would both become 100 Main St Apt 140 when geocoding.If you choose not
          to map an optional input address field used by the
          locator to a field in the input table of addresses, specify that there
          is no mapping using <None> in place of a field name.
      output_type (String):
          The file type to which the geocode results will be written.

          * CSV-Returns a comma-separated values file.

          * FEATURE_CLASS-Returns a feature class in a file geodatabase.

          * XLS-Returns a Microsoft Excel file (.xls).
      output_location (Workspace):
          The folder where the output geocoding results will be written.If the
          output is a .csv or .xls file, an output file will be placed in
          the specified folder.If the output is a feature class, an output file
          geodatabase will be
          created and placed in the specified folder, and the new file
          geodatabase will contain the geocoded feature class. The output file
          geodatabase and feature class in the file geodatabase will have the
          same name.
      output_name (String):
          The name of the output geocoded results.
      country {String}:
          The country or countries to search for the geocoded addresses. This
          parameter is available for locators that support a country parameter
          and will limit geocoding to the selected countries. Making a country
          selection will improve the accuracy of geocoding in most cases. If a
          field representing countries in the Input Table parameter is mapped to
          the Country Role: Field Name, the country value from the Input Table
          parameter will override the Country parameter.If no country is
          specified, geocoding is performed on all supported
          countries of the locator. The input value should be specified as an
          ISO 3166-1 3-character country code.The Country parameter is not
          supported for all locators.
      location_type {String}:
          Specifies the preferred output geometry for POINT_ADDRESS matches. The
          options for this parameter are ROUTING_LOCATION, the side of street
          location that can be used for routing, or ADDRESS_LOCATION, the
          location that represents the rooftop, parcel centroid for the address,
          or front door. If the preferred location does not exist in the data,
          the default location of ROUTING_LOCATION will be returned instead. For
          geocode results with Addr_type=PointAddress, the x,y attribute values
          describe the coordinates of the address along the street, while the
          DisplayX and DisplayY values describe the rooftop or building centroid
          coordinates. See the REST API web help for details about the
          locationType parameter for reverseGeocode.This parameter is not
          supported for all locators.

          * ADDRESS_LOCATION-Returns geometry for geocode results that represent
          an address location such as a rooftop location, parcel centroid, or
          front door.

          * ROUTING_LOCATION-Returns geometry for geocode results that represent
          a location close to the side of the street that can be used for
          vehicle routing. This is the default.
      category {String}:
          Limits the types of places the locator searches, eliminating
          false positive matches and potentially speeding up the search process.
          When no category is used, geocoding is performed on all supported
          categories. Not all category values are supported for all locations
          and countries. In general, the Category parameter can be used for the
          following:

          * Limit matches to specific place types or address levels

          * Avoid fallback matches to unwanted address levels

          * Disambiguate coordinate searches
          This parameter is not supported for all locators.See the REST API web
          help for details about category filtering."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeocodeFile_geocoding(*gp_fixargs((in_table, locator, address_fields, output_type, output_location, output_name, country, location_type, category), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeocodeLocationsFromTable_geocoding', None)
def GeocodeLocationsFromTable(in_table=None, in_address_locator=None, address_fields=None, output_name=None, country=None, location_type=None, category=None):
    """GeocodeLocationsFromTable_geocoding(in_table, in_address_locator, address_fields, output_name, {country;country...}, {location_type}, {category;category...})

        Geocodes hosted tables using locators hosted on an ArcGIS Enterprise
        portal, which creates a hosted feature layer containing the geocoded
        results.This tool is designed to automate the process of geocoding
        tables
        published to the portal and saving the output to the portal. If you
        are not interested in saving the geocode results to the portal, use
        the Geocode Table pane or the Geocode Addresses tool.This tool
        requires that you have publisher or administrator privileges
        on the portal. If you are a member of a custom role, be sure the
        portal administrator has granted you the Publish hosted web layers
        privilege.

     INPUTS:
      in_table (Record Set):
          The table on the portal that contains addresses or places to geocode.
      in_address_locator (Address Locator):
          The portal locator that will be used to geocode the input table from
          the portal.A populated list of locators on the active portal. You can
          select a
          locator from this list or browse the active portal for other available
          locators. Locators that have been set as utility services in the
          active portal will be available by default. If the portal locator you
          want to use is not in the populated list, ask your portal
          administrator to add the locator as a portal utility service, and
          configure the locator for batch geocoding.The ArcGIS World Geocoding
          Service is disabled for this tool. Use the
          Geocode Addresses tool if you want to use the ArcGIS World Geocoding
          Service.
      address_fields (Field Info):
          Each field mapping in this parameter is in the format
          input_locator_field, table_field_name where input_locator_field is the
          name of the input address field specified by the locator, and
          table_field_name is the name of the corresponding field in the table
          of addresses you want to geocode.You can specify one single input
          field that stores the complete
          address, for example, 303 Peachtree St NE, Atlanta, GA 30308.
          Alternatively, you can specify multiple fields if the input addresses
          are split into multiple fields such as Address, City, State, and ZIP
          for a general United States address.Some locators support multiple
          input address fields such as Address,
          Address2, and Address3. In this case, the address component can be
          separated into multiple fields and the address fields will be
          concatenated together at the time of geocoding. For example, 100, Main
          St, and Apt 140 across three fields or 100 Main St and Apt 140 across
          two fields would both become 100 Main St Apt 140 when geocoding.If you
          choose not to map an optional input address field used by the
          locator to a field in the input table of addresses, specify that there
          is no mapping by using <None> in place of a field name.
      output_name (String):
          The name of the output geocoded feature layer that will be created on
          the portal.
      country {String}:
          The country or countries to search for the geocoded addresses. This
          parameter is available for locators that support a country parameter
          and will limit geocoding to the selected countries. Making a country
          selection will improve the accuracy of geocoding in most cases. If a
          field representing countries in the Input Table is mapped to the
          Country Input Address Field, the country value from the Input Table
          will override the Country parameter.If no country is specified,
          geocoding is performed against all
          supported countries of the locator. The input value should be
          specified as ISO 3166-1 3-character country codes.Country is not
          supported for all locators.
      location_type {String}:
          Specifies the preferred output geometry for POINT_ADDRESS matches. The
          options for this parameter are ROUTING_LOCATION, the side of street
          location that can be used for routing, or ADDRESS_LOCATION, the
          location that represents the rooftop, parcel centroid for the address,
          or front door. If the preferred location does not exist in the data,
          the default location of ROUTING_LOCATION will be returned instead. For
          geocode results with Addr_type=PointAddress, the x,y attribute values
          describe the coordinates of the address along the street, while the
          DisplayX and DisplayY values describe the rooftop or building centroid
          coordinates. See the REST API web help for details about the
          locationType parameter for reverseGeocode.This parameter is not
          supported for all locators.

          * ADDRESS_LOCATION-Returns geometry for geocode results that represent
          an address location such as a rooftop location, parcel centroid, or
          front door.

          * ROUTING_LOCATION-Returns geometry for geocode results that represent
          a location close to the side of the street that can be used for
          vehicle routing. This is the default.
      category {String}:
          Limits the types of places the locator searches, thus
          eliminating false positive matches and potentially speeding up the
          search process. When no category is used, geocoding is performed
          against all supported categories. Not all category values are
          supported for all locations and countries. In general, the Category
          parameter can be used for the following:

          * Limit matches to specific place types or address levels

          * Avoid fallback matches to unwanted address levels

          * Disambiguate coordinate searches
          This parameter is not supported for all locators.See the REST API web
          help for details about category filtering."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeocodeLocationsFromTable_geocoding(*gp_fixargs((in_table, in_address_locator, address_fields, output_name, country, location_type, category), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject