# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Intelligence Tools"""
__all__ = ['BatchImportData', 'CompareAreas', 'DOFToObstacleFeatures',
           'DistanceFromPoint', 'DistanceFromPoints', 'DropZones',
           'FindCotravelers', 'FindMeetingLocations', 'FindOverlaps',
           'GenerateBlindSpotAreas', 'GenerateCoverageAreas',
           'GenerateHLZSuitability', 'GenerateObstacleFeatures',
           'InsideBoundary', 'LeastCostPath', 'OutsideBoundary',
           'PointClustering', 'PointToPoint', 'PointsToTrackSegments',
           'WithinDistanceOfBoundary', 'WithinDistanceOfLine']
__alias__ = 'intelligence'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Alerts toolset
@gptooldoc('DistanceFromPoint_intelligence', None)
def DistanceFromPoint(input_point_features=None, input_coordinate_type=None, input_coordinate_string=None, input_search_distance=None, input_search_expression=None):
    """DistanceFromPoint_intelligence(input_point_features, input_coordinate_type, input_coordinate_string, input_search_distance, {input_search_expression})

        Find like entities within distance from an location.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_coordinate_type (String):
          Coordinate Type
      input_coordinate_string (String):
          Coordinate Location
      input_search_distance (Linear Unit):
          Distance
      input_search_expression {SQL Expression}:
          Input Search Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DistanceFromPoint_intelligence(*gp_fixargs((input_point_features, input_coordinate_type, input_coordinate_string, input_search_distance, input_search_expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DistanceFromPoints_intelligence', None)
def DistanceFromPoints(input_point_features=None, source_point_features=None, input_search_distance=None, input_search_expression=None):
    """DistanceFromPoints_intelligence(input_point_features, source_point_features, input_search_distance, {input_search_expression})

        Find like entities within distance from an location.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      source_point_features (Feature Layer):
          Source Points
      input_search_distance (Linear Unit):
          Distance
      input_search_expression {SQL Expression}:
          Input Search Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DistanceFromPoints_intelligence(*gp_fixargs((input_point_features, source_point_features, input_search_distance, input_search_expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('InsideBoundary_intelligence', None)
def InsideBoundary(input_point_features=None, input_area_features=None, input_search_expression=None, input_area_expression=None):
    """InsideBoundary_intelligence(input_point_features, input_area_features, {input_search_expression}, {input_area_expression})

        Find like entities within specified boundary feature.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_area_features (Feature Layer):
          Input Area
      input_search_expression {SQL Expression}:
          Input Search Expression
      input_area_expression {SQL Expression}:
          Input Area Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.InsideBoundary_intelligence(*gp_fixargs((input_point_features, input_area_features, input_search_expression, input_area_expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OutsideBoundary_intelligence', None)
def OutsideBoundary(input_point_features=None, input_area_features=None, input_search_expression=None, input_area_expression=None):
    """OutsideBoundary_intelligence(input_point_features, input_area_features, {input_search_expression}, {input_area_expression})

        Entities outside given boundary.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_area_features (Feature Layer):
          Input Areas
      input_search_expression {SQL Expression}:
          Input Search Expression
      input_area_expression {SQL Expression}:
          Input Area Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OutsideBoundary_intelligence(*gp_fixargs((input_point_features, input_area_features, input_search_expression, input_area_expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PointClustering_intelligence', None)
def PointClustering(input_point_features=None, input_search_distance=None, minimum_features_cluster=None):
    """PointClustering_intelligence(input_point_features, {input_search_distance}, {minimum_features_cluster})

        Find clusters of point features.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_search_distance {Linear Unit}:
          Distance
      minimum_features_cluster {Long}:
          Minimum Features Per Cluster"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PointClustering_intelligence(*gp_fixargs((input_point_features, input_search_distance, minimum_features_cluster), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PointToPoint_intelligence', None)
def PointToPoint(input_point_features=None, input_search_distance=None, input_search_expression=None):
    """PointToPoint_intelligence(input_point_features, input_search_distance, {input_search_expression})

        Find like entities within a distance of each other.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_search_distance (Linear Unit):
          Distance
      input_search_expression {SQL Expression}:
          Input Search Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PointToPoint_intelligence(*gp_fixargs((input_point_features, input_search_distance, input_search_expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('WithinDistanceOfBoundary_intelligence', None)
def WithinDistanceOfBoundary(input_point_features=None, input_area_features=None, input_distance=None, input_search_expression=None, input_area_expression=None):
    """WithinDistanceOfBoundary_intelligence(input_point_features, input_area_features, input_distance, {input_search_expression}, {input_area_expression})

        Entities within distance of given boundary.

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_area_features (Feature Layer):
          Input Areas
      input_distance (Linear Unit):
          Distance
      input_search_expression {SQL Expression}:
          Input Search Expression
      input_area_expression {SQL Expression}:
          Input Area Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.WithinDistanceOfBoundary_intelligence(*gp_fixargs((input_point_features, input_area_features, input_distance, input_search_expression, input_area_expression), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('WithinDistanceOfLine_intelligence', None)
def WithinDistanceOfLine(input_point_features=None, input_linear_features=None, input_distance=None, input_search_expression=None, input_linear_expression=None):
    """WithinDistanceOfLine_intelligence(input_point_features, input_linear_features, input_distance, {input_search_expression}, {input_linear_expression})

        Entities near or along linear features

     INPUTS:
      input_point_features (Feature Layer):
          Input Points
      input_linear_features (Feature Layer):
          Input Lines
      input_distance (Linear Unit):
          Distance
      input_search_expression {SQL Expression}:
          Input Search Expression
      input_linear_expression {SQL Expression}:
          Input Line Expression"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.WithinDistanceOfLine_intelligence(*gp_fixargs((input_point_features, input_linear_features, input_distance, input_search_expression, input_linear_expression), True)))
        return retval
    except Exception as e:
        raise e


# Analysis toolset
@gptooldoc('FindOverlaps_intelligence', None)
def FindOverlaps(in_features=None, out_intersection=None, out_centroid=None, group_field=None):
    """FindOverlaps_intelligence(in_features, out_intersection, out_centroid, {group_field})

        Finds overlapping areas in a feature class and provides a count for
        the number of overlaps.

     INPUTS:
      in_features (Feature Layer):
          The input polygon features for which overlaps will be computed.
      group_field {Field}:
          The Input Features group field.

     OUTPUTS:
      out_intersection (Feature Class):
          The output intersection areas.
      out_centroid (Feature Class):
          The output centroid locations of the Output Intersections features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindOverlaps_intelligence(*gp_fixargs((in_features, out_intersection, out_centroid, group_field), True)))
        return retval
    except Exception as e:
        raise e


# Analysis\Blind Spot toolset
@gptooldoc('GenerateBlindSpotAreas_intelligence', None)
def GenerateBlindSpotAreas(in_features=None, out_feature_class=None, clip_features=None, start_time_field=None, end_time_field=None):
    """GenerateBlindSpotAreas_intelligence(in_features, out_feature_class, {clip_features}, {start_time_field}, {end_time_field})

        Creates an output nonvisible area, or blind spot, for input
        Intelligence, Surveillance, Reconnaissance (ISR) or patrol visible
        buffer features based on start and end times. The output blind spot
        layer is used with the time slider to visualize and explore areas that
        are not visible to ISR or patrol assets at specified times.

     INPUTS:
      in_features (Feature Layer):
          The input visible buffer features.
      clip_features {Feature Set}:
          The features used to define the input boundary.
      start_time_field {Field}:
          The field containing the start date and time when the asset is
          available.
      end_time_field {Field}:
          The field containing the end date and time when the asset is no longer
          available.

     OUTPUTS:
      out_feature_class (Feature Layer):
          The output blind spot area features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateBlindSpotAreas_intelligence(*gp_fixargs((in_features, out_feature_class, clip_features, start_time_field, end_time_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateCoverageAreas_intelligence', None)
def GenerateCoverageAreas(in_features=None, out_feature_class=None, buffer_type=None, range_unit=None, start_time_field=None, end_time_field=None):
    """GenerateCoverageAreas_intelligence(in_features, out_feature_class, buffer_type, {range_unit}, {start_time_field}, {end_time_field})

        Creates a proximity buffer for input Intelligence, Surveillance, and
        Reconnaissance (ISR) or patrol assets for use in the Generate Blind
        Spot Areas tool.

     INPUTS:
      in_features (Feature Layer):
          The input asset features.
      buffer_type (Linear Unit / Field):
          The distance around the input features that will be buffered.
          Distances can be provided as either a value representing a linear
          distance or a field from the input features that defines the
          individual ranges and units to buffer each feature.
      range_unit {String}:
          Specifies a linear unit when the chosen buffer_type parameter value
          does not contain the unit of distance.

          * Meters-The distance unit will be meters.

          * Kilometers-The distance unit will be kilometers.

          * Feet-The distance unit will be feet.

          * Miles-The distance unit will be miles.

          * NauticalMiles-The distance unit will be nautical miles.
      start_time_field {Field}:
          The field containing the start date and time the asset is available.
      end_time_field {Field}:
          The field containing the end date and time the asset is no longer
          available.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output blind spot buffer features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateCoverageAreas_intelligence(*gp_fixargs((in_features, out_feature_class, buffer_type, range_unit, start_time_field, end_time_field), True)))
        return retval
    except Exception as e:
        raise e


# Analysis\Suitability toolset
@gptooldoc('DOFToObstacleFeatures_intelligence', None)
def DOFToObstacleFeatures(in_table=None, out_obstacle_features=None, out_obstacle_buffers=None, clip_features=None):
    """DOFToObstacleFeatures_intelligence(in_table, out_obstacle_features, out_obstacle_buffers, {clip_features})

        Converts the U.S. Federal Aviation Administration (FAA) Digital
        Obstacle File (DOF) to obstruction points and obstruction buffer
        features.

     INPUTS:
      in_table (Table View):
          The input DOF table to convert into obstacle features.
      clip_features {Feature Layer}:
          An area to clip from the Input Table. Only obstacles within this area
          will be created and buffered.

     OUTPUTS:
      out_obstacle_features (Feature Class):
          The point obstacle features created from the Input Table.
      out_obstacle_buffers (Feature Class):
          The distance buffers created at 10 times the value of the AGL field in
          the Input Table."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DOFToObstacleFeatures_intelligence(*gp_fixargs((in_table, out_obstacle_features, out_obstacle_buffers, clip_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DropZones_intelligence', None)
def DropZones(in_slope_raster=None, in_vegetation_features=None, clip_features=None, out_feature_class=None):
    """DropZones_intelligence(in_slope_raster, in_vegetation_features, clip_features, out_feature_class)

        Identifies drop zone locations suitable for parachuting equipment or
        personnel within a designated area of interest given slope and
        vegetation data.

     INPUTS:
      in_slope_raster (Raster Layer):
          The slope raster percentage used to determine the slope component of
          DZ suitability.
      in_vegetation_features (Feature Layer):
          The features that define the combined vegetation and land cover types.
          These features are used to find areas with suitable vegetation
          coverage for DZs.
      clip_features (Feature Set):
          The area within which to find suitable DZs.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class showing terrain suitability for DZs."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DropZones_intelligence(*gp_fixargs((in_slope_raster, in_vegetation_features, clip_features, out_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateHLZSuitability_intelligence', None)
def GenerateHLZSuitability(in_slope_raster=None, in_land_cover_raster=None, in_obstacle_buffer_features=None, out_raster=None):
    """GenerateHLZSuitability_intelligence(in_slope_raster, in_land_cover_raster, in_obstacle_buffer_features, out_raster)

        Creates a helicopter landing zone (HLZ) suitability raster layer from
        reclassified slope, reclassified land cover, and obstacle buffers.

     INPUTS:
      in_slope_raster (Raster Layer):
          The reclassified slope raster with values 1 (acceptable) and 2
          (acceptable with caution). All other values will be excluded from the
          analysis.
      in_land_cover_raster (Raster Layer):
          The reclassified land cover raster with values 1 (acceptable) and 2
          (acceptable with caution). All other values will be excluded from the
          analysis.
      in_obstacle_buffer_features (Feature Layer):
          Obstacle area features representing approach and departure safety
          buffers around obstacles.

     OUTPUTS:
      out_raster (Raster Dataset):
          The output raster dataset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateHLZSuitability_intelligence(*gp_fixargs((in_slope_raster, in_land_cover_raster, in_obstacle_buffer_features, out_raster), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateObstacleFeatures_intelligence', None)
def GenerateObstacleFeatures(in_features=None, height_field=None, out_obstacle_features=None, out_obstacle_buffers=None, clip_features=None):
    """GenerateObstacleFeatures_intelligence(in_features, height_field, out_obstacle_features, out_obstacle_buffers, {clip_features})

        Converts features with a height field to a 3D obstacle feature and an
        obstacle restriction buffer for use in evaluating helicopter landing
        zones.

     INPUTS:
      in_features (Feature Layer):
          The input source features used to create obstacle features.
      height_field (Field):
          A field from the Input Features parameter containing height values.
          The field type can be numeric or text. If a text field is used, the
          field values must be numeric.
      clip_features {Feature Layer}:
          An area to clip the Output Obstacle Features. Only features within the
          Clip Features will be processed.

     OUTPUTS:
      out_obstacle_features (Feature Class):
          The output 3D obstacle features.
      out_obstacle_buffers (Feature Class):
          The output obstacle buffer features"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateObstacleFeatures_intelligence(*gp_fixargs((in_features, height_field, out_obstacle_features, out_obstacle_buffers, clip_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LeastCostPath_intelligence', None)
def LeastCostPath(in_cost_surface=None, in_start_point=None, in_end_point=None, out_path_feature_class=None, handle_zeros=None):
    """LeastCostPath_intelligence(in_cost_surface, in_start_point, in_end_point, out_path_feature_class, {handle_zeros})

        Finds the shortest path between starting points and ending points
        across a cost surface.

     INPUTS:
      in_cost_surface (Raster Layer):
          The input raster used to determine the cost to travel from starting
          point to ending point. No Data values cannot be crossed.
      in_start_point (Feature Set):
          The input starting point feature. Multiple start points will
          significantly increase processing time.
      in_end_point (Feature Set):
          The input ending point feature. Multiple end points will increase the
          number of output lines, as the resulting path will branch into
          separate paths.
      handle_zeros {String}:
          Specifies how zero values in the Input Cost Surface parameter
          (in_cost_surface parameter in Python) will be handled.

          * SMALL_POSITIVE-All zeros will be changed to a small positive value.
          This will allow these cells to be traversed. This is the default.

          * NO_DATA-All zeros will be changed to null values. These cells will
          not be traversed and will be avoided.

     OUTPUTS:
      out_path_feature_class (Feature Class):
          The output path feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LeastCostPath_intelligence(*gp_fixargs((in_cost_surface, in_start_point, in_end_point, out_path_feature_class, handle_zeros), True)))
        return retval
    except Exception as e:
        raise e


# Conversion toolset
@gptooldoc('BatchImportData_intelligence', None)
def BatchImportData(in_data=None, target_gdb=None, filter=None, include_sub_folders=None):
    """BatchImportData_intelligence(in_data;in_data..., target_gdb, {filter}, {include_sub_folders})

        Imports directories of KML, KMZ, shapefiles, Excel worksheets, tabular
        text files, GeoJSON, and GPX files to feature classes stored in a
        single geodatabase.

     INPUTS:
      in_data (Folder):
          The directories containing the data files to convert to geodatabase
          feature classes.
      target_gdb (Workspace):
          The target geodatabase where output feature classes will be stored.
      filter {String}:
          A filter for the data being added to the geodatabase. The
          wildcard characters for the filter work on the full path to the input
          data and are listed below:Multiple patterns can be added to the filter
          by separating each pattern with the vertical bar/pipe delimiter (|);
          no spaces should exist before or after the delimiter. Pattern
          comparisons are not case sensitive, so using the *airport.shp,
          *AIRPORT.SHP, or *Airport.shp pattern will import the same shapefile.

          * *-Matches any characters

          * ?-Matches a single character

          * [ range ]-Matches a single character in the range

          * [! range ]-Matches any character not in the range
                 The following are filter examples:

          * To import all shapefiles, use *.shp.

          * To import all shapefiles and all KML files, use *.shp|*.kml.

          * To import all files that have airport in the file path or file name,
          use *airport*.

          * To import all GeoJSON files that have airport in the file path or
          file name, use *airport*.geojson.

          * To import all KMZ files that have airport appended with any two
          characters in the name, use *airport??.kmz.

          * To import all files that have 1990 through 1997 in the file path or
          file name, use *199[0-7]*.

          * To import all shapefiles that have the exact folder name
          airfacilities in their file path, use *\\airfacilities\\*.shp.
      include_sub_folders {Boolean}:
          Specifies whether subfolders will be recursively explored.

          * SUBFOLDERS-All subfolders will be explored This is the default.

          * NO_SUBFOLDERS-Only the top-level folder will be explored."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.BatchImportData_intelligence(*gp_fixargs((in_data, target_gdb, filter, include_sub_folders), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PointsToTrackSegments_intelligence', None)
def PointsToTrackSegments(in_features=None, date_field=None, out_feature_class=None, group_field=None, include_velocity=None, out_point_feature_class=None):
    """PointsToTrackSegments_intelligence(in_features, date_field, out_feature_class, {group_field}, {include_velocity}, {out_point_feature_class})

        Converts a series of output paths from time-enabled sequences of input
        point data, such as GPS points.

     INPUTS:
      in_features (Feature Layer):
          Point features as point positions along the tracks to be created.
      date_field (Field):
          The date field used to order the Input Features points.
      group_field {Field}:
          A field from the Input Features used to group the input points. Each
          unique group will create a separate track.
      include_velocity {Boolean}:
          Specifies whether output velocity fields speed_meters_per_second,
          speed_mph, speed_kilometers_per_hour, and speed_knots) will be
          included in the out_feature_class.

          * INCLUDE_VELOCITY-Output velocity fields will be added to the output.
          This is the default.

          * EXCLUDE_VELOCITY-Output velocity fields will not be added to the
          output.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output track line features.
      out_point_feature_class {Feature Class}:
          The output point features. The output will include a SEQUENCE field
          that contains the order used for the path created in the Output
          Feature Class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PointsToTrackSegments_intelligence(*gp_fixargs((in_features, date_field, out_feature_class, group_field, include_velocity, out_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e


# Movement toolset
@gptooldoc('CompareAreas_intelligence', None)
def CompareAreas(in_point_features=None, in_area_features=None, out_featureclass=None, point_id_field=None, area_id_field=None, relationship=None, time_difference=None):
    """CompareAreas_intelligence(in_point_features, in_area_features, out_featureclass, point_id_field, area_id_field, relationship, {time_difference})

        Compares movement point tracks across multiple known areas of
        interest.

     INPUTS:
      in_point_features (Feature Layer):
          The point features representing the movement track points. The layer
          can be time enabled.
      in_area_features (Feature Layer):
          The area features representing the areas of interest that will be used
          to identify unique movement track point identifiers. The layer can be
          time enabled.
      point_id_field (Field):
          The field containing the unique identifiers for the movement track
          points. The field can be either a number or a string.
      area_id_field (Field):
          The field containing the unique identifiers for the areas of interest.
          The field can be either a number or a string.
      relationship (String):
          Specifies the relationship between the inputs.

          * LOCATION_ONLY-Points and area features will be evaluated based on
          spatial co-occurrence.

          * LOCATION_TIME-Points and area features will be evaluated based on
          spatial and temporal co-occurrence.
      time_difference {Time Unit}:
          The time allowed between the in_point_features and in_point_features
          parameter values before a spatial relationship is considered invalid.
          This parameter is enabled when the relationship parameter is set to
          LOCATION_TIME and both inputs are time enabled.

     OUTPUTS:
      out_featureclass (Feature Layer):
          The output area feature class. The output will contain a copy of the
          in_area_features geometry and the unique identifiers from the
          area_id_field and point_id_field parameters.If both the
          in_point_features and in_area_features parameter values
          are time enabled and relationship is set to LOCATION_TIME, only the
          features matching the geometry and the time span will be returned."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CompareAreas_intelligence(*gp_fixargs((in_point_features, in_area_features, out_featureclass, point_id_field, area_id_field, relationship, time_difference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindCotravelers_intelligence', None)
def FindCotravelers(input_features=None, out_featureclass=None, id_field=None, search_distance=None, time_difference=None):
    """FindCotravelers_intelligence(input_features, out_featureclass, id_field, {search_distance}, {time_difference})

        Extracts unique identifiers that are moving through space and time at
        user-defined intervals in a point track dataset.

     INPUTS:
      input_features (Feature Layer):
          The time-enabled features representing the known identifier that will
          be used to find cotravelers. The unique identifiers, time stamps, and
          locations will be transferred to the output layer to assist with
          calculating the time and spatial separation.
      id_field (Field):
          A field from the Input Features that will be used to obtain the unique
          identifiers per point track. The field will be copied to the output
          feature class.
      search_distance {Linear Unit}:
          The maximum distance that can separate features before they are
          considered not to be cotraveling features. The default is 100 meters.
      time_difference {Time Unit}:
          The maximum time difference that can separate features before they are
          considered not to be cotraveling features. The default is 10 minutes.

     OUTPUTS:
      out_featureclass (Feature Class):
          The output feature class that will contain the point track segments
          identified as cotraveling with the input source layers. This feature
          class will include the source with which the specified point track
          segment is associated. Time and spatial separation will be calculated
          for each point track feature. The output will include the following
          fields:

          * traveler_id-The unique identifier for the traveling feature. This is
          the identifier the cotraveling feature was moving with and can be
          considered the source feature.

          * cotraveler_id-The unique identifier for the cotraveling feature.
          This is the identifier that was cotraveling with the traveling feature
          and can be considered the target feature.

          * X-The x-coordinate of the cotraveling feature. The coordinate will
          be in the projection units of the Input Features.

          * Y-The y-coordinate of the cotraveling feature. The coordinate will
          be in the projection units of the Input Features.

          * traveler_time-The date and time of the traveling feature.

          * cotraveler_time-The date and time of the cotraveling feature.

          * distance_difference-The distance between the feature identified in
          the Input Features and the assessed cotraveler. The distance will be
          in the linear units of the Input Features.

          * time_difference-The time separation from the feature identified in
          the Input Features and the assessed cotraveler. The time difference
          will be in seconds and can be a positive or negative number. Positive
          numbers indicate features identified as occurring after the traveler.
          Negative numbers indicate features identified as occurring before the
          traveler."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindCotravelers_intelligence(*gp_fixargs((input_features, out_featureclass, id_field, search_distance, time_difference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindMeetingLocations_intelligence', None)
def FindMeetingLocations(in_features=None, out_area_features=None, out_point_features=None, unique_name_field=None, search_distance=None, minimum_loiter_time=None):
    """FindMeetingLocations_intelligence(in_features, out_area_features, out_point_features, unique_name_field, {search_distance}, {minimum_loiter_time})

        Identifies locations where multiple unique movement tracks have
        dwelled for a defined time period.

     INPUTS:
      in_features (Feature Layer):
          The input movement track points that will be analyzed for possible
          meeting locations. This layer must be time enabled.
      unique_name_field (Field):
          The field containing the unique identifiers for movement track points.
      search_distance {Linear Unit}:
          The maximum search distance a movement track can loiter before it is
          no longer considered part of a meeting. The default is 100 meters.
      minimum_loiter_time {Time Unit}:
          The minimum amount of time a movement track point can loiter in an
          area before it is considered to be dwelling. This helps identify
          possible meeting locations where multiple unique movement tracks are
          dwelling in the same time and space. The default is 10 minutes.

     OUTPUTS:
      out_area_features (Feature Class):
          The output area features that represent the extent of the identified
          meeting location.
      out_point_features (Feature Class):
          The output point features that represent the centroid of the area of
          the individual meeting. Multiple meetings can occur at a given meeting
          location. This feature class contains all of the details regarding the
          individual meetings including participants, duration, and start and
          end times."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindMeetingLocations_intelligence(*gp_fixargs((in_features, out_area_features, out_point_features, unique_name_field, search_distance, minimum_loiter_time), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject