# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Spatial Statistics Tools"""
__all__ = ['AverageNearestNeighbor', 'BuildBalancedZones', 'CalculateAreas',
           'CalculateDistanceBand', 'CentralFeature', 'ClustersOutliers',
           'CollectEvents', 'ColocationAnalysis',
           'ConvertSpatialWeightsMatrixtoTable', 'DensityBasedClustering',
           'DirectionalDistribution', 'DirectionalMean',
           'ExploratoryRegression', 'ExportXYv', 'Forest', 'GWR',
           'GeneralizedLinearRegression', 'GenerateNetworkSWM',
           'GenerateNetworkSpatialWeights', 'GenerateSpatialWeightsMatrix',
           'GeographicallyWeightedRegression', 'GroupingAnalysis',
           'HighLowClustering', 'HotSpots', 'IncrementalSpatialAutocorrelation',
           'LocalBivariateRelationships', 'MeanCenter', 'MedianCenter',
           'MultiDistanceSpatialClustering', 'MultivariateClustering',
           'OptimizedHotSpotAnalysis', 'OptimizedOutlierAnalysis',
           'OrdinaryLeastSquares', 'SimilaritySearch', 'SpatialAutocorrelation',
           'SpatiallyConstrainedMultivariateClustering', 'StandardDistance']
__alias__ = 'stats'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analyzing Patterns toolset
@gptooldoc('AverageNearestNeighbor_stats', None)
def AverageNearestNeighbor(Input_Feature_Class=None, Distance_Method=None, Generate_Report=None, Area=None):
    """AverageNearestNeighbor_stats(Input_Feature_Class, Distance_Method, {Generate_Report}, {Area})

        Calculates a nearest neighbor index based on the average distance from
        each feature to its nearest neighboring feature.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class, typically a point feature class, for which the
          average nearest neighbor distance will be calculated.
      Distance_Method (String):
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies)

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block); calculated by summing the
          (absolute) difference between the x- and y-coordinates
      Generate_Report {Boolean}:
          * NO_REPORT-No graphical summary will be created. This is the default.

          * GENERATE_REPORT-A graphical summary will be created as an HTML file.
      Area {Double}:
          A numeric value representing the study area size. The default value is
          the area of the minimum enclosing rectangle that would encompass all
          features (or all selected features). Units should match those for the
          Output Coordinate System."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AverageNearestNeighbor_stats(*gp_fixargs((Input_Feature_Class, Distance_Method, Generate_Report, Area), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('HighLowClustering_stats', None)
def HighLowClustering(Input_Feature_Class=None, Input_Field=None, Generate_Report=None, Conceptualization_of_Spatial_Relationships=None, Distance_Method=None, Standardization=None, Distance_Band_or_Threshold_Distance=None, Weights_Matrix_File=None, number_of_neighbors=None):
    """HighLowClustering_stats(Input_Feature_Class, Input_Field, {Generate_Report}, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, {Distance_Band_or_Threshold_Distance}, {Weights_Matrix_File}, {number_of_neighbors})

        Measures the degree of clustering for either high or low values using
        the Getis-Ord General G statistic.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class for which the General G statistic will be
          calculated.
      Input_Field (Field):
          The numeric field to be evaluated.
      Generate_Report {Boolean}:
          * NO_REPORT-No graphical summary will be created. This is the default.

          * GENERATE_REPORT-A graphical summary will be created as an HTML file.
      Conceptualization_of_Spatial_Relationships (String):
          Specifies how spatial relationships among features are defined.

          * INVERSE_DISTANCE-Nearby neighboring features have a larger influence
          on the computations for a target feature than features that are far
          away.

          * INVERSE_DISTANCE_SQUARED-Same as INVERSE_DISTANCE except that the
          slope is sharper, so influence drops off more quickly, and only a
          target feature's closest neighbors will exert substantial influence on
          computations for that feature.

          * FIXED_DISTANCE_BAND-Each feature is analyzed within the context of
          neighboring features. Neighboring features inside the specified
          critical distance (Distance_Band_or_Threshold) receive a weight of one
          and exert influence on computations for the target feature.
          Neighboring features outside the critical distance receive a weight of
          zero and have no influence on a target feature's computations.

          * ZONE_OF_INDIFFERENCE-Features within the specified critical distance
          (Distance_Band_or_Threshold) of a target feature receive a weight of
          one and influence computations for that feature. Once the critical
          distance is exceeded, weights (and the influence a neighboring feature
          has on target feature computations) diminish with distance.

          * K_NEAREST_NEIGHBORS-The closest k features are included in the
          analysis; k is a specified numeric parameter.

          * CONTIGUITY_EDGES_ONLY-Only neighboring polygon features that share a
          boundary or overlap will influence computations for the target polygon
          feature.

          * CONTIGUITY_EDGES_CORNERS-Polygon features that share a boundary,
          share a node, or overlap will influence computations for the target
          polygon feature.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial relationships are defined by a
          specified spatial weights file. The path to the spatial weights file
          is specified by the Weights_Matrix_File parameter.
      Distance_Method (String):
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies)

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block); calculated by summing the
          (absolute) difference between the x- and y-coordinates
      Standardization (String):
          Specifies whether standardization of spatial weights will be applied.
          Row standardization is recommended whenever the distribution of your
          features is potentially biased due to sampling design or an imposed
          aggregation scheme.

          * NONE-No standardization of spatial weights is applied.

          * ROW-Spatial weights are standardized; each weight is divided by its
          row sum (the sum of the weights of all neighboring features). This is
          the default.
      Distance_Band_or_Threshold_Distance {Double}:
          Specifies a cutoff distance for the inverse distance and fixed
          distance options. Features outside the specified cutoff for a target
          feature are ignored in analyses for that feature. However, for
          ZONE_OF_INDIFFERENCE, the influence of features outside the given
          distance is reduced with distance, while those inside the distance
          threshold are equally considered. The distance value entered should
          match that of the output coordinate system.For the inverse distance
          conceptualizations of spatial relationships,
          a value of 0 indicates that no threshold distance is applied; when
          this parameter is left blank, a default threshold value is computed
          and applied. This default value is the Euclidean distance that ensures
          that every feature has at least one neighbor.This parameter has no
          effect when polygon contiguity
          (CONTIGUITY_EDGES_ONLY or CONTIGUITY_EDGES_CORNERS) or
          GET_SPATIAL_WEIGHTS_FROM_FILE spatial conceptualizations are selected.
      Weights_Matrix_File {File}:
          The path to a file containing weights that define spatial, and
          potentially temporal, relationships among features.
      number_of_neighbors {Long}:
          An integer specifying the number of neighbors that will be included in
          the analysis."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.HighLowClustering_stats(*gp_fixargs((Input_Feature_Class, Input_Field, Generate_Report, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, Distance_Band_or_Threshold_Distance, Weights_Matrix_File, number_of_neighbors), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('IncrementalSpatialAutocorrelation_stats', None)
def IncrementalSpatialAutocorrelation(Input_Features=None, Input_Field=None, Number_of_Distance_Bands=None, Beginning_Distance=None, Distance_Increment=None, Distance_Method=None, Row_Standardization=None, Output_Table=None, Output_Report_File=None):
    """IncrementalSpatialAutocorrelation_stats(Input_Features, Input_Field, Number_of_Distance_Bands, {Beginning_Distance}, {Distance_Increment}, {Distance_Method}, {Row_Standardization}, {Output_Table}, {Output_Report_File})

        Measures spatial autocorrelation for a series of distances and
        optionally creates a line graph of those distances and their
        corresponding z-scores. Z-scores reflect the intensity of spatial
        clustering, and statistically significant peak z-scores indicate
        distances where spatial processes promoting clustering are most
        pronounced. These peak distances are often appropriate values to use
        for tools with a Distance Band or Distance Radius parameter.

     INPUTS:
      Input_Features (Feature Layer):
          The feature class for which spatial autocorrelation will be measured
          over a series of distances.
      Input_Field (Field):
          The numeric field used in assessing spatial autocorrelation.
      Number_of_Distance_Bands (Long):
          The number of times to increment the neighborhood size and analyze the
          dataset for spatial autocorrelation. The starting point and size of
          the increment are specified in the Beginning_Distance and
          Distance_Increment parameters, respectively.
      Beginning_Distance {Double}:
          The distance at which to start the analysis of spatial autocorrelation
          and the distance from which to increment. The value entered for this
          parameter should be in the units of the Output Coordinate System
          environment setting.
      Distance_Increment {Double}:
          The distance to increase after each iteration. The distance used in
          the analysis starts at the Beginning_Distance and increases by the
          amount specified in the Distance_Increment. The value entered for this
          parameter should be in the units of the Output Coordinate System
          environment setting.
      Distance_Method {String}:
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN-The straight-line distance between two points (as the crow
          flies)

          * MANHATTAN-The distance between two points measured along axes at
          right angles (city block); calculated by summing the (absolute)
          difference between the x- and y-coordinates
      Row_Standardization {Boolean}:
          Row standardization is recommended whenever feature distribution is
          potentially biased due to sampling design or to an imposed aggregation
          scheme.

          * ROW_STANDARDIZATION-Spatial weights are standardized by row. Each
          weight is divided by its row sum.

          * NO_STANDARDIZATION-No standardization of spatial weights is applied.

     OUTPUTS:
      Output_Table {Table}:
          The table to be created with each distance band and associated z-score
          result.
      Output_Report_File {File}:
          The PDF file to be created containing a line graph summarizing
          results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.IncrementalSpatialAutocorrelation_stats(*gp_fixargs((Input_Features, Input_Field, Number_of_Distance_Bands, Beginning_Distance, Distance_Increment, Distance_Method, Row_Standardization, Output_Table, Output_Report_File), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MultiDistanceSpatialClustering_stats', None)
def MultiDistanceSpatialClustering(Input_Feature_Class=None, Output_Table=None, Number_of_Distance_Bands=None, Compute_Confidence_Envelope=None, Display_Results_Graphically=None, Weight_Field=None, Beginning_Distance=None, Distance_Increment=None, Boundary_Correction_Method=None, Study_Area_Method=None, Study_Area_Feature_Class=None):
    """MultiDistanceSpatialClustering_stats(Input_Feature_Class, Output_Table, Number_of_Distance_Bands, {Compute_Confidence_Envelope}, {Display_Results_Graphically}, {Weight_Field}, {Beginning_Distance}, {Distance_Increment}, {Boundary_Correction_Method}, {Study_Area_Method}, {Study_Area_Feature_Class})

        Determines whether features, or the values associated with features,
        exhibit statistically significant clustering or dispersion over a
        range of distances.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class upon which the analysis will be performed.
      Number_of_Distance_Bands (Long):
          The number of times to increment the neighborhood size and analyze the
          dataset for clustering. The starting point and size of the increment
          are specified in the Beginning_Distance and Distance_Increment
          parameters, respectively.
      Compute_Confidence_Envelope {String}:
          The confidence envelope is calculated by randomly placing feature
          points (or feature values) in the study area. The number of
          points/values randomly placed is equal to the number of points in the
          feature class. Each set of random placements is called a permutation
          and the confidence envelope is created from these permutations. This
          parameter allows you to select how many permutations you want to use
          to create the confidence envelope.

          * 0_PERMUTATIONS_-_NO_CONFIDENCE_ENVELOPE-Confidence envelopes are not
          created.

          * 9_PERMUTATIONS-Nine sets of points/values are randomly placed.

          * 99_PERMUTATIONS-99 sets of points/values are randomly placed.

          * 999_PERMUTATIONS-999 sets of points/values are randomly placed.
      Display_Results_Graphically {Boolean}:
          This parameter has no effect; it remains to support backward
          compatibility.

          * NO_DISPLAY-No graphical summary will be created (default).

          * DISPLAY_IT-A graphical summary will be created as a graph layer.
      Weight_Field {Field}:
          A numeric field with weights representing the number of
          features/events at each location.
      Beginning_Distance {Double}:
          The distance at which to start the cluster analysis and the distance
          from which to increment. The value entered for this parameter should
          be in the units of the Output Coordinate System.
      Distance_Increment {Double}:
          The distance to increment during each iteration. The distance used in
          the analysis starts at the Beginning_Distance and increments by the
          amount specified in the Distance_Increment. The value entered for this
          parameter should be in the units of the Output Coordinate System
          environment setting.
      Boundary_Correction_Method {String}:
          Method to use to correct for underestimates in the number of neighbors
          for features near the edges of the study area.

          * NONE-No edge correction is applied. However, if the input feature
          class already has points that fall outside the study area boundaries,
          these will be used in neighborhood counts for features near
          boundaries.

          * SIMULATE_OUTER_BOUNDARY_VALUES-This method simulates points outside
          the study area so that the number of neighbors near edges is not
          underestimated. The simulated points are the "mirrors" of points near
          edges within the study area boundary.

          * REDUCE_ANALYSIS_AREA-This method shrinks the study area such that
          some points are found outside of the study area boundary. Points found
          outside the study area are used to calculate neighbor counts but are
          not used in the cluster analysis itself.

          * RIPLEY_EDGE_CORRECTION_FORMULA-For all the points (j) in the
          neighborhood of point i, this method checks to see if the edge of the
          study area is closer to i, or if j is closer to i. If j is closer,
          extra weight is given to the point j. This edge correction method is
          only appropriate for square or rectangular shaped study areas.
      Study_Area_Method {String}:
          Specifies the region to use for the study area. The K Function is
          sensitive to changes in study area size so careful selection of this
          value is important.

          * MINIMUM_ENCLOSING_RECTANGLE-Indicates that the smallest possible
          rectangle enclosing all of the points will be used.

          * USER_PROVIDED_STUDY_AREA_FEATURE_CLASS-Indicates that a feature
          class defining the study area will be provided in the Study Area
          Feature Class parameter.
      Study_Area_Feature_Class {Feature Layer}:
          Feature class that delineates the area over which the input feature
          class should be analyzed. Only specified if Study_Area_Method =
          "USER_PROVIDED_STUDY_AREA_FEATURE_CLASS" .

     OUTPUTS:
      Output_Table (Table):
          The table to which the results of the analysis will be written."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MultiDistanceSpatialClustering_stats(*gp_fixargs((Input_Feature_Class, Output_Table, Number_of_Distance_Bands, Compute_Confidence_Envelope, Display_Results_Graphically, Weight_Field, Beginning_Distance, Distance_Increment, Boundary_Correction_Method, Study_Area_Method, Study_Area_Feature_Class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SpatialAutocorrelation_stats', None)
def SpatialAutocorrelation(Input_Feature_Class=None, Input_Field=None, Generate_Report=None, Conceptualization_of_Spatial_Relationships=None, Distance_Method=None, Standardization=None, Distance_Band_or_Threshold_Distance=None, Weights_Matrix_File=None, number_of_neighbors=None):
    """SpatialAutocorrelation_stats(Input_Feature_Class, Input_Field, {Generate_Report}, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, {Distance_Band_or_Threshold_Distance}, {Weights_Matrix_File}, {number_of_neighbors})

        Measures spatial autocorrelation based on feature locations and
        attribute values using the Global Moran's I statistic.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class for which spatial autocorrelation will be
          calculated.
      Input_Field (Field):
          The numeric field used in assessing spatial autocorrelation.
      Generate_Report {Boolean}:
          * NO_REPORT-No graphical summary will be created. This is the default.

          * GENERATE_REPORT-A graphical summary will be created as an HTML file.
      Conceptualization_of_Spatial_Relationships (String):
          Specifies how spatial relationships among features are defined.

          * INVERSE_DISTANCE-Nearby neighboring features have a larger influence
          on the computations for a target feature than features that are far
          away.

          * INVERSE_DISTANCE_SQUARED-This is the same as INVERSE_DISTANCE except
          that the slope is sharper, so influence drops off more quickly, and
          only a target feature's closest neighbors will exert substantial
          influence on computations for that feature.

          * FIXED_DISTANCE_BAND-Each feature is analyzed within the context of
          neighboring features. Neighboring features inside the specified
          critical distance (Distance_Band_or_Threshold) receive a weight of one
          and exert influence on computations for the target feature.
          Neighboring features outside the critical distance receive a weight of
          zero and have no influence on a target feature's computations.

          * ZONE_OF_INDIFFERENCE-Features within the specified critical distance
          (Distance_Band_or_Threshold) of a target feature receive a weight of
          one and influence computations for that feature. Once the critical
          distance is exceeded, weights (and the influence a neighboring feature
          has on target feature computations) diminish with distance.

          * K_NEAREST_NEIGHBORS-The closest k features are included in the
          analysis. The number of neighbors (k) to include in the analysis is
          specified by the number_of_neighbors parameter.

          * CONTIGUITY_EDGES_ONLY-Only neighboring polygon features that share a
          boundary or overlap will influence computations for the target polygon
          feature.

          * CONTIGUITY_EDGES_CORNERS-Polygon features that share a boundary,
          share a node, or overlap will influence computations for the target
          polygon feature.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial relationships are defined by a
          specified spatial weights file. The path to the spatial weights file
          is specified by the Weights_Matrix_File parameter.
      Distance_Method (String):
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies) will be used.

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block) will be used. This is calculated by
          summing the (absolute) difference between the x- and y-coordinates
      Standardization (String):
          Specifies whether standardization of spatial weights will be applied.
          Row standardization is recommended whenever the distribution of your
          features is potentially biased due to sampling design or an imposed
          aggregation scheme.

          * NONE-No standardization of spatial weights is applied.

          * ROW-Spatial weights are standardized; each weight is divided by its
          row sum (the sum of the weights of all neighboring features). This is
          the default.
      Distance_Band_or_Threshold_Distance {Double}:
          The cutoff distance for the various inverse distance and fixed
          distance options. Features outside the specified cutoff for a target
          feature are ignored in analyses for that feature. However, for
          ZONE_OF_INDIFFERENCE, the influence of features outside the given
          distance is reduced with distance, while those inside the distance
          threshold are equally considered. The distance value entered should
          match that of the output coordinate system.For the inverse distance
          conceptualizations of spatial relationships,
          a value of 0 indicates that no threshold distance is applied; when
          this parameter is left blank, a default threshold value is computed
          and applied. This default value is the Euclidean distance, which
          ensures that every feature has at least one neighbor.This parameter
          has no effect when polygon contiguity
          (CONTIGUITY_EDGES_ONLY or CONTIGUITY_EDGES_CORNERS) or
          GET_SPATIAL_WEIGHTS_FROM_FILE spatial conceptualization is selected.
      Weights_Matrix_File {File}:
          The path to a file containing weights that define spatial, and
          potentially temporal, relationships among features.
      number_of_neighbors {Long}:
          An integer specifying the number of neighbors to include in the
          analysis."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SpatialAutocorrelation_stats(*gp_fixargs((Input_Feature_Class, Input_Field, Generate_Report, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, Distance_Band_or_Threshold_Distance, Weights_Matrix_File, number_of_neighbors), True)))
        return retval
    except Exception as e:
        raise e


# Mapping Clusters toolset
@gptooldoc('BuildBalancedZones_stats', None)
def BuildBalancedZones(in_features=None, output_features=None, zone_creation_method=None, number_of_zones=None, zone_building_criteria_target=None, zone_building_criteria=None, spatial_constraints=None, weights_matrix_file=None, zone_characteristics=None, attribute_to_consider=None, distance_to_consider=None, categorial_variable=None, proportion_method=None, population_size=None, number_generations=None, mutation_factor=None, output_convergence_table=None):
    """BuildBalancedZones_stats(in_features, output_features, zone_creation_method, {number_of_zones}, {zone_building_criteria_target;zone_building_criteria_target...}, {zone_building_criteria;zone_building_criteria...}, {spatial_constraints}, {weights_matrix_file}, {zone_characteristics;zone_characteristics...}, {attribute_to_consider;attribute_to_consider...}, {distance_to_consider;distance_to_consider...}, {categorial_variable}, {proportion_method}, {population_size}, {number_generations}, {mutation_factor}, {output_convergence_table})

        Creates spatially contiguous zones in your study area using a genetic
        growth algorithm based on criteria that you specify.You can create
        zones that contain an equal number of features, zones
        that are similar based on a set of attribute values, or both. There
        are also options to select zones with approximately equal areas, are
        as compact as possible, and that maintain consistent summary
        statistics of other variables.

     INPUTS:
      in_features (Feature Layer):
          The feature class or feature layer that will be aggregated into zones.
      zone_creation_method (String):
          Specifies the method that will be used to grow each zone. Zones grow
          until all specified criteria are satisfied.

          * ATTRIBUTE_TARGET-Zones will be created based on target values of one
          or multiple variables. If this option is chosen, the desired sum of
          each attribute must be specified in the Zone Building Criteria With
          Target parameter, and each zone will grow until the sum of the
          attributes exceeds these values. For example, you can use this option
          to create zones that each have at least 100,000 residents and 20,000
          family homes.

          * NUMBER_ZONES_AND_ATTRIBUTE-A specified number of zones will be
          created while keeping the sum of an attribute approximately equal
          within each zone. If this option is chosen, the desired number of
          zones must be specified in the Target Number of Zones parameter. The
          attribute sum within each zone is equal to the sum of the total
          attribute divided by the number of zones.

          * NUMBER_OF_ZONES-A specified number of zones will be created that are
          each composed of approximately the same number of input features. If
          this option is chosen, the desired number of zones must be specified
          in the Target Number of Zones parameter.
      number_of_zones {Long}:
          The number of zones that will be created.
      zone_building_criteria_target {Value Table}:
          Specifies the variables that will be considered, their target values,
          and optional weights. The default weights are set to 1, and each
          variable contributes equally unless they are changed.
      zone_building_criteria {Value Table}:
          Specifies the variables that will be considered and, optionally,
          weights. The default weights are set to 1, and each variable
          contributes equally unless changed.
      spatial_constraints {String}:
          Specifies how neighbors are defined while the zones grow. Zones can
          only grow into new features that are neighbors of at least one of the
          features already in the zone. If the input features are polygons, the
          default spatial constraint is Contiguity edges corners. If the input
          features are points, the default spatial constraint is Trimmed
          Delaunay triangulation.

          * CONTIGUITY_EDGES_ONLY-For zones containing contiguous polygon
          features, only polygons that share an edge will be part of the same
          zone.

          * CONTIGUITY_EDGES_CORNERS-For zones containing contiguous polygon
          features, only polygons that share an edge or a vertex will be part of
          the same zone.

          * TRIMMED_DELAUNAY_TRIANGULATION-Features in the same zone will have
          at least one natural neighbor in common with another feature in the
          zone. Natural neighbor relationships are based on a trimmed Delaunay
          Triangulation. Conceptually, Delaunay Triangulation creates a non-
          overlapping mesh of triangles from feature centroids. Each feature is
          a triangle node, and nodes that share edges are considered neighbors.
          These triangles are then clipped to a convex hull to ensure that
          features cannot be neighbors with any features outside of the convex
          hull. This is the default.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial, and, optionally, temporal
          relationships will be defined by a specified spatial weights file
          (.swm). Create the spatial weights matrix using the Generate Spatial
          Weights Matrix tool or the Generate Network Spatial Weights tool. The
          path to the spatial weights file is specified by the Spatial Weights
          Matrix File parameter.
      weights_matrix_file {File}:
          The path to a file containing spatial weights that define spatial and,
          optionally, temporal relationships among features.
      zone_characteristics {String}:
          Specifies the desired characteristics of the zones that will be
          created.

          * EQUAL_AREA-Zones with total area as similar as possible will be
          created.

          * COMPACTNESS-Zones will be created with more closely-packed (compact)
          features.

          * EQUAL_NUMBER_OF_FEATURES-Zones with an equal number of features will
          be created.
      attribute_to_consider {Value Table}:
          Specifies attributes and statistics to consider in the selection of
          final zones. You can choose to homogenize attributes based on their
          sum, average, median, or variance. For example, if you are creating
          zones based on home values and want to balance the average total
          income within each zone, the solution with the most equal average
          income across zones will be preferred.
      distance_to_consider {Feature Layer}:
          The feature class that will be used to homogenize the total distance
          per zone. The distance is calculated from each of the input features
          to the closest feature provided in this parameter. This distance is
          then used as an additional attribute constraint when selecting the
          final zone solution. For example, you can create police patrol
          districts that are each approximately the same distance from the
          closest police station.This optional parameter is not available with a
          Desktop Basic or
          Desktop Standard license.
      categorial_variable {Field}:
          The categorical variable to be considered for zone proportions.
      proportion_method {String}:
          Specifies the type of proportion that will be maintained based on the
          chosen categorical variable.

          * MAINTAIN_WITHIN_PROPORTION-Each zone will maintain the same
          proportions as the overall study area for the given categorical
          variable. For example, given a categorical variable that is 60% Type A
          and 40% Type B, this method will prefer zones that are comprised of
          approximately 60% Type A features and 40% Type B features.

          * MAINTAIN_OVERALL_PROPORTION-Zones will be created so that the
          overall proportions of category predominance by zone matches the
          proportions of the given categorical variable for the entire dataset.
          For example, given a categorical variable that is 60% Type A and 40%
          Type B, this method will prefer solutions where 60% of the zones are
          predominantly Type A features and 40% of the zones are predominantly
          Type B features.
      population_size {Long}:
          The number of randomly generated initial seeds. For larger datasets,
          increasing this number will increase the search space and the
          probability of finding a better solution. The default is 100.
      number_generations {Long}:
          The number of times the zone search process is repeated. For larger
          datasets, increasing the number is recommended in order to find an
          optimal solution. The default is 50 generations.
      mutation_factor {Double}:
          The probability that an individual's seed values will be mutated to a
          new set of seeds. Mutation increases the search space by introducing
          variability of the possible solutions in every generation and allows
          for faster convergence to an optimal solution. The default is 0.1.

     OUTPUTS:
      output_features (Feature Class):
          The output feature class indicating which features are aggregated into
          each zone. The feature class will be symbolized by the ZONE_ID field
          and will contain fields displaying the values of each criteria that
          you specify.
      output_convergence_table {Table}:
          If specified, a table will be created containing the total fitness
          score for the best solution found in every generation as well as the
          fitness score for the individual zone constraints."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.BuildBalancedZones_stats(*gp_fixargs((in_features, output_features, zone_creation_method, number_of_zones, zone_building_criteria_target, zone_building_criteria, spatial_constraints, weights_matrix_file, zone_characteristics, attribute_to_consider, distance_to_consider, categorial_variable, proportion_method, population_size, number_generations, mutation_factor, output_convergence_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ClustersOutliers_stats', None)
def ClustersOutliers(Input_Feature_Class=None, Input_Field=None, Output_Feature_Class=None, Conceptualization_of_Spatial_Relationships=None, Distance_Method=None, Standardization=None, Distance_Band_or_Threshold_Distance=None, Weights_Matrix_File=None, Apply_False_Discovery_Rate__FDR__Correction=None, Number_of_Permutations=None, number_of_neighbors=None):
    """ClustersOutliers_stats(Input_Feature_Class, Input_Field, Output_Feature_Class, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, {Distance_Band_or_Threshold_Distance}, {Weights_Matrix_File}, {Apply_False_Discovery_Rate__FDR__Correction}, {Number_of_Permutations}, {number_of_neighbors})

        Given a set of weighted features, identifies statistically significant
        hot spots, cold spots, and spatial outliers using the Anselin Local
        Moran's I statistic.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class for which cluster and outlier analysis will be
          performed.
      Input_Field (Field):
          The numeric field to be evaluated.
      Conceptualization_of_Spatial_Relationships (String):
          Specifies how spatial relationships among features are defined.

          * INVERSE_DISTANCE-Nearby neighboring features have a larger influence
          on the computations for a target feature than features that are far
          away.

          * INVERSE_DISTANCE_SQUARED-Same as INVERSE_DISTANCE except that the
          slope is sharper, so influence drops off more quickly, and only a
          target feature's closest neighbors will exert substantial influence on
          computations for that feature.

          * FIXED_DISTANCE_BAND-Each feature is analyzed within the context of
          neighboring features. Neighboring features inside the specified
          critical distance (Distance_Band_or_Threshold_Distance) receive a
          weight of one and exert influence on computations for the target
          feature. Neighboring features outside the critical distance receive a
          weight of zero and have no influence on a target feature's
          computations.

          * ZONE_OF_INDIFFERENCE-Features within the specified critical distance
          (Distance_Band_or_Threshold_Distance) of a target feature receive a
          weight of one and influence computations for that feature. Once the
          critical distance is exceeded, weights (and the influence a
          neighboring feature has on target feature computations) diminish with
          distance.

          * K_NEAREST_NEIGHBORS-The closest k features are included in the
          analysis. The number of neighbors (k) is specified by the
          number_of_neighbors parameter.

          * CONTIGUITY_EDGES_ONLY-Only neighboring polygon features that share a
          boundary or overlap will influence computations for the target polygon
          feature.

          * CONTIGUITY_EDGES_CORNERS-Polygon features that share a boundary,
          share a node, or overlap will influence computations for the target
          polygon feature.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial relationships are defined by a
          specified spatial weights file. The path to the spatial weights file
          is specified by the Weights_Matrix_File parameter.
      Distance_Method (String):
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies)

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block); calculated by summing the
          (absolute) difference between the x- and y-coordinates
      Standardization (String):
          Row standardization is recommended whenever the distribution of your
          features is potentially biased due to sampling design or an imposed
          aggregation scheme.

          * NONE-No standardization of spatial weights is applied.

          * ROW-Spatial weights are standardized; each weight is divided by its
          row sum (the sum of the weights of all neighboring features).
      Distance_Band_or_Threshold_Distance {Double}:
          Specifies a cutoff distance for Inverse Distance and Fixed Distance
          options. Features outside the specified cutoff for a target feature
          are ignored in analyses for that feature. However, for Zone of
          Indifference, the influence of features outside the given distance is
          reduced with distance, while those inside the distance threshold are
          equally considered. The distance value entered should match that of
          the output coordinate system.For the Inverse Distance
          conceptualizations of spatial relationships,
          a value of 0 indicates that no threshold distance is applied; when
          this parameter is left blank, a default threshold value is computed
          and applied. This default value is the Euclidean distance that ensures
          every feature has at least one neighbor.This parameter has no effect
          when Polygon Contiguity or Get Spatial
          Weights From File spatial conceptualizations are selected.
      Weights_Matrix_File {File}:
          The path to a file containing weights that define spatial, and
          potentially temporal, relationships among features.
      Apply_False_Discovery_Rate__FDR__Correction {Boolean}:
          * APPLY_FDR-Statistical significance will be based on the False
          Discovery Rate correction for a 95 percent confidence level.

          * NO_FDR-Features with p-values less than 0.05 will appear in the
          COType field reflecting statistically significant clusters or outliers
          at a 95 percent confidence level (default).
      Number_of_Permutations {Long}:
          The number of random permutations for the calculation of pseudo
          p-values. The default number of permutations is 499. If you choose 0
          permutations, the standard p-value is calculated.

          * 0-Permutations are not used and a standard p-value is calculated.

          * 99-With 99 permutations, the smallest possible pseudo p-value is
          0.01 and all other pseudo p-values will be multiples of this value.

          * 199-With 199 permutations, the smallest possible pseudo p-value is
          0.005 and all other possible pseudo p-values will be multiples of this
          value.

          * 499-With 499 permutations, the smallest possible pseudo p-value is
          0.002 and all other pseudo p-values will be multiples of this value.

          * 999-With 999 permutations, the smallest possible pseudo p-value is
          0.001 and all other pseudo p-values will be multiples of this value.

          * 9999-With 9999 permutations, the smallest possible pseudo p-value is
          0.0001 and all other pseudo p-values will be multiples of this value.
      number_of_neighbors {Long}:
          The number of neighbors to include in the analysis.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          The output feature class to receive the results fields."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ClustersOutliers_stats(*gp_fixargs((Input_Feature_Class, Input_Field, Output_Feature_Class, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, Distance_Band_or_Threshold_Distance, Weights_Matrix_File, Apply_False_Discovery_Rate__FDR__Correction, Number_of_Permutations, number_of_neighbors), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DensityBasedClustering_stats', None)
def DensityBasedClustering(in_features=None, output_features=None, cluster_method=None, min_features_cluster=None, search_distance=None, cluster_sensitivity=None):
    """DensityBasedClustering_stats(in_features, output_features, cluster_method, min_features_cluster, {search_distance}, {cluster_sensitivity})

        Finds clusters of point features within surrounding noise based on
        their spatial distribution.

     INPUTS:
      in_features (Feature Layer):
          The point feature class for which density-based clustering will be
          performed.
      cluster_method (String):
          Specifies the method used to define clusters.

          * DBSCAN-Uses a specified distance to separate dense clusters from
          sparser noise. DBSCAN is the fastest of the clustering methods but is
          only appropriate if there is a very clear distance to use that works
          well to define all clusters that may be present. This results in
          clusters that have similar densities.

          * HDBSCAN-Uses varying distances to separate clusters of varying
          densities from sparser noise. HDBSCAN is the most data-driven of the
          clustering methods and requires the least user input.

          * OPTICS-Uses the distance between neighbors and a reachability plot
          to separate clusters of varying densities from noise. OPTICS offers
          the most flexibility in fine-tuning the clusters that are detected,
          though it is computationally intensive, particularly with a large
          Search Distance.
      min_features_cluster (Long):
          The minimum number of features to be considered a cluster. Any cluster
          with fewer features than the number provided will be considered noise.
      search_distance {Linear Unit}:
          The maximum distance to consider.For Defined distance (DBSCAN), the
          Minimum Features per Cluster
          specified must be found within this distance for cluster membership.
          Individual clusters will be separated by at least this distance. If a
          feature is located further than this distance from the next closest
          feature in the cluster, it will not be included in the cluster.For
          Multi-scale (OPTICS), this parameter is optional and is used as
          the maximum search distance when creating the reachability plot. For
          OPTICS, the reachability plot, combined with the Cluster Sensitivity
          parameter, determines cluster membership. If no distance is specified,
          the tool will search all distances, which will increase processing
          time.If left blank, the default distance used will be the highest core
          distance found in the dataset, excluding those core distances in the
          top 1 percent (excluding the most extreme core distances).
      cluster_sensitivity {Long}:
          An integer between 0 and 100 that determines the compactness of
          clusters. A number close to 100 will result in a higher number of
          dense clusters. A number close to 0 will result in fewer, less compact
          clusters. If left blank, the tool will find a sensitivity value using
          the Kullback-Leibler divergence that finds the value where adding more
          clusters does not add additional information.

     OUTPUTS:
      output_features (Feature Class):
          The output feature class to receive the cluster results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DensityBasedClustering_stats(*gp_fixargs((in_features, output_features, cluster_method, min_features_cluster, search_distance, cluster_sensitivity), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GroupingAnalysis_stats', None)
def GroupingAnalysis(Input_Features=None, Unique_ID_Field=None, Output_Feature_Class=None, Number_of_Groups=None, Analysis_Fields=None, Spatial_Constraints=None, Distance_Method=None, Number_of_Neighbors=None, Weights_Matrix_File=None, Initialization_Method=None, Initialization_Field=None, Output_Report_File=None, Evaluate_Optimal_Number_of_Groups=None):
    """GroupingAnalysis_stats(Input_Features, Unique_ID_Field, Output_Feature_Class, Number_of_Groups, Analysis_Fields;Analysis_Fields..., Spatial_Constraints, {Distance_Method}, {Number_of_Neighbors}, {Weights_Matrix_File}, {Initialization_Method}, {Initialization_Field}, {Output_Report_File}, {Evaluate_Optimal_Number_of_Groups})

        Groups features based on feature attributes and optional spatial or
        temporal constraints.This is a deprecated tool. The algorithm behind
        this tool has been
        enhanced and new functionality has been added to these methods. To
        simplify the new features and methods, this tool has been replaced by
        two new tools. Use the Spatially Constrained Multivariate Clustering
        tool if you would like to create spatially constrained groups. Use the
        Multivariate Clustering tool to create groups with no spatial
        constraints.

     INPUTS:
      Input_Features (Feature Layer):
          The feature class or feature layer for which you want to create
          groups.
      Unique_ID_Field (Field):
          An integer field containing a different value for every feature in the
          input feature class. If you don't have a Unique ID field, you can
          create one by adding an integer field to your feature class table and
          calculating the field values to equal the FID or OBJECTID field.
      Number_of_Groups (Long):
          The number of groups to create. The Output Report parameter will be
          disabled for more than 15 groups.
      Analysis_Fields (Field):
          A list of fields you want to use to distinguish one group from
          another. The Output Report parameter will be disabled for more than 15
          fields.
      Spatial_Constraints (String):
          Specifies if and how spatial relationships among features should
          constrain the groups created.

          * CONTIGUITY_EDGES_ONLY-Groups contain contiguous polygon features.
          Only polygons that share an edge can be part of the same group.

          * CONTIGUITY_EDGES_CORNERS-Groups contain contiguous polygon features.
          Only polygons that share an edge or a vertex can be part of the same
          group.

          * DELAUNAY_TRIANGULATION-Features in the same group will have at least
          one natural neighbor in common with another feature in the group.
          Natural neighbor relationships are based on Delaunay Triangulation.
          Conceptually, Delaunay Triangulation creates a nonoverlapping mesh of
          triangles from feature centroids. Each feature is a triangle node and
          nodes that share edges are considered neighbors.

          * K_NEAREST_NEIGHBORS-Features in the same group will be near each
          other; each feature will be a neighbor of at least one other feature
          in the group. Neighbor relationships are based on the nearest K
          features where you specify an Integer value, K, for the
          Number_of_Neighbors parameter.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial, and optionally temporal,
          relationships are defined by a spatial weights file (.swm). Create the
          spatial weights matrix file using the Generate Spatial Weights Matrix
          tool or the Generate Network Spatial Weights tool.

          * NO_SPATIAL_CONSTRAINT-Features will be grouped using data space
          proximity only. Features do not have to be near each other in space or
          time to be part of the same group.
      Distance_Method {String}:
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN-The straight-line distance between two points (as the crow
          flies)

          * MANHATTAN-The distance between two points measured along axes at
          right angles (city block); calculated by summing the (absolute)
          difference between the x- and y-coordinates
      Number_of_Neighbors {Long}:
          This parameter may be specified whenever the Spatial_Constraints
          parameter is K_NEAREST_NEIGHBORS or one of the contiguity methods
          (CONTIGUITY_EDGES_ONLY or CONTIGUITY_EDGES_CORNERS). The default
          number of neighbors is 8 and cannot be smaller than 2 for
          K_NEAREST_NEIGHBORS. This value reflects the exact number of nearest
          neighbor candidates to consider when building groups. A feature will
          not be included in a group unless one of the other features in that
          group is a K nearest neighbor. The default for CONTIGUITY_EDGES_ONLY
          and CONTIGUITY_EDGES_CORNERS is 0. For the contiguity methods, this
          value reflects the minimum number of neighbor candidates to consider.
          Additional nearby neighbors for features with less than the
          Number_of_Neighbors specified will be based on feature centroid
          proximity.
      Weights_Matrix_File {File}:
          The path to a file containing spatial weights that define spatial
          relationships among features.
      Initialization_Method {String}:
          Specifies how initial seeds are obtained when the Spatial_Constraint
          parameter selected is NO_SPATIAL_CONSTRAINT. Seeds are used to grow
          groups. If you indicate you want three groups, for example, the
          analysis will begin with three seeds.

          * FIND_SEED_LOCATIONS-Seed features will be selected to optimize
          performance.

          * GET_SEEDS_FROM_FIELD-Nonzero entries in the Initialization Field
          will be used as starting points to grow groups.

          * USE_RANDOM_SEEDS-Initial seed features will be randomly selected.
      Initialization_Field {Field}:
          The numeric field identifying seed features. Features with a value of
          1 for this field will be used to grow groups.
      Evaluate_Optimal_Number_of_Groups {Boolean}:
          * EVALUATE-Groupings from 2 to 15 will be evaluated.

          * DO_NOT_EVALUATE-No evaluation of the number of groups will be
          performed. This is the default.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          The new output feature class created containing all features, the
          analysis fields specified, and a field indicating to which group each
          feature belongs.
      Output_Report_File {File}:
          The full path for the PDF report file to be created summarizing group
          characteristics. This report provides a number of graphs to help you
          compare the characteristics of each group. Creating the report file
          can add substantial processing time."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GroupingAnalysis_stats(*gp_fixargs((Input_Features, Unique_ID_Field, Output_Feature_Class, Number_of_Groups, Analysis_Fields, Spatial_Constraints, Distance_Method, Number_of_Neighbors, Weights_Matrix_File, Initialization_Method, Initialization_Field, Output_Report_File, Evaluate_Optimal_Number_of_Groups), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('HotSpots_stats', None)
def HotSpots(Input_Feature_Class=None, Input_Field=None, Output_Feature_Class=None, Conceptualization_of_Spatial_Relationships=None, Distance_Method=None, Standardization=None, Distance_Band_or_Threshold_Distance=None, Self_Potential_Field=None, Weights_Matrix_File=None, Apply_False_Discovery_Rate__FDR__Correction=None, number_of_neighbors=None):
    """HotSpots_stats(Input_Feature_Class, Input_Field, Output_Feature_Class, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, {Distance_Band_or_Threshold_Distance}, {Self_Potential_Field}, {Weights_Matrix_File}, {Apply_False_Discovery_Rate__FDR__Correction}, {number_of_neighbors})

        Given a set of weighted features, identifies statistically significant
        hot spots and cold spots using the Getis-Ord Gi* statistic.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class for which hot spot analysis will be performed.
      Input_Field (Field):
          The numeric field (number of victims, crime rate, test scores, and so
          on) to be evaluated.
      Conceptualization_of_Spatial_Relationships (String):
          Specifies how spatial relationships among features will be defined.

          * INVERSE_DISTANCE-Nearby neighboring features will have a larger
          influence on the computations for a target feature than features that
          are far away.

          * INVERSE_DISTANCE_SQUARED-Same as INVERSE_DISTANCE except that the
          slope is sharper, so influence will drop off more quickly, and only a
          target feature's closest neighbors will exert substantial influence on
          computations for that feature.

          * FIXED_DISTANCE_BAND-Each feature will be analyzed within the context
          of neighboring features. Neighboring features inside the specified
          critical distance (Distance_Band_or_Threshold) will receive a weight
          of one and exert influence on computations for the target feature.
          Neighboring features outside the critical distance will receive a
          weight of zero and have no influence on a target feature's
          computations.

          * ZONE_OF_INDIFFERENCE-Features within the specified critical distance
          (Distance_Band_or_Threshold) of a target feature will receive a weight
          of one and influence computations for that feature. Once the critical
          distance is exceeded, weights (and the influence a neighboring feature
          has on target feature computations) will diminish with distance.

          * K_NEAREST_NEIGHBORS-The closest k features will be included in the
          analysis; k is a specified numeric parameter.

          * CONTIGUITY_EDGES_ONLY-Only neighboring polygon features that share a
          boundary or overlap will influence computations for the target polygon
          feature.

          * CONTIGUITY_EDGES_CORNERS-Polygon features that share a boundary,
          share a node, or overlap will influence computations for the target
          polygon feature.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial relationships will be defined
          by a specified spatial weights file. The path to the spatial weights
          file is specified by the Weights_Matrix_File parameter.
      Distance_Method (String):
          Specifies how distances will be calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies)

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block), calculated by summing the
          (absolute) difference between the x- and y-coordinates
      Standardization (String):
          Row standardization has no impact on this tool: results from Hot Spot
          Analysis (the Getis-Ord Gi* statistic) would be identical with or
          without row standardization. The parameter is disabled; it remains as
          a tool parameter only to support backward compatibility.

          * NONE-No standardization of spatial weights is applied.

          * ROW-No standardization of spatial weights is applied.
      Distance_Band_or_Threshold_Distance {Double}:
          Specifies a cutoff distance for the inverse distance and fixed
          distance options. Features outside the specified cutoff for a target
          feature will be ignored in analyses for that feature. However, for
          ZONE_OF_INDIFFERENCE, the influence of features outside the given
          distance will be reduced with distance, while those inside the
          distance threshold will be equally considered. The distance value
          entered should match that of the output coordinate system.For the
          inverse distance conceptualizations of spatial relationships,
          a value of 0 indicates that no threshold distance will be applied;
          when this parameter is left blank, a default threshold value will be
          computed and applied. The default value is the Euclidean distance,
          which ensures that every feature has at least one neighbor.This
          parameter has no effect when polygon contiguity
          (CONTIGUITY_EDGES_ONLY or CONTIGUITY_EDGES_CORNERS) or
          GET_SPATIAL_WEIGHTS_FROM_FILE spatial conceptualization is selected.
      Self_Potential_Field {Field}:
          The field representing self potential: the distance or weight between
          a feature and itself.
      Weights_Matrix_File {File}:
          The path to a file containing weights that define spatial, and
          potentially temporal, relationships among features.
      Apply_False_Discovery_Rate__FDR__Correction {Boolean}:
          * APPLY_FDR-Statistical significance will be based on the FDR
          correction.

          * NO_FDR-Statistical significance will not be based on the FDR
          correction; it will be based on the p-value and z-score fields. This
          is the default.
      number_of_neighbors {Long}:
          An integer specifying the number of neighbors to include in the
          analysis.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          The output feature class to receive the z-score and p-value results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.HotSpots_stats(*gp_fixargs((Input_Feature_Class, Input_Field, Output_Feature_Class, Conceptualization_of_Spatial_Relationships, Distance_Method, Standardization, Distance_Band_or_Threshold_Distance, Self_Potential_Field, Weights_Matrix_File, Apply_False_Discovery_Rate__FDR__Correction, number_of_neighbors), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MultivariateClustering_stats', None)
def MultivariateClustering(in_features=None, output_features=None, analysis_fields=None, clustering_method=None, initialization_method=None, initialization_field=None, number_of_clusters=None, output_table=None):
    """MultivariateClustering_stats(in_features, output_features, analysis_fields;analysis_fields..., {clustering_method}, {initialization_method}, {initialization_field}, {number_of_clusters}, {output_table})

        Finds natural clusters of features based solely on feature attribute
        values.

     INPUTS:
      in_features (Feature Layer):
          The feature class or feature layer for which you want to create
          clusters.
      analysis_fields (Field):
          A list of fields you want to use to distinguish one cluster from
          another.
      clustering_method {String}:
          The clustering algorithm used. K_MEANS is the default.K_MEANS and
          K_MEDOIDS are both popular clustering algorithms and will
          generally produce similar results. However, K_MEDOIDS is more robust
          to noise and outliers in the in_features. K_MEANS is generally faster
          than K_MEDOIDS and is preferred for large data sets.

          * K_MEANS-The in_features will be clustered using the K means
          algorithm. This is the default.

          * K_MEDOIDS-The Input Features will be clustered using the K medoids
          algorithm.
      initialization_method {String}:
          Specifies how initial seeds to grow clusters are obtained. If you
          indicate you want three clusters, for example, the analysis will begin
          with three seeds.

          * OPTIMIZED_SEED_LOCATIONS-Seed features will be selected to optimize
          analysis results and performance. This is the default.

          * USER_DEFINED_SEED_LOCATIONS-Nonzero entries in the
          initialization_field will be used as starting points to grow clusters.

          * RANDOM_SEED_LOCATIONS-Initial seed features will be randomly
          selected.
      initialization_field {Field}:
          The numeric field identifying seed features. Features with a value of
          1 for this field will be used to grow clusters. All other features
          should contain zeros.
      number_of_clusters {Long}:
          The number of clusters to create. When you leave this parameter empty,
          the tool will evaluate the optimal number of clusters by computing a
          pseudo F-statistic for clustering solutions with 2 through 30
          clusters.This parameter is disabled if the seed locations were
          provided in an
          initialization field.

     OUTPUTS:
      output_features (Feature Class):
          The new output feature class created containing all features, the
          analysis fields specified, and a field indicating to which cluster
          each feature belongs.
      output_table {Table}:
          If specified, the table created contains the pseudo F-statistic for
          clustering solutions 2 through 30, calculated to evaluate the optimal
          number of clusters. The chart created from this table can be accessed
          in the stand-alone tables section of the Contents pane."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MultivariateClustering_stats(*gp_fixargs((in_features, output_features, analysis_fields, clustering_method, initialization_method, initialization_field, number_of_clusters, output_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OptimizedHotSpotAnalysis_stats', None)
def OptimizedHotSpotAnalysis(Input_Features=None, Output_Features=None, Analysis_Field=None, Incident_Data_Aggregation_Method=None, Bounding_Polygons_Defining_Where_Incidents_Are_Possible=None, Polygons_For_Aggregating_Incidents_Into_Counts=None, Density_Surface=None, Cell_Size=None, Distance_Band=None):
    """OptimizedHotSpotAnalysis_stats(Input_Features, Output_Features, {Analysis_Field}, {Incident_Data_Aggregation_Method}, {Bounding_Polygons_Defining_Where_Incidents_Are_Possible}, {Polygons_For_Aggregating_Incidents_Into_Counts}, {Density_Surface}, {Cell_Size}, {Distance_Band})

        Given incident points or weighted features (points or polygons),
        creates a map of statistically significant hot and cold spots using
        the Getis-Ord Gi* statistic. It evaluates the characteristics of the
        input feature class to produce optimal results.

     INPUTS:
      Input_Features (Feature Layer):
          The point or polygon feature class for which hot spot analysis will be
          performed.
      Analysis_Field {Field}:
          The numeric field (number of incidents, crime rates, test scores, and
          so on) to be evaluated.
      Incident_Data_Aggregation_Method {String}:
          The aggregation method to use to create weighted features for analysis
          from incident point data.

          * COUNT_INCIDENTS_WITHIN_FISHNET_POLYGONS-A fishnet polygon mesh will
          overlay the incident point data and the number of incidents within
          each polygon cell will be counted. If no bounding polygon is provided
          in the Bounding_Polygons_Defining_Where_Incidents_Are_Possible
          parameter, only cells with at least one incident will be used in the
          analysis; otherwise, all cells within the bounding polygons will be
          analyzed.

          * COUNT_INCIDENTS_WITHIN_HEXAGON_POLYGONS-A hexagon polygon mesh will
          overlay the incident point data and the number of incidents within
          each polygon cell will be counted. If no bounding polygon is provided
          in the Bounding_Polygons_Defining_Where_Incidents_Are_Possible
          parameter, only cells with at least one incident will be used in the
          analysis; otherwise, all cells within the bounding polygons will be
          analyzed.

          * COUNT_INCIDENTS_WITHIN_AGGREGATION_POLYGONS-You provide aggregation
          polygons to overlay the incident point data in the
          Polygons_For_Aggregating_Incidents_Into_Counts parameter. The
          incidents within each polygon are counted.

          * SNAP_NEARBY_INCIDENTS_TO_CREATE_WEIGHTED_POINTS-Nearby incidents
          will be aggregated together to create a single weighted point. The
          weight for each point is the number of aggregated incidents at that
          location.
      Bounding_Polygons_Defining_Where_Incidents_Are_Possible {Feature Layer}:
          A polygon feature class defining where the incident Input_Features
          could possibly occur.
      Polygons_For_Aggregating_Incidents_Into_Counts {Feature Layer}:
          The polygons to use to aggregate the incident Input_Features in order
          to get an incident count for each polygon feature.
      Cell_Size {Linear Unit}:
          The size of the grid cells used to aggregate the Input_Features. When
          aggregating into a hexagon grid, this distance is used as the height
          to construct the hexagon polygons.
      Distance_Band {Linear Unit}:
          The spatial extent of the analysis neighborhood. This value determines
          which features are analyzed together in order to assess local
          clustering.

     OUTPUTS:
      Output_Features (Feature Class):
          The output feature class to receive the z-score, p-value, and Gi_Bin
          results.
      Density_Surface {Raster Dataset}:
          The Density_Surface parameter is disabled; it remains as a tool
          parameter only to support backwards compatibility. The Kernel Density
          tool can be used if you would like a density surface visualization of
          your weighted points."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OptimizedHotSpotAnalysis_stats(*gp_fixargs((Input_Features, Output_Features, Analysis_Field, Incident_Data_Aggregation_Method, Bounding_Polygons_Defining_Where_Incidents_Are_Possible, Polygons_For_Aggregating_Incidents_Into_Counts, Density_Surface, Cell_Size, Distance_Band), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OptimizedOutlierAnalysis_stats', None)
def OptimizedOutlierAnalysis(Input_Features=None, Output_Features=None, Analysis_Field=None, Incident_Data_Aggregation_Method=None, Bounding_Polygons_Defining_Where_Incidents_Are_Possible=None, Polygons_For_Aggregating_Incidents_Into_Counts=None, Performance_Adjustment=None, Cell_Size=None, Distance_Band=None):
    """OptimizedOutlierAnalysis_stats(Input_Features, Output_Features, {Analysis_Field}, {Incident_Data_Aggregation_Method}, {Bounding_Polygons_Defining_Where_Incidents_Are_Possible}, {Polygons_For_Aggregating_Incidents_Into_Counts}, {Performance_Adjustment}, {Cell_Size}, {Distance_Band})

        Given incident points or weighted features (points or polygons),
        creates a map of statistically significant hot spots, cold spots, and
        spatial outliers using the Anselin Local Moran's I statistic. It
        evaluates the characteristics of the input feature class to produce
        optimal results.

     INPUTS:
      Input_Features (Feature Layer):
          The point or polygon feature class for which the cluster and outlier
          analysis will be performed.
      Analysis_Field {Field}:
          The numeric field (number of incidents, crime rates, test scores, and
          so on) to be evaluated.
      Incident_Data_Aggregation_Method {String}:
          The aggregation method to use to create weighted features for analysis
          from incident point data.

          * COUNT_INCIDENTS_WITHIN_FISHNET_POLYGONS-A fishnet polygon mesh will
          overlay the incident point data and the number of incidents within
          each polygon cell will be counted. If no bounding polygon is provided
          in the Bounding_Polygons_Defining_Where_Incidents_Are_Possible
          parameter, only cells with at least one incident will be used in the
          analysis; otherwise, all cells within the bounding polygons will be
          analyzed.

          * COUNT_INCIDENTS_WITHIN_HEXAGON_POLYGONS-A hexagon polygon mesh will
          overlay the incident point data and the number of incidents within
          each polygon cell will be counted. If no bounding polygon is provided
          in the Bounding_Polygons_Defining_Where_Incidents_Are_Possible
          parameter, only cells with at least one incident will be used in the
          analysis; otherwise, all cells within the bounding polygons will be
          analyzed.

          * COUNT_INCIDENTS_WITHIN_AGGREGATION_POLYGONS-You provide aggregation
          polygons to overlay the incident point data in the
          Polygons_For_Aggregating_Incidents_Into_Counts parameter. The
          incidents within each polygon are counted.

          * SNAP_NEARBY_INCIDENTS_TO_CREATE_WEIGHTED_POINTS-Nearby incidents
          will be aggregated together to create a single weighted point. The
          weight for each point is the number of aggregated incidents at that
          location.
      Bounding_Polygons_Defining_Where_Incidents_Are_Possible {Feature Layer}:
          A polygon feature class defining where the incident Input_Features
          could possibly occur.
      Polygons_For_Aggregating_Incidents_Into_Counts {Feature Layer}:
          The polygons to use to aggregate the incident Input_Features in order
          to get an incident count for each polygon feature.
      Performance_Adjustment {String}:
          This analysis utilizes permutations to create a reference
          distribution. Choosing the number of permutations is a balance between
          precision and increased processing time. Choose your preference for
          speed versus precision. More robust and precise results take longer to
          calculate.

          * QUICK_199-With 199 permutations, the smallest possible pseudo
          p-value is 0.005 and all other pseudo p-values will be even multiples
          of this value.

          * BALANCED_499-With 499 permutations, the smallest possible pseudo
          p-value is 0.002 and all other pseudo p-values will be even multiples
          of this value.

          * ROBUST_999-With 999 permutations, the smallest possible pseudo
          p-value is 0.001 and all other pseudo p-values will be even multiples
          of this value.
      Cell_Size {Linear Unit}:
          The size of the grid cells used to aggregate the Input_Features. When
          aggregating into a hexagon grid, this distance is used as the height
          to construct the hexagon polygons.
      Distance_Band {Linear Unit}:
          The spatial extent of the analysis neighborhood. This value determines
          which features are analyzed together in order to assess local
          clustering.

     OUTPUTS:
      Output_Features (Feature Class):
          The output feature class to receive the result fields."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OptimizedOutlierAnalysis_stats(*gp_fixargs((Input_Features, Output_Features, Analysis_Field, Incident_Data_Aggregation_Method, Bounding_Polygons_Defining_Where_Incidents_Are_Possible, Polygons_For_Aggregating_Incidents_Into_Counts, Performance_Adjustment, Cell_Size, Distance_Band), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SimilaritySearch_stats', None)
def SimilaritySearch(Input_Features_To_Match=None, Candidate_Features=None, Output_Features=None, Collapse_Output_To_Points=None, Most_Or_Least_Similar=None, Match_Method=None, Number_Of_Results=None, Attributes_Of_Interest=None, Fields_To_Append_To_Output=None):
    """SimilaritySearch_stats(Input_Features_To_Match, Candidate_Features, Output_Features, Collapse_Output_To_Points, Most_Or_Least_Similar, Match_Method, Number_Of_Results, Attributes_Of_Interest;Attributes_Of_Interest..., {Fields_To_Append_To_Output;Fields_To_Append_To_Output...})

        Identifies which candidate features are most similar or most
        dissimilar to one or more input features based on feature attributes.

     INPUTS:
      Input_Features_To_Match (Feature Layer):
          The layer (or a selection on a layer) containing the features you want
          to match; you are searching for other features that look like these
          features. When more than one feature is provided, matching is based on
          attribute averages. Tip: When your Input Features To Match and
          Candidate Features
          come from a single dataset layer you can

          * Copy and paste the layer to Contents, making a duplicate layer.

          * Rename the duplicate layer.

          * On the renamed layer, make a selection or set a definition query for
          the reference features you want to match. Use the new layer created
          for the Input Features To Match parameter.

          * Apply a selection or set a definition query on the original layer so
          it excludes the reference features. This will give you the layer to
          use for the Candidate Features parameter.
      Candidate_Features (Feature Layer):
          The layer (or a selection on a layer) containing candidate matching
          features. The tool will look for features most like (or most dislike)
          the Input_Features_To_Match among these candidates.
      Collapse_Output_To_Points (Boolean):
          When the Input_Features_To_Match and the Candidate_Features are both
          either lines or polygons, you may choose whether you want the geometry
          for the Output_Features to be collapsed to points or to match the
          original geometry (lines or polygons) of the input features. This
          option is only available with an Desktop Advanced license. Choosing
          COLLAPSE for large line or polygon datasets will improve tool
          performance.

          * COLLAPSE-The line and polygon features will be represented as
          feature centroids (points).

          * NO_COLLAPSE-The output geometry will match the line or polygon
          geometry of the input features. This is the default.
      Most_Or_Least_Similar (String):
          Choose whether you are interested in features that are most alike or
          most different to the Input_Features_To_Match.

          * MOST_SIMILAR-Find the features that are most alike.

          * LEAST_SIMILAR-Find the features that are most different.

          * BOTH-Find both the features that are most alike and the features
          that are most different.
      Match_Method (String):
          Choose whether matching should be based on values, ranks, or cosine
          relationships.

          * ATTRIBUTE_VALUES-Similarity or dissimilarity will be based on the
          sum of squared standardized attribute value differences for all the
          Attributes Of Interest.

          * RANKED_ATTRIBUTE_VALUES-Similarity or dissimilarity will be based on
          the sum of squared rank differences for all the Attributes Of
          Interest.

          * ATTRIBUTE_PROFILES-Similarity or dissimilarity will be computed as a
          function of cosine similarity for all the Attributes Of Interest.
      Number_Of_Results (Long):
          The number of solution matches to find. Entering zero or a number
          larger than the total number of Candidate_Features will return
          rankings for all the candidate features.
      Attributes_Of_Interest (Field):
          A list of numeric attributes representing the matching criteria.
      Fields_To_Append_To_Output {Field}:
          An optional list of attributes to include with the Output_Features.
          You might want to include a name identifier, categorical field, or
          date field, for example. These fields are not used to determine
          similarity; they are only included in the Output_Features for your
          reference.

     OUTPUTS:
      Output_Features (Feature Class):
          The output feature class contains a record for each of the
          Input_Features_To_Match and for all the solution-matching features
          found."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SimilaritySearch_stats(*gp_fixargs((Input_Features_To_Match, Candidate_Features, Output_Features, Collapse_Output_To_Points, Most_Or_Least_Similar, Match_Method, Number_Of_Results, Attributes_Of_Interest, Fields_To_Append_To_Output), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SpatiallyConstrainedMultivariateClustering_stats', None)
def SpatiallyConstrainedMultivariateClustering(in_features=None, output_features=None, analysis_fields=None, size_constraints=None, constraint_field=None, min_constraint=None, max_constraint=None, number_of_clusters=None, spatial_constraints=None, weights_matrix_file=None, number_of_permutations=None, output_table=None):
    """SpatiallyConstrainedMultivariateClustering_stats(in_features, output_features, analysis_fields;analysis_fields..., {size_constraints}, {constraint_field}, {min_constraint}, {max_constraint}, {number_of_clusters}, {spatial_constraints}, {weights_matrix_file}, {number_of_permutations}, {output_table})

        Finds spatially contiguous clusters of features based on a set of
        feature attribute values and optional cluster size limits.

     INPUTS:
      in_features (Feature Layer):
          The feature class or feature layer for which you want to create
          clusters.
      analysis_fields (Field):
          A list of fields that will be used to distinguish one cluster from
          another.
      size_constraints {String}:
          Specifies cluster size based on number of features per group or a
          target attribute value per group.

          * NONE-No cluster size constraints will be used. This is the default.

          * NUM_FEATURES-A minimum and maximum number of features per group will
          be used.

          * ATTRIBUTE_VALUE-A minimum and maximum attribute value per group will
          be used.
      constraint_field {Field}:
          The attribute value to be summed per cluster.
      min_constraint {Double}:
          The minimum number of features per cluster or the minimum attribute
          value per cluster. This must be a positive value.
      max_constraint {Double}:
          The maximum number of features per cluster or the maximum attribute
          value per cluster. If a maximum constraint is set, the
          number_of_clusters parameter is disabled. This must be a positive
          value.
      number_of_clusters {Long}:
          The number of clusters to create. If this parameter is empty, the tool
          will evaluate the optimal number of clusters by computing a pseudo
          F-statistic value for clustering solutions with 2 through 30
          clusters.This parameter will be disabled if a maximum number of
          features or
          maximum attribute value has been set.
      spatial_constraints {String}:
          Specifies how spatial relationships among features will be defined.

          * CONTIGUITY_EDGES_ONLY-Clusters will contain contiguous polygon
          features. Only polygons that share an edge can be part of the same
          cluster.

          * CONTIGUITY_EDGES_CORNERS-Clusters will contain contiguous polygon
          features. Only polygons that share an edge or a vertex can be part of
          the same cluster. This is the default for polygon features.

          * TRIMMED_DELAUNAY_TRIANGULATION-Features in the same cluster will
          have at least one natural neighbor in common with another feature in
          the cluster. Natural neighbor relationships are based on a trimmed
          Delaunay triangulation. Conceptually, Delaunay triangulation creates a
          nonoverlapping mesh of triangles from feature centroids. Each feature
          is a triangle node, and nodes that share edges are considered
          neighbors. These triangles are then clipped to a convex hull to ensure
          that features cannot be neighbors with any features outside the convex
          hull. This is the default for point features.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-Spatial, and optionally temporal,
          relationships are defined by a specified spatial weights file (.swm).
          Create the spatial weights matrix using the Generate Spatial Weights
          Matrix or Generate Network Spatial Weights tool. The path to the
          spatial weights file is specified by the Weights_Matrix_File
          parameter.
      weights_matrix_file {File}:
          The path to a file containing spatial weights that define spatial, and
          potentially temporal, relationships among features.
      number_of_permutations {Long}:
          The number of random permutations for the calculation of membership
          stability scores. If 0 (zero) is chosen, probabilities will not be
          calculated. Calculating these probabilities uses permutations of
          random spanning trees and evidence accumulation.This calculation can
          take a significant time to run for larger
          datasets. It is recommended that you iterate and find the optimal
          number of clusters for your analysis first; then calculate
          probabilities for your analysis in a subsequent run. Setting the
          Parallel Processing Factor Environment setting to 50 may improve the
          run time of the tool.

     OUTPUTS:
      output_features (Feature Class):
          The new output feature class created containing all features, the
          analysis fields specified, and a field indicating to which cluster
          each feature belongs.
      output_table {Table}:
          The table created containing the results of the F-statistic values
          calculated to evaluate the optimal number of clusters. The chart
          created from this table can be accessed in the Contents pane under the
          output feature layer."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SpatiallyConstrainedMultivariateClustering_stats(*gp_fixargs((in_features, output_features, analysis_fields, size_constraints, constraint_field, min_constraint, max_constraint, number_of_clusters, spatial_constraints, weights_matrix_file, number_of_permutations, output_table), True)))
        return retval
    except Exception as e:
        raise e


# Measuring Geographic Distributions toolset
@gptooldoc('CentralFeature_stats', None)
def CentralFeature(Input_Feature_Class=None, Output_Feature_Class=None, Distance_Method=None, Weight_Field=None, Self_Potential_Weight_Field=None, Case_Field=None):
    """CentralFeature_stats(Input_Feature_Class, Output_Feature_Class, Distance_Method, {Weight_Field}, {Self_Potential_Weight_Field}, {Case_Field})

        Identifies the most centrally located feature in a point, line, or
        polygon feature class.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class containing a distribution of features from which to
          identify the most centrally located feature.
      Distance_Method (String):
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies)

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block); calculated by summing the
          (absolute) difference between the x- and y-coordinates
      Weight_Field {Field}:
          The numeric field used to weight distances in the origin-destination
          distance matrix.
      Self_Potential_Weight_Field {Field}:
          The field representing self-potential-the distance or weight between a
          feature and itself.
      Case_Field {Field}:
          Field used to group features for separate central feature
          computations. The case field can be of integer, date, or string type.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          The feature class that will contain the most centrally located feature
          in the Input Feature Class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CentralFeature_stats(*gp_fixargs((Input_Feature_Class, Output_Feature_Class, Distance_Method, Weight_Field, Self_Potential_Weight_Field, Case_Field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DirectionalDistribution_stats', None)
def DirectionalDistribution(Input_Feature_Class=None, Output_Ellipse_Feature_Class=None, Ellipse_Size=None, Weight_Field=None, Case_Field=None):
    """DirectionalDistribution_stats(Input_Feature_Class, Output_Ellipse_Feature_Class, Ellipse_Size, {Weight_Field}, {Case_Field})

        Creates standard deviational ellipses or ellipsoids to summarize the
        spatial characteristics of geographic features: central tendency,
        dispersion, and directional trends.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          A feature class containing a distribution of features for which the
          standard deviational ellipse or ellipsoid will be calculated.
      Ellipse_Size (String):
          The size of output ellipses in standard deviations. The default
          ellipse size is 1; valid choices are 1, 2, or 3 standard deviations.

          * 1_STANDARD_DEVIATION-1 standard deviation

          * 2_STANDARD_DEVIATIONS-2 standard deviations

          * 3_STANDARD_DEVIATIONS-3 standard deviations
      Weight_Field {Field}:
          The numeric field used to weight locations according to their relative
          importance.
      Case_Field {Field}:
          The field used to group features for separate directional distribution
          calculations. The case field can be of integer, date, or string type.

     OUTPUTS:
      Output_Ellipse_Feature_Class (Feature Class):
          A polygon feature class that will contain the output ellipse feature."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DirectionalDistribution_stats(*gp_fixargs((Input_Feature_Class, Output_Ellipse_Feature_Class, Ellipse_Size, Weight_Field, Case_Field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DirectionalMean_stats', None)
def DirectionalMean(Input_Feature_Class=None, Output_Feature_Class=None, Orientation_Only=None, Case_Field=None):
    """DirectionalMean_stats(Input_Feature_Class, Output_Feature_Class, Orientation_Only, {Case_Field})

        Identifies the mean direction, length, and geographic center for a set
        of lines.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class containing vectors for which the mean direction will
          be calculated.
      Orientation_Only (Boolean):
          Specifies whether to include direction (From and To nodes) information
          in the analysis.

          * DIRECTION-The From and To nodes are utilized in calculating the
          mean. This is the default.

          * ORIENTATION_ONLY-The From and To node information is ignored.
      Case_Field {Field}:
          Field used to group features for separate directional mean
          calculations. The case field can be of integer, date, or string type.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          A line feature class that will contain the features representing the
          mean directions of the input feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DirectionalMean_stats(*gp_fixargs((Input_Feature_Class, Output_Feature_Class, Orientation_Only, Case_Field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MeanCenter_stats', None)
def MeanCenter(Input_Feature_Class=None, Output_Feature_Class=None, Weight_Field=None, Case_Field=None, Dimension_Field=None):
    """MeanCenter_stats(Input_Feature_Class, Output_Feature_Class, {Weight_Field}, {Case_Field}, {Dimension_Field})

        Identifies the geographic center (or the center of concentration) for
        a set of features.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          A feature class for which the mean center will be calculated.
      Weight_Field {Field}:
          The numeric field used to create a weighted mean center.
      Case_Field {Field}:
          Field used to group features for separate mean center calculations.
          The case field can be of integer, date, or string type.
      Dimension_Field {Field}:
          A numeric field containing attribute values from which an average
          value will be calculated.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          A point feature class that will contain the features representing the
          mean centers of the input feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MeanCenter_stats(*gp_fixargs((Input_Feature_Class, Output_Feature_Class, Weight_Field, Case_Field, Dimension_Field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MedianCenter_stats', None)
def MedianCenter(Input_Feature_Class=None, Output_Feature_Class=None, Weight_Field=None, Case_Field=None, Attribute_Field=None):
    """MedianCenter_stats(Input_Feature_Class, Output_Feature_Class, {Weight_Field}, {Case_Field}, {Attribute_Field;Attribute_Field...})

        Identifies the location that minimizes overall Euclidean distance to
        the features in a dataset.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          A feature class for which the median center will be calculated.
      Weight_Field {Field}:
          The numeric field used to create a weighted median center.
      Case_Field {Field}:
          Field used to group features for separate median center calculations.
          The case field can be of integer, date, or string type.
      Attribute_Field {Field}:
          Numeric field(s) for which the data median value will be computed.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          A point feature class that will contain the features representing the
          median centers of the input feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MedianCenter_stats(*gp_fixargs((Input_Feature_Class, Output_Feature_Class, Weight_Field, Case_Field, Attribute_Field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StandardDistance_stats', None)
def StandardDistance(Input_Feature_Class=None, Output_Standard_Distance_Feature_Class=None, Circle_Size=None, Weight_Field=None, Case_Field=None):
    """StandardDistance_stats(Input_Feature_Class, Output_Standard_Distance_Feature_Class, Circle_Size, {Weight_Field}, {Case_Field})

        Measures the degree to which features are concentrated or dispersed
        around the geometric mean center.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          A feature class containing a distribution of features for which the
          standard distance will be calculated.
      Circle_Size (String):
          The size of output circles in standard deviations. The default circle
          size is 1; valid choices are 1, 2, or 3 standard deviations.

          * 1_STANDARD_DEVIATION-1 standard deviation

          * 2_STANDARD_DEVIATIONS-2 standard deviations

          * 3_STANDARD_DEVIATIONS-3 standard deviations
      Weight_Field {Field}:
          The numeric field used to weight locations according to their relative
          importance.
      Case_Field {Field}:
          Field used to group features for separate standard distance
          calculations. The case field can be of integer, date, or string type.

     OUTPUTS:
      Output_Standard_Distance_Feature_Class (Feature Class):
          A polygon feature class that will contain a circle polygon for each
          input center. These circle polygons graphically portray the standard
          distance at each center point."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StandardDistance_stats(*gp_fixargs((Input_Feature_Class, Output_Standard_Distance_Feature_Class, Circle_Size, Weight_Field, Case_Field), True)))
        return retval
    except Exception as e:
        raise e


# Modeling Spatial Relationships toolset
@gptooldoc('ColocationAnalysis_stats', None)
def ColocationAnalysis(input_type=None, in_features_of_interest=None, output_features=None, field_of_interest=None, time_field_of_interest=None, category_of_interest=None, input_feature_for_comparison=None, field_for_comparison=None, time_field_for_comparison=None, category_for_comparison=None, neighborhood_type=None, number_of_neighbors=None, distance_band=None, weights_matrix_file=None, temporal_relationship_type=None, time_step_interval=None, number_of_permutations=None, local_weighting_scheme=None, output_table=None):
    """ColocationAnalysis_stats(input_type, in_features_of_interest, output_features, {field_of_interest}, {time_field_of_interest}, {category_of_interest}, {input_feature_for_comparison}, {field_for_comparison}, {time_field_for_comparison}, {category_for_comparison}, {neighborhood_type}, {number_of_neighbors}, {distance_band}, {weights_matrix_file}, {temporal_relationship_type}, {time_step_interval}, {number_of_permutations}, {local_weighting_scheme}, {output_table})

        Measures local patterns of spatial association, or colocation, between
        two categories of point features using the colocation quotient
        statistic.

     INPUTS:
      input_type (String):
          Specifies whether the in_features_of_interest will come from the same
          dataset with specified categories, different datasets with specified
          categories, or different datasets that will be treated as their own
          category (for example, one dataset with all points representing
          cheetahs and a second dataset in which all points represent gazelles).

          * SINGLE_DATASET-The categories to be analyzed exist within a field in
          a single dataset.

          * TWO_DATASETS-The categories to be analyzed exist in fields of
          separate datasets.

          * DATASETS_WITHOUT_CATEGORIES-Two separate datasets representing two
          categories will be analyzed.
      in_features_of_interest (Feature Layer):
          The feature class containing points with representative categories.
      field_of_interest {Field}:
          The field containing the category or categories to be analyzed.
      time_field_of_interest {Field}:
          A date field with an optional time stamp for each feature to analyze
          points using a space time window. Features near each other in space
          and time will be considered neighbors and will be analyzed together.
      category_of_interest {String}:
          The base category for the analysis. The tool will determine, for each
          category_of_interest, the degree to which the base category is
          attracted to or colocated with the neighboring_category.
      input_feature_for_comparison {Feature Layer}:
          The input feature class containing the points with the categories that
          will be compared.
      field_for_comparison {Field}:
          The field from the input_feature_for_comparison containing the
          category to be compared.
      time_field_for_comparison {Field}:
          A date field with a time stamp for each feature to analyze your points
          using a space time window. Features near each other in space and time
          will be considered neighbors and will be analyzed together.
      category_for_comparison {String}:
          The neighboring category for the analysis. The tool will determine the
          degree to which the category_of_interest is attracted to or isolated
          from the category_for_comparison.
      neighborhood_type {String}:
          Specifies how the spatial relationships among features are defined.

          * DISTANCE_BAND-Each feature is analyzed within the context of
          neighboring features. Neighboring features inside the specified
          critical distance specified by the distance_band parameter receive a
          weight of one and exert influence on computations for the target
          feature. Neighboring features outside the critical distance receive a
          weight of zero and have no influence on a target feature's
          computations.

          * K_NEAREST_NEIGHBORS-The closest k features are included in the
          analysis as neighbors. The number of neighbors is specified by the
          number_of_neighbors parameter. The neighbor's influence in the
          analysis is weighted based on the distance to the farthest neighbor.
          This is the default.

          * GET_SPATIAL_WEIGHTS_FROM_FILE-When SINGLE_DATASET is used as the
          input_type, spatial relationships can be defined by a specified
          spatial weights matrix file. The neighbor's influence in the analysis
          is weighted based on the distance to the farthest neighbor. The path
          to the spatial weights file is specified by the weights_matrix_file
          parameter.
      number_of_neighbors {Long}:
          The number of neighbors around each feature that will be used to test
          for local relationships between categories. If left blank, the default
          is 8. The provided value should be large enough to detect the
          relationships between features, but small enough to still identify
          local patterns.
      distance_band {Linear Unit}:
          The neighborhood size is a constant or fixed distance for each
          feature. All features within this distance will be used to test for
          local relationships between categories. If left empty, the distance
          used will be the average distance at which each feature has at least
          eight neighbors.
      weights_matrix_file {File}:
          The path to a file containing weights that define spatial, and
          potentially temporal, relationships among features.
      temporal_relationship_type {String}:
          Specifies how temporal relationships among features are defined.

          * BEFORE-The time window extends back in time for each of the
          in_features_of_interest. Neighboring features must have a date/time
          stamp that occurs before the date/time stamp of the feature of
          interest to be included in the analysis. This is the default.

          * AFTER-The time window extends forward in time for each of the
          in_features_of_interest. Neighboring features must have a date/time
          stamp that occurs after the date/time stamp of the feature of interest
          to be included in the analysis.

          * SPAN-The time window extends both back and forward in time for each
          of the in_features_of_interest. Neighboring features that have a
          date/time stamp that occurs within the time_step_interval before or
          after the date/time stamp of the feature of interest will be included
          in the analysis. For example, if the time_step_interval is set to 1
          week, the window will look 1 week before and 1 week after the target
          feature.
      time_step_interval {Time Unit}:
          An integer and unit of measurement representing the number of time
          units composing the time window.
      number_of_permutations {Long}:
          This analysis uses permutations to create a reference distribution.
          Choosing the number of permutations is a balance between precision and
          increased processing time. Choose your preference of speed versus
          precision. More robust and precise results take longer to calculate.

          * 99-With 99 permutations, the smallest possible pseudo p-value is
          0.02, and all other pseudo p-values will be multiples of this value.
          This is the default.

          * 199-With 199 permutations, the smallest possible pseudo p-value is
          0.01 and all other pseudo p-values will be even multiples of this
          value.

          * 499-With 499 permutations, the smallest possible pseudo p-value is
          0.004 and all other pseudo p-values will be even multiples of this
          value.

          * 999-With 999 permutations, the smallest possible pseudo p-value is
          0.002 and all other pseudo p-values will be even multiples of this
          value.

          * 9999-With 9999 permutations, the smallest possible pseudo p-value is
          0.0002 and all other pseudo p-values will be even multiples of this
          value.
      local_weighting_scheme {String}:
          Specifies the kernel type that will be used to provide the spatial
          weighting. The kernel defines how each feature is related to other
          features within its neighborhood.

          * BISQUARE-Features are weighted based on the distance to the farthest
          neighbor or the edge of the distance band, and a weight of 0 will be
          assigned to any feature outside the neighborhood specified.

          * GAUSSIAN-Features are weighted based on the distance to the farthest
          neighbor or the edge of the distance band but drop off more quickly
          than Bisquare. A weight of 0 will be assigned to any feature outside
          the neighborhood specified. This is the default.

          * NONE-No weighting scheme is applied, and all features within the
          neighborhood are given a weight of 1 and contribute equally. All
          features outside the neighborhood are given a weight of 0.

     OUTPUTS:
      output_features (Feature Class):
          The output feature class containing all the in_features with fields
          representing the local colocation quotient scores and p-values.
      output_table {Table}:
          When a value is specified for this parameter, a table is produced to
          show the global colocation quotients between all the categories in the
          Field of Interest and all the categories in the Field Containing the
          Neighboring Category. This table can be used in an exploratory manner
          to help you determine the local categories to analyze.If Datasets
          without categories is used as the Input Type, global
          colocation quotients are calculated for each dataset against each
          other and also against itself."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ColocationAnalysis_stats(*gp_fixargs((input_type, in_features_of_interest, output_features, field_of_interest, time_field_of_interest, category_of_interest, input_feature_for_comparison, field_for_comparison, time_field_for_comparison, category_for_comparison, neighborhood_type, number_of_neighbors, distance_band, weights_matrix_file, temporal_relationship_type, time_step_interval, number_of_permutations, local_weighting_scheme, output_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExploratoryRegression_stats', None)
def ExploratoryRegression(Input_Features=None, Dependent_Variable=None, Candidate_Explanatory_Variables=None, Weights_Matrix_File=None, Output_Report_File=None, Output_Results_Table=None, Maximum_Number_of_Explanatory_Variables=None, Minimum_Number_of_Explanatory_Variables=None, Minimum_Acceptable_Adj_R_Squared=None, Maximum_Coefficient_p_value_Cutoff=None, Maximum_VIF_Value_Cutoff=None, Minimum_Acceptable_Jarque_Bera_p_value=None, Minimum_Acceptable_Spatial_Autocorrelation_p_value=None):
    """ExploratoryRegression_stats(Input_Features, Dependent_Variable, Candidate_Explanatory_Variables;Candidate_Explanatory_Variables..., {Weights_Matrix_File}, {Output_Report_File}, {Output_Results_Table}, {Maximum_Number_of_Explanatory_Variables}, {Minimum_Number_of_Explanatory_Variables}, {Minimum_Acceptable_Adj_R_Squared}, {Maximum_Coefficient_p_value_Cutoff}, {Maximum_VIF_Value_Cutoff}, {Minimum_Acceptable_Jarque_Bera_p_value}, {Minimum_Acceptable_Spatial_Autocorrelation_p_value})

        The Exploratory Regression tool evaluates all possible combinations of
        the input candidate explanatory variables, looking for OLS models that
        best explain the dependent variable within the context of user-
        specified criteria.

     INPUTS:
      Input_Features (Feature Layer):
          The feature class or feature layer containing the dependent and
          candidate explanatory variables to analyze.
      Dependent_Variable (Field):
          The numeric field containing the observed values you want to model
          using OLS.
      Candidate_Explanatory_Variables (Field):
          A list of fields to try as OLS model explanatory variables.
      Weights_Matrix_File {File}:
          A file containing spatial weights that define the spatial
          relationships among your input features. This file is used to assess
          spatial autocorrelation among regression residuals. You can use the
          Generate Spatial Weights Matrix File tool to create this. When you do
          not provide a spatial weights matrix file, residuals are assessed for
          spatial autocorrelation based on each feature's 8 nearest
          neighbors.Note: The spatial weights matrix file is only used to
          analyze spatial
          structure in model residuals; it is not used to build or to calibrate
          any of the OLS models.
      Maximum_Number_of_Explanatory_Variables {Long}:
          All models with explanatory variables up to the value entered here
          will be assessed. If, for example, the
          Minimum_Number_of_Explanatory_Variables is 2 and the
          Maximum_Number_of_Explanatory_Variables is 3, the Exploratory
          Regression tool will try all models with every combination of two
          explanatory variables, and all models with every combination of three
          explanatory variables.
      Minimum_Number_of_Explanatory_Variables {Long}:
          This value represents the minimum number of explanatory variables for
          models evaluated. If, for example, the
          Minimum_Number_of_Explanatory_Variables is 2 and the
          Maximum_Number_of_Explanatory_Variables is 3, the Exploratory
          Regression tool will try all models with every combination of two
          explanatory variables, and all models with every combination of three
          explanatory variables.
      Minimum_Acceptable_Adj_R_Squared {Double}:
          This is the lowest Adjusted R-Squared value you consider a passing
          model. If a model passes all of your other search criteria, but has an
          Adjusted R-Squared value smaller than the value entered here, it will
          not show up as a Passing Model in the Output_Report_File. Valid values
          for this parameter range from 0.0 to 1.0. The default value is 0.5,
          indicating that passing models will explain at least fifty percent of
          the variation in the dependent variable.
      Maximum_Coefficient_p_value_Cutoff {Double}:
          For each model evaluated, OLS computes explanatory variable
          coefficient p-values. The cutoff p-value you enter here represents the
          confidence level you require for all coefficients in the model in
          order to consider the model passing. Small p-values reflect a stronger
          confidence level. Valid values for this parameter range from 1.0 down
          to 0.0, but will most likely be 0.1, 0.05, 0.01, 0.001, and so on. The
          default value is 0.05, indicating passing models will only contain
          explanatory variables whose coefficients are statistically at the 95
          percent confidence level (p-values smaller than 0.05). To relax this
          default you would enter a larger p-value cutoff, such as 0.1. If you
          are getting lots of passing models, you will likely want to make this
          search criteria more stringent by decreasing the default p-value
          cutoff from 0.05 to 0.01 or smaller.
      Maximum_VIF_Value_Cutoff {Double}:
          This value reflects how much redundancy (multicollinearity) among
          model explanatory variables you will tolerate. When the VIF (Variance
          Inflation Factor) value is higher than about 7.5, multicollinearity
          can make a model unstable; consequently, 7.5 is the default value
          here. If you want your passing models to have less redundancy, you
          would enter a smaller value, such as 5.0, for this parameter.
      Minimum_Acceptable_Jarque_Bera_p_value {Double}:
          The p-value returned by the Jarque-Bera diagnostic test indicates
          whether the model residuals are normally distributed. If the p-value
          is statistically significant (small), the model residuals are not
          normal and the model is biased. Passing models should have large
          Jarque-Bera p-values. The default minimum acceptable p-value is 0.1.
          Only models returning p-values larger than this minimum will be
          considered passing. If you are having trouble finding unbiased passing
          models, and decide to relax this criterion, you might enter a smaller
          minimum p-value such as 0.05.
      Minimum_Acceptable_Spatial_Autocorrelation_p_value {Double}:
          For models that pass all of the other search criteria, the Exploratory
          Regression tool will check model residuals for spatial clustering
          using Global Moran's I. When the p-value for this diagnostic test is
          statistically significant (small), it indicates the model is very
          likely missing key explanatory variables (it isn't telling the whole
          story). Unfortunately, if you have spatial autocorrelation in your
          regression residuals, your model is misspecified, so you cannot trust
          your results. Passing models should have large p-values for this
          diagnostic test. The default minimum p-value is 0.1. Only models
          returning p-values larger than this minimum will be considered
          passing. If you are having trouble finding properly specified models
          because of this diagnostic test, and decide to relax this search
          criteria, you might enter a smaller minimum such as 0.05.

     OUTPUTS:
      Output_Report_File {File}:
          The report file contains tool results, including details about any
          models found that passed all the search criteria you entered. This
          output file also contains diagnostics to help you fix common
          regression problems in the case that you don't find any passing
          models.
      Output_Results_Table {Table}:
          The optional output table created containing the explanatory variables
          and diagnostics for all of the models within the Coefficient p-value
          and VIF value cutoffs."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExploratoryRegression_stats(*gp_fixargs((Input_Features, Dependent_Variable, Candidate_Explanatory_Variables, Weights_Matrix_File, Output_Report_File, Output_Results_Table, Maximum_Number_of_Explanatory_Variables, Minimum_Number_of_Explanatory_Variables, Minimum_Acceptable_Adj_R_Squared, Maximum_Coefficient_p_value_Cutoff, Maximum_VIF_Value_Cutoff, Minimum_Acceptable_Jarque_Bera_p_value, Minimum_Acceptable_Spatial_Autocorrelation_p_value), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Forest_stats', None)
def Forest(prediction_type=None, in_features=None, variable_predict=None, treat_variable_as_categorical=None, explanatory_variables=None, distance_features=None, explanatory_rasters=None, features_to_predict=None, output_features=None, output_raster=None, explanatory_variable_matching=None, explanatory_distance_matching=None, explanatory_rasters_matching=None, output_trained_features=None, output_importance_table=None, use_raster_values=None, number_of_trees=None, minimum_leaf_size=None, maximum_depth=None, sample_size=None, random_variables=None, percentage_for_training=None, output_classification_table=None, output_validation_table=None, compensate_sparse_categories=None, number_validation_runs=None, calculate_uncertainty=None):
    """Forest_stats(prediction_type, in_features, {variable_predict}, {treat_variable_as_categorical}, {explanatory_variables;explanatory_variables...}, {distance_features;distance_features...}, {explanatory_rasters;explanatory_rasters...}, {features_to_predict}, {output_features}, {output_raster}, {explanatory_variable_matching;explanatory_variable_matching...}, {explanatory_distance_matching;explanatory_distance_matching...}, {explanatory_rasters_matching;explanatory_rasters_matching...}, {output_trained_features}, {output_importance_table}, {use_raster_values}, {number_of_trees}, {minimum_leaf_size}, {maximum_depth}, {sample_size}, {random_variables}, {percentage_for_training}, {output_classification_table}, {output_validation_table}, {compensate_sparse_categories}, {number_validation_runs}, {calculate_uncertainty})

        Creates models and generates predictions using an adaptation of Leo
        Breiman's random forest algorithm, which is a supervised machine
        learning method. Predictions can be performed for both categorical
        variables (classification) and continuous variables (regression).
        Explanatory variables can take the form of fields in the attribute
        table of the training features, raster datasets, and distance features
        used to calculate proximity values for use as additional variables. In
        addition to validation of model performance based on the training
        data, predictions can be made to either features or a prediction
        raster.

     INPUTS:
      prediction_type (String):
          Specifies the operation mode of the tool. The tool can be run to train
          a model to only assess performance, predict features, or create a
          prediction surface.

          * TRAIN-A model will be trained, but no predictions will be generated.
          Use this option to assess the accuracy of your model before generating
          predictions. This option will output model diagnostics in the messages
          window and a chart of variable importance. This is the default

          * PREDICT_FEATURES-Predictions or classifications will be generated
          for features. Explanatory variables must be provided for both the
          training features and the features to be predicted. The output of this
          option will be a feature class, model diagnostics in the messages
          window, and an optional table and chart of variable importance.

          * PREDICT_RASTER-A prediction raster will be generated for the area
          where the explanatory rasters intersect. Explanatory rasters must be
          provided for both the training area and the area to be predicted. The
          output of this option will be a prediction surface, model diagnostics
          in the messages window, and an optional table and chart of variable
          importance.
      in_features (Feature Layer):
          The feature class containing the variable_predict parameter and,
          optionally, the explanatory training variables from fields.
      variable_predict {Field}:
          The variable from the in_features parameter containing the values to
          be used to train the model. This field contains known (training)
          values of the variable that will be used to predict at unknown
          locations.
      treat_variable_as_categorical {Boolean}:
          * CATEGORICAL-The variable_predict is a categorical variable and the
          tool will perform classification.

          * NUMERIC-The variable_predict is continuous and the tool will perform
          regression. This is the default
      explanatory_variables {Value Table}:
          A list of fields representing the explanatory variables that help
          predict the value or category of the variable_predict. Use the
          treat_variable_as_categorical parameter for any variables that
          represent classes or categories (such as land cover or presence or
          absence). Specify the variable as true for any that represent classes
          or categories such as land cover or presence or absence and false if
          the variable is continuous.
      distance_features {Feature Layer}:
          Automatically creates explanatory variables by calculating a distance
          from the provided features to the in_features. Distances will be
          calculated from each of the input distance_features to the nearest
          in_features. If the input distance_features are polygons or lines, the
          distance attributes are calculated as the distance between the closest
          segments of the pair of features.
      explanatory_rasters {Value Table}:
          Automatically creates explanatory training variables in your model
          whose values are extracted from rasters. For each feature in the
          in_features, the value of the raster cell is extracted at that exact
          location. Bilinear raster resampling is used when extracting the
          raster value unless it is specified as categorical, in which case
          nearest neighbor assignment is used. Specify the raster as true for
          any rasters that represent classes or categories such as land cover or
          presence or absence and false if the raster is continuous.
      features_to_predict {Feature Layer}:
          A feature class representing locations where predictions will be made.
          This feature class must also contain any explanatory variables
          provided as fields that correspond to those used from the training
          data if any.
      explanatory_variable_matching {Value Table}:
          A list of the explanatory_variables specified from the in_features on
          the right and their corresponding fields from the features_to_predict
          on the left, for example, [["LandCover2000", "LandCover2010"],
          ["Income", "PerCapitaIncome"]].
      explanatory_distance_matching {Value Table}:
          A list of the distance_features specified for the in_features on the
          right. Corresponding feature sets should be specified for the
          features_to_predict on the left.explanatory_distance_features that are
          more appropriate for the
          features_to_predict can be provided if those used for training are in
          a different study area or time period.
      explanatory_rasters_matching {Value Table}:
          A list of the explanatory_rasters specified for the in_features on the
          right. Corresponding rasters should be specified for the
          features_to_predict or output_raster to be created on the
          left.explanatory_rasters that are more appropriate for the
          features_to_predict can be provided if those used for training are in
          a different study area or time period.
      use_raster_values {Boolean}:
          Specifies how polygons are treated when training the model if the
          in_features are polygons with a categorical variable_predict and only
          explanatory_rasters have been specified.

          * TRUE-The polygon is divided into all of the raster cells with
          centroids falling within the polygon. The raster values at each
          centroid are then extracted and used to train the model. The model is
          no longer trained on the polygon itself, but rather the model is
          trained on the raster values extracted for each cell centroid. This is
          the default.

          * FALSE-Each polygon is assigned the average value of the underlying
          continuous rasters and the majority for underlying categorical
          rasters.
      number_of_trees {Long}:
          The number of trees to create in the forest model. More trees will
          generally result in more accurate model prediction, but the model will
          take longer to calculate. The default number of trees is 100.
      minimum_leaf_size {Long}:
          The minimum number of observations required to keep a leaf (that is
          the terminal node on a tree without further splits). The default
          minimum for regression is 5 and the default for classification is 1.
          For very large data, increasing these numbers will decrease the run
          time of the tool.
      maximum_depth {Long}:
          The maximum number of splits that will be made down a tree. Using a
          large maximum depth, more splits will be created, which may increase
          the chances of overfitting the model. The default is data driven and
          depends on the number of trees created and the number of variables
          included.
      sample_size {Long}:
          Specifies the percentage of the in_features used for each decision
          tree. The default is 100 percent of the data. Samples for each tree
          are taken randomly from two-thirds of the data specified.Each decision
          tree in the forest is created using a random sample or
          subset (approximately two-thirds) of the training data available.
          Using a lower percentage of the input data for each decision tree
          increases the speed of the tool for very large datasets.
      random_variables {Long}:
          Specifies the number of explanatory variables used to create each
          decision tree.Each of the decision trees in the forest is created
          using a random
          subset of the explanatory variables specified. Increasing the number
          of variables used in each decision tree will increase the chances of
          overfitting your model particularly if there is one or a couple
          dominant variables. A common practice is to use the square root of the
          total number of explanatory variables (fields, distances, and rasters
          combined) if your variable_predict is numeric or divide the total
          number of explanatory variables (fields, distances, and rasters
          combined) by 3 if variable_predict is categorical.
      percentage_for_training {Double}:
          Specifies the percentage (between 10 percent and 50 percent) of
          in_features to reserve as the test dataset for validation. The model
          will be trained without this random subset of data, and the observed
          values for those features will be compared to the predicted value. The
          default is 10 percent.
      compensate_sparse_categories {Boolean}:
          If there are categories in your dataset that don't occur as often as
          others, checking this parameter will ensure that each category is
          represented in each tree.

          * TRUE-Each tree will include every category that is represented in
          the training dataset.

          * FALSE-Each tree will be created based on a random sample of the
          training dataset. This is the default.
      number_validation_runs {Long}:
          The tool will run for the number of iterations specified. The
          distribution of the R2 for each run can be displayed using the Output
          Validation Table parameter. When this is set and predictions are being
          generated, only the model that produced the highest R2 value will be
          used for predictions.
      calculate_uncertainty {Boolean}:
          Specifies whether prediction uncertainty will be calculated when
          training, predicting to features, or predicting to raster.

          * TRUE-A prediction uncertainty interval will be calculated.

          * FALSE-Uncertainty will not be calculated. This is the default.

     OUTPUTS:
      output_features {Feature Class}:
          The output feature class to receive the results of the prediction
          results.
      output_raster {Raster Dataset}:
          The output raster containing the prediction results. The default cell
          size will be the maximum cell size of the raster inputs. To set a
          different cell size, use the cell size environment setting.
      output_trained_features {Feature Class}:
          output_trained_features will contain all explanatory variables used
          for training (including sampled raster values and distance
          calculations), as well as the observed variable_to_predict field and
          accompanying predictions that can be used to further assess
          performance of the trained model.
      output_importance_table {Table}:
          If specified, the table will contain information describing the
          importance of each explanatory variable (fields, distance features,
          and rasters) used in the model created.
      output_classification_table {Table}:
          If specified, creates a confusion matrix for classification
          summarizing the performance of the model created. This table can be
          used to calculate other diagnostics beyond the accuracy and
          sensitivity measures the tool calculates in the output messages.
      output_validation_table {Table}:
          If the Number of Runs for Validation specified is greater than 2, this
          table creates a chart of the distribution of R2 for each model. This
          distribution can be used to assess the stability of your model."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Forest_stats(*gp_fixargs((prediction_type, in_features, variable_predict, treat_variable_as_categorical, explanatory_variables, distance_features, explanatory_rasters, features_to_predict, output_features, output_raster, explanatory_variable_matching, explanatory_distance_matching, explanatory_rasters_matching, output_trained_features, output_importance_table, use_raster_values, number_of_trees, minimum_leaf_size, maximum_depth, sample_size, random_variables, percentage_for_training, output_classification_table, output_validation_table, compensate_sparse_categories, number_validation_runs, calculate_uncertainty), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GWR_stats', None)
def GWR(in_features=None, dependent_variable=None, model_type=None, explanatory_variables=None, output_features=None, neighborhood_type=None, neighborhood_selection_method=None, minimum_number_of_neighbors=None, maximum_number_of_neighbors=None, minimum_search_distance=None, maximum_search_distance=None, number_of_neighbors_increment=None, search_distance_increment=None, number_of_increments=None, number_of_neighbors=None, distance_band=None, prediction_locations=None, explanatory_variables_to_match=None, output_predicted_features=None, robust_prediction=None, local_weighting_scheme=None, coefficient_raster_workspace=None):
    """GWR_stats(in_features, dependent_variable, model_type, explanatory_variables;explanatory_variables..., output_features, neighborhood_type, neighborhood_selection_method, {minimum_number_of_neighbors}, {maximum_number_of_neighbors}, {minimum_search_distance}, {maximum_search_distance}, {number_of_neighbors_increment}, {search_distance_increment}, {number_of_increments}, {number_of_neighbors}, {distance_band}, {prediction_locations}, {explanatory_variables_to_match;explanatory_variables_to_match...}, {output_predicted_features}, {robust_prediction}, {local_weighting_scheme}, {coefficient_raster_workspace})

        Performs Geographically Weighted Regression (GWR), which is a local
        form of linear regression that is used to model spatially varying
        relationships.This tool was added at ArcGIS Pro 2.3 to replace the
        similar but now
        deprecated Geographically Weighted Regression (GWR) tool. This new
        tool includes improvements to the method developed over the past
        several years and supports additional models.

     INPUTS:
      in_features (Feature Layer):
          The feature class containing the dependent and explanatory variables.
      dependent_variable (Field):
          The numeric field containing the observed values that will be modeled.
      model_type (String):
          Specifies the type of data that will be modeled.

          * CONTINUOUS-The dependent_variable value is continuous. The Gaussian
          model will be used, and the tool will perform ordinary least squares
          regression.

          * BINARY-The dependent_variable value represents presence or absence.
          This can be either conventional 1s and 0s or continuous data that has
          been coded based on a threshold value. The Logistic regression model
          will be used.

          * COUNT-The dependent_variable value is discrete and represents
          events, such as crime counts, disease incidents, or traffic accidents.
          The Poisson regression model will be used.
      explanatory_variables (Field):
          A list of fields representing independent explanatory variables in the
          regression model.
      neighborhood_type (String):
          Specifies whether the neighborhood used is constructed as a fixed
          distance or allowed to vary in spatial extent depending on the density
          of the features.

          * NUMBER_OF_NEIGHBORS-The neighborhood size is a function of a
          specified number of neighbors included in calculations for each
          feature. Where features are dense, the spatial extent of the
          neighborhood is smaller; where features are sparse, the spatial extent
          of the neighborhood is larger.

          * DISTANCE_BAND-The neighborhood size is a constant or fixed distance
          for each feature.
      neighborhood_selection_method (String):
          Specifies how the neighborhood size will be determined. The
          neighborhood selected with the GOLDEN_SEARCH and MANUAL_INTERVALS
          options is based on minimizing the AICc value.

          * GOLDEN_SEARCH-The tool will identify an optimal distance or number
          of neighbors based on the characteristics of the data using the golden
          section search method.

          * MANUAL_INTERVALS-The neighborhoods tested will be defined by the
          values specified in the minimum_number_of_neighbors and
          number_of_neighbors_increment parameters when NUMBER_OF_NEIGHBORS is
          chosen for the neighborhood_type parameter, or the
          minimum_search_distance and search_distance_increment parameters when
          DISTANCE_BAND is chosen for the neighborhood_type parameter, as well
          as the number_of_increments parameter.

          * USER_DEFINED-The neighborhood size will be specified by either the
          number_of_neighbors or distance_band parameter.
      minimum_number_of_neighbors {Long}:
          The minimum number of neighbors each feature will include in its
          calculations. It is recommended that you use at least 30 neighbors.
      maximum_number_of_neighbors {Long}:
          The maximum number of neighbors (up to 1000) each feature will include
          in its calculations.
      minimum_search_distance {Linear Unit}:
          The minimum neighborhood search distance. It is recommended that you
          use a distance at which each feature has at least 30 neighbors.
      maximum_search_distance {Linear Unit}:
          The maximum neighborhood search distance. If a distance results in
          features with more than 1000 neighbors, the tool will use the first
          1000 in calculations for the target feature.
      number_of_neighbors_increment {Long}:
          The number of neighbors by which manual intervals will increase for
          each neighborhood test.
      search_distance_increment {Linear Unit}:
          The distance by which manual intervals will increase for each
          neighborhood test.
      number_of_increments {Long}:
          The number of neighborhood sizes to test starting with the
          minimum_number_of_neighbors or minimum_search_distance parameter.
      number_of_neighbors {Long}:
          The closest number of neighbors (up to 1000) to consider for each
          feature. The number must be an integer between 2 and 1000.
      distance_band {Linear Unit}:
          The spatial extent of the neighborhood.
      prediction_locations {Feature Layer}:
          A feature class containing features representing locations where
          estimates will be computed. Each feature in this dataset should
          contain values for all the explanatory variables specified. The
          dependent variable for these features will be estimated using the
          model calibrated for the input feature class data. To be predicted,
          these feature locations should be within the same study area as the
          in_features or be close (within the extent plus 15 percent).A feature
          class containing features representing locations where
          estimates will be computed. Each feature in this dataset should
          contain values for all the explanatory variables specified. The
          dependent variable for these features will be estimated using the
          model calibrated for the input feature class data. To be predicted,
          these feature locations should be within the same study area as the
          Input Features or be close (within the extent plus 15 percent).
      explanatory_variables_to_match {Value Table}:
          The explanatory variables from the prediction_locations parameter that
          match corresponding explanatory variables from the in_features
          parameter. [["LandCover2000", "LandCover2010"], ["Income",
          "PerCapitaIncome"]] are examples.
      robust_prediction {Boolean}:
          Specifies the features that will be used in prediction calculations.

          * ROBUST-Features with values more than three standard deviations from
          the mean (value outliers) and features with weights of 0 (spatial
          outliers) will be excluded from prediction calculations but will
          receive predictions in the output feature class. This is the default.

          * NON_ROBUST-All features will be used in prediction calculations
      local_weighting_scheme {String}:
          Specifies the kernel type that will be used to provide the spatial
          weighting in the model. The kernel defines how each feature is related
          to other features within its neighborhood.

          * BISQUARE-A weight of 0 will be assigned to any feature outside the
          neighborhood specified. This is the default.

          * GAUSSIAN-All features will receive weights, but weights become
          exponentially smaller the farther away they are from the target
          feature.
      coefficient_raster_workspace {Workspace}:
          The workspace where the coefficient rasters will be created. When this
          workspace is provided, rasters are created for the intercept and every
          explanatory variable.

     OUTPUTS:
      output_features (Feature Class):
          The new feature class containing the dependent variable estimates and
          residuals.
      output_predicted_features {Feature Class}:
          The output feature class that will receive dependent variable
          estimates for each prediction_location."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GWR_stats(*gp_fixargs((in_features, dependent_variable, model_type, explanatory_variables, output_features, neighborhood_type, neighborhood_selection_method, minimum_number_of_neighbors, maximum_number_of_neighbors, minimum_search_distance, maximum_search_distance, number_of_neighbors_increment, search_distance_increment, number_of_increments, number_of_neighbors, distance_band, prediction_locations, explanatory_variables_to_match, output_predicted_features, robust_prediction, local_weighting_scheme, coefficient_raster_workspace), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeneralizedLinearRegression_stats', None)
def GeneralizedLinearRegression(in_features=None, dependent_variable=None, model_type=None, output_features=None, explanatory_variables=None, distance_features=None, prediction_locations=None, explanatory_variables_to_match=None, explanatory_distance_matching=None, output_predicted_features=None):
    """GeneralizedLinearRegression_stats(in_features, dependent_variable, model_type, output_features, {explanatory_variables;explanatory_variables...}, {distance_features;distance_features...}, {prediction_locations}, {explanatory_variables_to_match;explanatory_variables_to_match...}, {explanatory_distance_matching;explanatory_distance_matching...}, {output_predicted_features})

        Performs Generalized Linear Regression (GLR) to generate predictions
        or to model a dependent variable in terms of its relationship to a set
        of explanatory variables. This tool can be used to fit continuous
        (OLS), binary (logistic), and count (Poisson) models.

     INPUTS:
      in_features (Feature Layer):
          The feature class containing the dependent and independent variables.
      dependent_variable (Field):
          The numeric field containing the observed values to be modeled.
      model_type (String):
          Specifies the type of data that will be modeled.

          * CONTINUOUS-The dependent_variable is continuous. The model used is
          Gaussian, and the tool performs ordinary least squares regression.

          * BINARY-The dependent_variable represents presence or absence. This
          can be either conventional 1s and 0s, or continuous data that has been
          recoded based on some threshold value. The model used is Logistic
          Regression.

          * COUNT-The dependent_variable is discrete and represents events, for
          example, crime counts, disease incidents, or traffic accidents. The
          model used is Poisson regression.
      explanatory_variables {Field}:
          A list of fields representing independent explanatory variables in the
          regression model.
      distance_features {Feature Layer}:
          Automatically creates explanatory variables by calculating a distance
          from the provided features to the in_features. Distances will be
          calculated from each of the input distance_features to the nearest
          in_features. If the input distance_features are polygons or lines, the
          distance attributes are calculated as the distance between the closest
          segments of the pair of features.
      prediction_locations {Feature Layer}:
          A feature class containing features representing locations where
          estimates will be computed. Each feature in this dataset should
          contain values for all the explanatory variables specified. The
          dependent variable for these features will be estimated using the
          model calibrated for the input feature class data.
      explanatory_variables_to_match {Value Table}:
          Matches the explanatory variables in the prediction_locations to
          corresponding explanatory variables from the in_features-for example,
          [["LandCover2000", "LandCover2010"], ["Income", "PerCapitaIncome"]]
      explanatory_distance_matching {Value Table}:
          Matches the distance features specified for the features_to_predict on
          the left to the corresponding distance features for the in_features on
          the right-for example, [["stores2010", "stores2000"], ["freeways2010",
          "freeways2000"]].

     OUTPUTS:
      output_features (Feature Class):
          The new feature class that will contain the dependent variable
          estimates and residuals.
      output_predicted_features {Feature Class}:
          The output feature class to receive dependent variable estimates for
          each prediction_location.The output feature class to receive dependent
          variable estimates for
          each Prediction Location."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeneralizedLinearRegression_stats(*gp_fixargs((in_features, dependent_variable, model_type, output_features, explanatory_variables, distance_features, prediction_locations, explanatory_variables_to_match, explanatory_distance_matching, output_predicted_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateNetworkSWM_stats', None)
def GenerateNetworkSWM(Input_Feature_Class=None, Unique_ID_Field=None, Output_Spatial_Weights_Matrix_File=None, Input_Network_Data_Source=None, Travel_Mode=None, Impedance_Distance_Cutoff=None, Impedance_Temporal_Cutoff=None, Impedance_Cost_Cutoff=None, Maximum_Number_of_Neighbors=None, Time_of_Day=None, Time_Zone=None, Barriers=None, Search_Tolerance=None, Conceptualization_of_Spatial_Relationships=None, Exponent=None, Row_Standardization=None):
    """GenerateNetworkSWM_stats(Input_Feature_Class, Unique_ID_Field, Output_Spatial_Weights_Matrix_File, Input_Network_Data_Source, Travel_Mode, {Impedance_Distance_Cutoff}, {Impedance_Temporal_Cutoff}, {Impedance_Cost_Cutoff}, {Maximum_Number_of_Neighbors}, {Time_of_Day}, {Time_Zone}, {Barriers}, {Search_Tolerance}, {Conceptualization_of_Spatial_Relationships}, {Exponent}, {Row_Standardization})

        Constructs a spatial weights matrix file (.swm) using a network
        dataset, defining spatial relationships in terms of the underlying
        network structure.

     INPUTS:
      Input_Feature_Class (Feature Class):
          The point feature class representing locations on the network. For
          each feature, neighbors and weights are calculated and stored in the
          output spatial weights matrix file.
      Unique_ID_Field (Field):
          An integer field containing a unique value for each feature in the
          input feature class. If you don't have a field with unique ID values,
          you can create one by adding an integer field to your feature class
          table and calculating the field values to equal the FID or OBJECTID
          field.
      Input_Network_Data_Source (Network Data Source):
          The network dataset used to find neighbors of each input feature.
          Network datasets usually represent street networks but can also
          represent other kinds of transportation networks such as railroads or
          walking paths. The network dataset must include at least one attribute
          related to distance, travel time, or cost.
      Travel_Mode (String):
          The mode of transportation for the analysis. A travel mode defines how
          a pedestrian, car, truck, or other medium of transportation moves
          through the network and represents a collection of network settings,
          such as travel restrictions and U-turn policies.An arcpy.na.TravelMode
          object and a string containing the valid JSON
          representation of a travel mode can also be used as input to the
          parameter.
      Impedance_Distance_Cutoff {Linear Unit}:
          The maximum impedance distance allowed for neighbors of a feature. Any
          feature whose distance is farther than this value will not be used as
          a neighbor. By default, no distance cutoff is used.
      Impedance_Temporal_Cutoff {Time Unit}:
          The maximum impedance travel time allowed for neighbors of a feature.
          Any feature whose travel time is longer than this value will not be
          used as a neighbor. By default, no temporal cutoff is used.
      Impedance_Cost_Cutoff {Double}:
          The maximum impedance cost allowed for neighbors of a feature. Any
          feature whose cost of travel is larger than this value will not be
          used as a neighbor. By default, no cost cutoff is used.
      Maximum_Number_of_Neighbors {Long}:
          An integer reflecting the maximum number of neighbors for each
          feature. The actual number of neighbors used for each feature may be
          smaller due to impedance cutoffs.
      Time_of_Day {Date}:
          The time of day traffic conditions will be considered in the analysis.
          Traffic conditions can impact the distance that can be traveled over a
          given time. If no date or time is provided, the analysis will not
          consider the impact of traffic.Instead of using a particular date, you
          can specify a day of the week
          using the following dates:

          * Today-12/30/1899

          * Sunday-12/31/1899

          * Monday-1/1/1900

          * Tuesday-1/2/1900

          * Wednesday-1/3/1900

          * Thursday-1/4/1900

          * Friday-1/5/1900

          * Saturday-1/6/1900
          For example, to specify that travel should begin at 5:00 p.m. on
          Tuesday, specify the parameter value as 1/2/1900 5:00 PM.
      Time_Zone {String}:
          Specifies the time zone for the Time_of_Day parameter.

          * LOCAL_TIME_AT_LOCATIONS-The time zone in which the
          Input_Feature_Class is located will be used. This is the default.

          * UTC-Coordinated universal time (UTC) will be used.
      Barriers {Feature Layer}:
          The point features that represent blocked intersections, road
          closures, accident sites, or other locations where travel is blocked
          along the network.
      Search_Tolerance {Linear Unit}:
          The maximum distance used to assign each input feature to a location
          on the network. If any of the input points do not fall exactly on a
          line of the network, they will be assigned to the closest location on
          the network for the analysis. However, if the feature is farther than
          the search tolerance value from any location on the network, it will
          not be assigned to the network and will not be included in the
          analysis.
      Conceptualization_of_Spatial_Relationships {String}:
          Specifies how weights will be defined for each neighbor.

          * INVERSE-Features farther in distance, time, or cost will have a
          smaller weight than features nearby. The weights decrease by their
          inverse to an exponent.

          * FIXED-All neighbors will be given equal weight. This is the default.
      Exponent {Double}:
          The exponent used when INVERSE is specified for the
          Conceptualization_of_Spatial_Relationships parameter. The weights
          assigned to each neighbor are calculated by taking the inverse
          distance, time, or cost to the power of the exponent. The default
          value is 1, and the value must be between 0.01 and 4. Weights drop off
          more rapidly as the exponent increases.
      Row_Standardization {Boolean}:
          Specifies whether row standardization will be applied. Row
          standardization is recommended when the locations of the input points
          are potentially biased due to sampling design or an imposed
          aggregation scheme. It is also recommended that you standardize rows
          when weighting neighbors based on inverse distance, time, or cost.

          * ROW_STANDARDIZATION-Spatial weights will be standardized by row.
          Each weight is divided by its row sum. This is the default.

          * NO_STANDARDIZATION-No standardization of spatial weights will be
          applied.

     OUTPUTS:
      Output_Spatial_Weights_Matrix_File (File):
          The output network spatial weights matrix file (.swm) that will store
          the neighbors and weights for each input feature."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateNetworkSWM_stats(*gp_fixargs((Input_Feature_Class, Unique_ID_Field, Output_Spatial_Weights_Matrix_File, Input_Network_Data_Source, Travel_Mode, Impedance_Distance_Cutoff, Impedance_Temporal_Cutoff, Impedance_Cost_Cutoff, Maximum_Number_of_Neighbors, Time_of_Day, Time_Zone, Barriers, Search_Tolerance, Conceptualization_of_Spatial_Relationships, Exponent, Row_Standardization), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateNetworkSpatialWeights_stats', None)
def GenerateNetworkSpatialWeights(Input_Feature_Class=None, Unique_ID_Field=None, Output_Spatial_Weights_Matrix_File=None, Input_Network=None, Impedance_Attribute=None, Impedance_Cutoff=None, Maximum_Number_of_Neighbors=None, Barriers=None, U_turn_Policy=None, Restrictions=None, Use_Hierarchy_in_Analysis=None, Search_Tolerance=None, Conceptualization_of_Spatial_Relationships=None, Exponent=None, Row_Standardization=None, Travel_Mode=None, Time_of_Day=None):
    """GenerateNetworkSpatialWeights_stats(Input_Feature_Class, Unique_ID_Field, Output_Spatial_Weights_Matrix_File, Input_Network, Impedance_Attribute, {Impedance_Cutoff}, {Maximum_Number_of_Neighbors}, {Barriers}, {U_turn_Policy}, {Restrictions;Restrictions...}, {Use_Hierarchy_in_Analysis}, {Search_Tolerance}, {Conceptualization_of_Spatial_Relationships}, {Exponent}, {Row_Standardization}, {Travel_Mode}, {Time_of_Day})

        Constructs a spatial weights matrix file (.swm) using a Network
        dataset, defining feature spatial relationships in terms of the
        underlying network structure.This is a deprecated tool. A new tool has
        been created with
        enhancements and new functionality including accepting networks from
        portal services. See the updated Generate Network Spatial Weights
        Matrix tool.

     INPUTS:
      Input_Feature_Class (Feature Class):
          The point feature class for which network spatial relationships among
          features will be assessed.
      Unique_ID_Field (Field):
          An integer field containing a different value for every feature in the
          input feature class. If you don't have a Unique ID field, you can
          create one by adding an integer field to your feature class table and
          calculating the field values to equal the FID or OBJECTID field.
      Input_Network (Network Dataset Layer):
          The network dataset for which spatial relationships among features in
          the input feature class will be defined. Network datasets most often
          represent street networks but may represent other kinds of
          transportation networks as well. The network dataset needs at least
          one time-based and one distance-based cost attribute.
      Impedance_Attribute (String):
          The type of cost units to use as impedance in the analysis.
      Impedance_Cutoff {Double}:
          Specifies a cutoff value for INVERSE and FIXED conceptualizations of
          spatial relationships. Enter this value using the units specified by
          the Impedance_Attribute parameter.A value of zero indicates that no
          threshold is applied. When this
          parameter is left blank, a default threshold value is computed based
          on input feature class extent and the number of features.
      Maximum_Number_of_Neighbors {Long}:
          An integer reflecting the maximum number of neighbors to find for each
          feature.
      Barriers {Feature Layer}:
          The name of a point feature class with features representing blocked
          intersections, road closures, accident sites, or other locations where
          travel is blocked along the network.
      U-turn_Policy {String}:
          Specifies optional U-turn restrictions.

          * ALLOW_UTURNS-U-turns will be allowed anywhere. This is the default.

          * NO_UTURNS-No U-turns will be allowed during navigation.

          * ALLOW_DEAD_ENDS_ONLY-U-turns will be allowed only at dead ends (that
          is, single-valent junctions).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns will be allowed only
          at dead ends and intersections.
      Restrictions {String}:
          A list of restrictions. Check the restrictions to be honored in
          spatial relationship computations.
      Use_Hierarchy_in_Analysis {Boolean}:
          Specifies whether to use a hierarchy in the analysis.

          * USE_HIERARCHY-The network dataset's hierarchy attribute will be used
          in a heuristic path algorithm to speed analysis.

          * NO_HIERARCHY-An exact path algorithm will be used instead. If there
          is no hierarchy attribute, this option does not affect analysis.
      Search_Tolerance {Linear Unit}:
          The search threshold used to locate features in the
          Input_Feature_Class onto the network dataset. This parameter includes
          a search value and the units for the tolerance.
      Conceptualization_of_Spatial_Relationships {String}:
          Specifies how the weighting associated with each spatial relationship
          is specified.

          * INVERSE-Features farther away have a smaller weight than features
          nearby.

          * FIXED-Features within the Impendance_Cutoff are neighbors (weight of
          1); features outside the Impendance_Cutoff are not weighted (weight of
          0).
      Exponent {Double}:
          Parameter for the INVERSE Conceptualization_of_Spatial_Relationships
          calculation. Typical values are 1 or 2. Weights drop off quicker with
          distance as this exponent value increases.
      Row_Standardization {Boolean}:
          Specifies whether row standardization is applied. Row standardization
          is recommended whenever feature distribution is potentially biased due
          to sampling design or to an imposed aggregation scheme.

          * ROW_STANDARDIZATION-Spatial weights are standardized by row. Each
          weight is divided by its row sum.

          * NO_STANDARDIZATION-No standardization of spatial weights is applied.
      Travel_Mode {String}:
          The mode of transportation for the analysis. Custom is always a
          choice. For other travel modes to appear, they must be present in the
          network dataset specified in the Network Dataset parameter.A travel
          mode is defined on a network dataset and provides override
          values for parameters that model car, truck, pedestrian, or other
          modes of travel.
      Time_of_Day {Date}:
          Specifies whether travel times should consider traffic conditions.
          Especially in urbanized areas, traffic conditions can significantly
          impact the area covered within a specified travel time. If no date or
          time is specified, the distance covered during a specified travel time
          will not be impacted by traffic.

     OUTPUTS:
      Output_Spatial_Weights_Matrix_File (File):
          The output network spatial weights matrix (.swm) file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateNetworkSpatialWeights_stats(*gp_fixargs((Input_Feature_Class, Unique_ID_Field, Output_Spatial_Weights_Matrix_File, Input_Network, Impedance_Attribute, Impedance_Cutoff, Maximum_Number_of_Neighbors, Barriers, U_turn_Policy, Restrictions, Use_Hierarchy_in_Analysis, Search_Tolerance, Conceptualization_of_Spatial_Relationships, Exponent, Row_Standardization, Travel_Mode, Time_of_Day), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateSpatialWeightsMatrix_stats', None)
def GenerateSpatialWeightsMatrix(Input_Feature_Class=None, Unique_ID_Field=None, Output_Spatial_Weights_Matrix_File=None, Conceptualization_of_Spatial_Relationships=None, Distance_Method=None, Exponent=None, Threshold_Distance=None, Number_of_Neighbors=None, Row_Standardization=None, Input_Table=None, Date_Time_Field=None, Date_Time_Interval_Type=None, Date_Time_Interval_Value=None, Use_Z_values=None):
    """GenerateSpatialWeightsMatrix_stats(Input_Feature_Class, Unique_ID_Field, Output_Spatial_Weights_Matrix_File, Conceptualization_of_Spatial_Relationships, {Distance_Method}, {Exponent}, {Threshold_Distance}, {Number_of_Neighbors}, {Row_Standardization}, {Input_Table}, {Date_Time_Field}, {Date_Time_Interval_Type}, {Date_Time_Interval_Value}, {Use_Z_values})

        Constructs a spatial weights matrix (.swm) file to represent the
        spatial relationships among features in a dataset.

     INPUTS:
      Input_Feature_Class (Feature Class):
          The feature class for which spatial relationships of features will be
          assessed.
      Unique_ID_Field (Field):
          An integer field containing a different value for every feature in the
          input feature class. If you don't have a Unique ID field, you can
          create one by adding an integer field to your feature class table and
          calculating the field values to equal the FID or OBJECTID field.
      Conceptualization_of_Spatial_Relationships (String):
          Specifies how spatial relationships among features are conceptualized.

          * INVERSE_DISTANCE-The impact of one feature on another feature
          decreases with distance.

          * FIXED_DISTANCE-Everything within a specified critical distance of
          each feature is included in the analysis; everything outside the
          critical distance is excluded.

          * K_NEAREST_NEIGHBORS-The closest k features are included in the
          analysis; k is a specified numeric parameter.

          * CONTIGUITY_EDGES_ONLY-Polygon features that share a boundary are
          neighbors.

          * CONTIGUITY_EDGES_CORNERS-Polygon features that share a boundary
          and/or share a node are neighbors.

          * DELAUNAY_TRIANGULATION-A mesh of nonoverlapping triangles is created
          from feature centroids; features associated with triangle nodes that
          share edges are neighbors.

          * SPACE_TIME_WINDOW-Features within a specified critical distance and
          specified time interval of each other are neighbors.

          * CONVERT_TABLE-Spatial relationships are defined in a table.
      Distance_Method {String}:
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN-The straight-line distance between two points (as the crow
          flies)

          * MANHATTAN-The distance between two points measured along axes at
          right angles (city block); calculated by summing the (absolute)
          difference between the x- and y-coordinates
      Exponent {Double}:
          Parameter for inverse distance calculation. Typical values are 1 or 2.
      Threshold_Distance {Double}:
          Specifies a cutoff distance for Inverse distance and Fixed distance
          conceptualizations of spatial relationships. Enter this value using
          the units specified in the environment output coordinate system.
          Defines the size of the space window for the Space time window
          conceptualization of spatial relationships.A value of zero indicates
          that no threshold distance is applied. When
          this parameter is left blank, a default threshold value is computed
          based on output feature class extent and the number of features.
      Number_of_Neighbors {Long}:
          An integer reflecting either the minimum or the exact number of
          neighbors. For K_NEAREST_NEIGHBORS, each feature will have exactly
          this specified number of neighbors. For INVERSE_DISTANCE or
          FIXED_DISTANCE, each feature will have at least this many neighbors
          (the threshold distance will be temporarily extended to ensure this
          many neighbors, if necessary). When one of the contiguity
          Conceptualizations of Spatial Relationships is selected, each polygon
          will be assigned this minimum number of neighbors. For polygons with
          fewer than this number of contiguous neighbors, additional neighbors
          will be based on feature centroid proximity.
      Row_Standardization {Boolean}:
          Row standardization is recommended whenever feature distribution is
          potentially biased due to sampling design or to an imposed aggregation
          scheme.

          * ROW_STANDARDIZATION-Spatial weights are standardized by row. Each
          weight is divided by its row sum. This is the default.

          * NO_STANDARDIZATION-No standardization of spatial weights is applied.
      Input_Table {Table}:
          A table containing numeric weights relating every feature to every
          other feature in the input feature class. Required fields are the
          Input Feature Class, Unique ID field, NID (neighbor ID), and WEIGHT.
      Date_Time_Field {Field}:
          A date field with a timestamp for each feature.
      Date_Time_Interval_Type {String}:
          The units to use for measuring time.

          * SECONDS-Seconds

          * MINUTES-Minutes

          * HOURS-Hours

          * DAYS-Days

          * WEEKS-Weeks

          * MONTHS-30 Days

          * YEARS-Years
      Date_Time_Interval_Value {Long}:
          An integer reflecting the number of time units comprising the time
          window.For example, if you select HOURS for the Date/Time Interval
          Type and 3
          for the Date/Time Interval Value, the time window would be 3 hours;
          features within the specified space window and within the specified
          time window would be neighbors.
      Use_Z_values {Boolean}:
          * USE_Z_VALUES-Z-values are used in the construction of the spatial
          weights matrix.

          * DO_NOT_USE_Z_VALUES-Z-values are ignored and only X and Y
          coordinates are considered in the construction of the spatial weights
          matrix. This is the default.

     OUTPUTS:
      Output_Spatial_Weights_Matrix_File (File):
          The full path for the spatial weights matrix file (.swm) you want to
          create."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateSpatialWeightsMatrix_stats(*gp_fixargs((Input_Feature_Class, Unique_ID_Field, Output_Spatial_Weights_Matrix_File, Conceptualization_of_Spatial_Relationships, Distance_Method, Exponent, Threshold_Distance, Number_of_Neighbors, Row_Standardization, Input_Table, Date_Time_Field, Date_Time_Interval_Type, Date_Time_Interval_Value, Use_Z_values), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeographicallyWeightedRegression_stats', None)
def GeographicallyWeightedRegression(in_features=None, dependent_field=None, explanatory_field=None, out_featureclass=None, kernel_type=None, bandwidth_method=None, distance=None, number_of_neighbors=None, weight_field=None, coefficient_raster_workspace=None, cell_size=None, in_prediction_locations=None, prediction_explanatory_field=None, out_prediction_featureclass=None):
    """GeographicallyWeightedRegression_stats(in_features, dependent_field, explanatory_field;explanatory_field..., out_featureclass, kernel_type, bandwidth_method, {distance}, {number_of_neighbors}, {weight_field}, {coefficient_raster_workspace}, {cell_size}, {in_prediction_locations}, {prediction_explanatory_field;prediction_explanatory_field...}, {out_prediction_featureclass})

        Performs Geographically Weighted Regression (GWR), a local form of
        linear regression used to model spatially varying relationships.An
        enhanced version of this tool has been added to ArcGIS Pro 2.3.
        This is the tool documentation for the older deprecated tool. It is
        recommended that you upgrade and use the new Geographically Weighted
        Regression tool available in ArcGIS Pro or later.

     INPUTS:
      in_features (Feature Layer):
          The feature class containing the dependent and independent variables.
      dependent_field (Field):
          The numeric field containing the values that will be modeled.
      explanatory_field (Field):
          A list of fields representing independent explanatory variables in the
          regression model.
      kernel_type (String):
          Specifies whether the kernel is constructed as a fixed distance, or if
          it is allowed to vary in extent as a function of feature density.

          * FIXED-The spatial context (the Gaussian kernel) used to solve each
          local regression analysis is a fixed distance.

          * ADAPTIVE-The spatial context (the Gaussian kernel) is a function of
          a specified number of neighbors. Where feature distribution is dense,
          the spatial context is smaller; where feature distribution is sparse,
          the spatial context is larger.
      bandwidth_method (String):
          Specifies how the extent of the kernel will be determined. When AICc
          or CV is selected, the tool will find the optimal distance or number
          of neighbors. Typically, you will select either AICc or CV when you
          aren't sure what to use for the distance or number_of_neighbors
          parameter. Once the tool determines the optimal distance or number of
          neighbors, however, you'll use the BANDWIDTH_PARAMETER option.

          * AICc-The extent of the kernel is determined using the Akaike
          Information Criterion (AICc).

          * CV-The extent of the kernel is determined using Cross Validation.

          * BANDWIDTH_PARAMETER-The extent of the kernel is determined by a
          fixed distance or a fixed number of neighbors. You must specify a
          value for either the distance or number_of_neighbors parameter.
      distance {Double}:
          The distance to use when kernel_type is FIXED and bandwidth_method is
          BANDWIDTH_PARAMETER.
      number_of_neighbors {Long}:
          The exact number of neighbors to include in the local bandwidth of the
          Gaussian kernel when kernel_type is ADAPTIVE and bandwidth_method is
          BANDWIDTH_PARAMETER.
      weight_field {Field}:
          The numeric field containing a spatial weighting for individual
          features. This weight field allows some features to be more important
          in the model calibration process than others. This is useful when the
          number of samples taken at different locations varies, values for the
          dependent and independent variables are averaged, and places with more
          samples are more reliable (should be weighted higher). If you have an
          average of 25 different samples for one location but an average of
          only 2 samples for another location, for example, you can use the
          number of samples as your weight field so that locations with more
          samples have a larger influence on model calibration than locations
          with few samples.
      coefficient_raster_workspace {Workspace}:
          The full path to the workspace where the coefficient rasters will be
          created. When this workspace is provided, rasters are created for the
          intercept and every explanatory variable.
      cell_size {Analysis Cell Size}:
          The cell size (a number) or reference to the cell size (a path to a
          raster dataset) to use when creating the coefficient rasters.The
          default cell size is the shortest of the width or height of the
          extent specified in the geoprocessing environment output coordinate
          system, divided by 250.
      in_prediction_locations {Feature Layer}:
          A feature class containing features representing locations where
          estimates should be computed. Each feature in this dataset should
          contain values for all of the explanatory variables specified; the
          dependent variable for these features will be estimated using the
          model calibrated for the input feature class data.
      prediction_explanatory_field {Field}:
          A list of fields representing explanatory variables in the Prediction
          locations feature class. These field names should be provided in the
          same order (a one-to-one correspondence) as those listed for the input
          feature class Explanatory variables parameter. If no prediction
          explanatory variables are given, the output prediction feature class
          will only contain computed coefficient values for each prediction
          location.

     OUTPUTS:
      out_featureclass (Feature Class):
          The output feature class that will receive dependent variable
          estimates and residuals.
      out_prediction_featureclass {Feature Class}:
          The output feature class to receive dependent variable estimates for
          each feature in the Prediction locations feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeographicallyWeightedRegression_stats(*gp_fixargs((in_features, dependent_field, explanatory_field, out_featureclass, kernel_type, bandwidth_method, distance, number_of_neighbors, weight_field, coefficient_raster_workspace, cell_size, in_prediction_locations, prediction_explanatory_field, out_prediction_featureclass), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LocalBivariateRelationships_stats', None)
def LocalBivariateRelationships(in_features=None, dependent_variable=None, explanatory_variable=None, output_features=None, number_of_neighbors=None, number_of_permutations=None, enable_local_scatterplot_popups=None, level_of_confidence=None, apply_false_discovery_rate_fdr_correction=None, scaling_factor=None):
    """LocalBivariateRelationships_stats(in_features, dependent_variable, explanatory_variable, output_features, {number_of_neighbors}, {number_of_permutations}, {enable_local_scatterplot_popups}, {level_of_confidence}, {apply_false_discovery_rate_fdr_correction}, {scaling_factor})

        Analyzes two variables for statistically significant relationships
        using local entropy. Each feature is classified into one of six
        categories based on the type of relationship. The output can be used
        to visualize areas where the variables are related and explore how
        their relationship changes across the study area.

     INPUTS:
      in_features (Feature Layer):
          The feature class containing fields representing the
          dependent_variable and explanatory_variable.
      dependent_variable (Field):
          The numeric field representing the values of the dependent variable.
          When categorizing the relationships, the explanatory_variable is used
          to predict the dependent_variable.
      explanatory_variable (Field):
          The numeric field representing the values of the explanatory variable.
          When categorizing the relationships, the explanatory_variable is used
          to predict the dependent_variable.
      number_of_neighbors {Long}:
          The number of neighbors around each feature (including the feature)
          that will be used to test for a local relationship between the
          variables. The number of neighbors must be between 30 and 1000, and
          the default is 30. The provided value should be large enough to detect
          the relationship between features, but small enough to still identify
          local patterns.
      number_of_permutations {Long}:
          Specifies the number of permutations used to calculate the pseudo
          p-value for each feature. Choosing a number of permutations is a
          balance between precision in the pseudo p-value and increased
          processing time.

          * 99-With 99 permutations, the smallest possible pseudo p-value is
          0.01, and all other pseudo p-values will be multiples of this value.

          * 199-With 199 permutations, the smallest possible pseudo p-value is
          0.005, and all other pseudo p-values will be multiples of this value.
          This is the default

          * 499-With 499 permutations, the smallest possible pseudo p-value is
          0.002, and all other pseudo p-values will be multiples of this value.

          * 999-With 999 permutations, the smallest possible pseudo p-value is
          0.001, and all other pseudo p-values will be multiples of this value.
      enable_local_scatterplot_popups {Boolean}:
          Specifies whether scatterplot pop-ups will be generated for each
          output feature. Each scatterplot displays the values of the
          explanatory (horizontal axis) and dependent (vertical axis) variables
          in the local neighborhood along with a fitted line or curve
          visualizing the form of the relationship. Scatterplot charts are not
          supported for shapefile outputs.

          * CREATE_POPUP-Local scatterplot pop-ups will be generated for each
          feature in the dataset. This is the default.

          * NO_POPUP-Local scatterplot pop-ups will not be generated.
      level_of_confidence {String}:
          Specifies a confidence level of the hypothesis test for significant
          relationships.

          * 90%-90% confidence level. This is the default.

          * 95%-95% confidence level.

          * 99%-99% confidence level.
      apply_false_discovery_rate_fdr_correction {Boolean}:
          Specifies whether False Discover Rate (FDR) correction will be applied
          to the pseudo p-values.

          * APPLY_FDR-Statistical significance will be based on the FDR
          correction. This is the default.

          * NO_FDR-Statistical significance will be based on the pseudo p-value.
      scaling_factor {Double}:
          Controls the sensitivity to subtle relationships between the
          variables. Larger values (closer to one) can detect relatively weak
          relationships, while smaller values (closer to zero) will only detect
          strong relationships. Smaller values are also more robust to outliers.
          The value must be between 0.01 and 1, and the default is 0.5.

     OUTPUTS:
      output_features (Feature Class):
          The output feature class containing all input features with fields
          representing the dependent_variable, explanatory_variable, entropy
          score, pseudo p-value, level of significance, type of categorized
          relationship, and diagnostics related to the categorization."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LocalBivariateRelationships_stats(*gp_fixargs((in_features, dependent_variable, explanatory_variable, output_features, number_of_neighbors, number_of_permutations, enable_local_scatterplot_popups, level_of_confidence, apply_false_discovery_rate_fdr_correction, scaling_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OrdinaryLeastSquares_stats', None)
def OrdinaryLeastSquares(Input_Feature_Class=None, Unique_ID_Field=None, Output_Feature_Class=None, Dependent_Variable=None, Explanatory_Variables=None, Coefficient_Output_Table=None, Diagnostic_Output_Table=None, Output_Report_File=None):
    """OrdinaryLeastSquares_stats(Input_Feature_Class, Unique_ID_Field, Output_Feature_Class, Dependent_Variable, Explanatory_Variables;Explanatory_Variables..., {Coefficient_Output_Table}, {Diagnostic_Output_Table}, {Output_Report_File})

        Performs global Ordinary Least Squares (OLS) linear regression to
        generate predictions or to model a dependent variable in terms of its
        relationships to a set of explanatory variables.The functionality of
        this tool is included in the Generalized Linear
        Regression tool added at ArcGIS Pro 2.3. The Generalized Linear
        Regression tool supports additional models.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class containing the dependent and independent variables
          for analysis.
      Unique_ID_Field (Field):
          An integer field containing a different value for every feature in the
          Input Feature Class.
      Dependent_Variable (Field):
          The numeric field containing values for what you are trying to model.
      Explanatory_Variables (Field):
          A list of fields representing explanatory variables in your regression
          model.

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          The output feature class that will receive dependent variable
          estimates and residuals.
      Coefficient_Output_Table {Table}:
          The full path to an optional table that will receive model
          coefficients, standardized coefficients, standard errors, and
          probabilities for each explanatory variable.
      Diagnostic_Output_Table {Table}:
          The full path to an optional table that will receive model summary
          diagnostics.
      Output_Report_File {File}:
          The path to the optional PDF file the tool will create. This report
          file includes model diagnostics, graphs, and notes to help you
          interpret the OLS results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OrdinaryLeastSquares_stats(*gp_fixargs((Input_Feature_Class, Unique_ID_Field, Output_Feature_Class, Dependent_Variable, Explanatory_Variables, Coefficient_Output_Table, Diagnostic_Output_Table, Output_Report_File), True)))
        return retval
    except Exception as e:
        raise e


# Utilities toolset
@gptooldoc('CalculateAreas_stats', None)
def CalculateAreas(Input_Feature_Class=None, Output_Feature_Class=None):
    """CalculateAreas_stats(Input_Feature_Class, Output_Feature_Class)

     INPUTS:
      Input_Feature_Class (Feature Layer):
          Input Feature Class

     OUTPUTS:
      Output_Feature_Class (Feature Class):
          Output Feature Class"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateAreas_stats(*gp_fixargs((Input_Feature_Class, Output_Feature_Class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CalculateDistanceBand_stats', None)
def CalculateDistanceBand(Input_Features=None, Neighbors=None, Distance_Method=None):
    """CalculateDistanceBand_stats(Input_Features, Neighbors, Distance_Method)

        Returns the minimum, the maximum, and the average distance to the
        specified Nth nearest neighbor (N is an input parameter) for a set of
        features. Results are written as tool execution messages.

     INPUTS:
      Input_Features (Feature Layer):
          The feature class or layer used to calculate distance statistics.
      Neighbors (Long):
          The number of neighbors (N) to consider for each feature. This number
          should be any integer between one and the total number of features in
          the feature class. A list of distances between each feature and its
          Nth neighbor is compiled, and the maximum, minimum, and average
          distances are output to the Results window.
      Distance_Method (String):
          Specifies how distances are calculated from each feature to
          neighboring features.

          * EUCLIDEAN_DISTANCE-The straight-line distance between two points (as
          the crow flies)

          * MANHATTAN_DISTANCE-The distance between two points measured along
          axes at right angles (city block); calculated by summing the
          (absolute) difference between the x- and y-coordinates"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDistanceBand_stats(*gp_fixargs((Input_Features, Neighbors, Distance_Method), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CollectEvents_stats', None)
def CollectEvents(Input_Incident_Features=None, Output_Weighted_Point_Feature_Class=None):
    """CollectEvents_stats(Input_Incident_Features, Output_Weighted_Point_Feature_Class)

        Converts event data, such as crime or disease incidents, to weighted
        point data.

     INPUTS:
      Input_Incident_Features (Feature Layer):
          The features representing event or incident data.

     OUTPUTS:
      Output_Weighted_Point_Feature_Class (Feature Class):
          The output feature class to contain the weighted point data."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CollectEvents_stats(*gp_fixargs((Input_Incident_Features, Output_Weighted_Point_Feature_Class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ConvertSpatialWeightsMatrixtoTable_stats', None)
def ConvertSpatialWeightsMatrixtoTable(Input_Spatial_Weights_Matrix_File=None, Output_Table=None):
    """ConvertSpatialWeightsMatrixtoTable_stats(Input_Spatial_Weights_Matrix_File, Output_Table)

        Converts a binary spatial weights matrix file (.swm) to a table.

     INPUTS:
      Input_Spatial_Weights_Matrix_File (File):
          The full pathname for the spatial weights matrix file (.swm) you want
          to convert.

     OUTPUTS:
      Output_Table (Table):
          A full pathname to the table you want to create."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConvertSpatialWeightsMatrixtoTable_stats(*gp_fixargs((Input_Spatial_Weights_Matrix_File, Output_Table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportXYv_stats', None)
def ExportXYv(Input_Feature_Class=None, Value_Field=None, Delimiter=None, Output_ASCII_File=None, Add_Field_Names_to_Output=None):
    """ExportXYv_stats(Input_Feature_Class, Value_Field;Value_Field..., Delimiter, Output_ASCII_File, Add_Field_Names_to_Output)

        Exports feature class coordinates and attribute values to a space-,
        comma-, tab-, or semicolon-delimited ASCII text file.

     INPUTS:
      Input_Feature_Class (Feature Layer):
          The feature class from which the feature coordinates and attribute
          values will be exported.
      Value_Field (Field):
          The field or fields in the input feature class containing the values
          to export to an ASCII text file.
      Delimiter (String):
          Specifies how feature coordinates and attribute values will be
          separated in the output ASCII file.

          * SPACE-Feature coordinates and attribute values will be separated by
          a space in the output. This is the default.

          * COMMA-Feature coordinates and attribute values will be separated by
          a comma in the output.

          * SEMI-COLON-Feature coordinates and attribute values will be
          separated by a semicolon in the output.

          * TAB-Feature coordinates and attribute values will be separated by a
          tab in the output.
      Add_Field_Names_to_Output (Boolean):
          Specifies whether field names will be included as the first line in
          the output text file.

          * ADD_FIELD_NAMES-Field names will be written to the output text file.

          * NO_FIELD_NAMES-Field names will not be written to the output text
          file. This is the default.

     OUTPUTS:
      Output_ASCII_File (File):
          The ASCII text file that will contain the feature coordinates and
          attribute values."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportXYv_stats(*gp_fixargs((Input_Feature_Class, Value_Field, Delimiter, Output_ASCII_File, Add_Field_Names_to_Output), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject