# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Topographic Production Tools"""
__all__ = ['ApplyBuildingOffsets', 'ApplyMasksFromRules',
           'ApplyVisualSpecificationToMap', 'CalculateBridgeOffsets',
           'CalculateDefaultValues', 'CalculateMetrics',
           'CopyExtendedProperties', 'CopyJobFiles', 'CreateJobForTask',
           'EliminatePolygon', 'ExportGeneralizedData', 'ExportMetadata',
           'ExportTopology', 'ExtractDataByFeature', 'FillGaps', 'GAIT',
           'GenerateAdjoiningSheetsFeatures', 'GenerateElevationBands',
           'GenerateElevationGuideFeatures', 'GenerateProductLayout',
           'GenerateSpotHeights', 'GenerateTopographicContours',
           'GeoNamesToGeodatabase', 'GeodatabaseToShape', 'GetFeaturesByJobAOI',
           'IdentifyContours', 'IdentifyNarrowPolygons',
           'ImportGeneralizationData', 'ImportMetadata', 'ImportTopology',
           'InsertTaskGroup', 'LoadData', 'MakeGridsAndGraticulesLayer',
           'MakeMasksFromRules', 'PolygonToCenterline', 'PopulateMapSheetInfo',
           'RemoveCutbackVertices', 'RemoveSmallLines',
           'RepairSelfIntersection', 'SetDataWorkspace', 'SetNextTask',
           'SetProductionProperties', 'SetTaskList', 'SetTaskStatus',
           'SplitFeatures', 'ThinHydrologyLines', 'ThinSpotHeights',
           'UnzipCellAndImport', 'UpdateExtendedProperty', 'UpdateGeoNames',
           'UpdatePropertyCount', 'UpdateTaskGroupMetrics']
__alias__ = 'topographic'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Cartography\Banding toolset
@gptooldoc('GenerateElevationBands_topographic', None)
def GenerateElevationBands(in_raster=None, in_aoi=None, out_feature_class=None, contour_interval=None, min_area=None, smooth_tolerance=None, in_hydro_features=None, number_of_bands=None):
    """GenerateElevationBands_topographic(in_raster;in_raster..., in_aoi, out_feature_class, contour_interval, min_area, smooth_tolerance, {in_hydro_features}, {number_of_bands})

        Creates an elevation bands feature class from a Digital Elevation
        Model (DEM).

     INPUTS:
      in_raster (Raster Layer / Mosaic Layer):
          The rasters used to create elevation bands.
      in_aoi (Layer):
          The layer that defines the processing extent.
      contour_interval (Long):
          Determines the closest available contour when calculating the
          elevation band area. The default is 20.

          * 10-A contour interval of 10.

          * 20-A contour interval of 20.

          * 40-A contour interval of 40.

          * 80-A contour interval of 80.
      min_area (Double):
          The minimum area for output polygons. Features smaller than
          this value will be removed. The default is 0.00016 square decimal
          degrees. If you're creating an output dataset with a projected
          coordinate
          system, this value should reflect the square units of that coordinate
          system-for example, square meters for a UTM dataset. Otherwise, the
          default value may result in an empty output dataset.
      smooth_tolerance (Linear Unit):
          The tolerance used by the smoothing algorithm. The larger the value,
          the more generalized the output band features. The default is 0.002
          decimal degrees.
      in_hydro_features {Feature Layer}:
          The bodies of water to exclude when calculating the elevation band
          area.
      number_of_bands {Long}:
          The number of elevation bands generated by the tool.

          * 1-One elevation band will be generated.

          * 2-Two elevation bands will be generated.

          * 3-Three elevation bands will be generated.

          * 4-Four elevation bands will be generated.

     OUTPUTS:
      out_feature_class (Feature Class):
          The feature class containing the output elevation band features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateElevationBands_topographic(*gp_fixargs((in_raster, in_aoi, out_feature_class, contour_interval, min_area, smooth_tolerance, in_hydro_features, number_of_bands), True)))
        return retval
    except Exception as e:
        raise e


# Cartography\Cartographic Refinement toolset
@gptooldoc('ApplyBuildingOffsets_topographic', None)
def ApplyBuildingOffsets(in_map=None, rule_file=None):
    """ApplyBuildingOffsets_topographic(in_map, rule_file)

        Aligns, moves, and hides building or bridge marker symbols based on
        product specification rules defined in an .xml file.If this tool is
        run with a building offset XML rule file, it aligns,
        moves, and hides building marker symbols based on product
        specification rules defined in an .xml file. If this tool is run with
        a bridge offset XML rule file, it calculates the offsets necessary to
        properly display bridges at a given location.For a bridge offset XML
        rule file, offsets can be calculated for
        either line bridge or point bridge features. For a line bridge
        feature, an offset will be calculated for the width of a bridge based
        on the overpassing feature that runs through the bridge. For point
        bridges, offsets include the following:

        * The rotation angle of a bridge based on its overpassing feature

        * The position of the bridge if the original position is not
        coincident with the overpassing feature
        A product file installer is available for ArcGIS Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined XML
        rule files that can be used for cartographic production.Learn more
        about Defense Mapping product files and Production Mapping
        product files.

     INPUTS:
      in_map (Map):
          The input map that contains the layers with proper symbology. This can
          be a map in the application or an .mapx file on disk.
      rule_file (File):
          An .xml file containing the offset rules that define how features will
          be aligned and refined in case of any conflict."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyBuildingOffsets_topographic(*gp_fixargs((in_map, rule_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyMasksFromRules_topographic', None)
def ApplyMasksFromRules(in_map=None, rule_file=None, in_feature_dataset=None):
    """ApplyMasksFromRules_topographic(in_map, rule_file, in_feature_dataset)

        Applies symbol layer masking to feature layers in a map based on an
        XML rule file and mask features created by the Make Mask From Rules
        tool.A product file installer is available for ArcGIS Production
        Mapping
        and ArcGIS Defense Mapping. The product files contain predefined XML
        masking rule files that can be used for cartographic production.Learn
        more about Defense Mapping product files and Production Mapping
        product files.

     INPUTS:
      in_map (Map):
          The input map containing symbolized features such as a map in a
          project or a MAPX file on disk.
      rule_file (File):
          The XML file containing rules to define how features should be masked
          based on colors and symbol parts.
      in_feature_dataset (Feature Dataset):
          The feature dataset containing the masking polygon feature classes
          created by the Make Mask From Rules tool."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyMasksFromRules_topographic(*gp_fixargs((in_map, rule_file, in_feature_dataset), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyVisualSpecificationToMap_topographic', None)
def ApplyVisualSpecificationToMap(in_map=None, vs_workspace=None, specification=None, in_style_file=None):
    """ApplyVisualSpecificationToMap_topographic(in_map, vs_workspace, specification, {in_style_file})

        Applies symbols and Arcade expressions to layers in a map based on the
        symbols and rules defined in a visual specification database.

     INPUTS:
      in_map (Map):
          The map containing layers to which symbols and Arcade expressions will
          be applied.
      vs_workspace (Workspace):
          The database containing the visual specification rules.
      specification (String):
          The specification rules that will be converted to Arcade and applied
          to the map layers.
      in_style_file {String}:
          The style file (.stylx) that contains the symbols defined in the
          visual specification rules."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyVisualSpecificationToMap_topographic(*gp_fixargs((in_map, vs_workspace, specification, in_style_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CalculateBridgeOffsets_topographic', None)
def CalculateBridgeOffsets(in_bridge_features=None, in_overpassing_features=None, reference_scale=None, search_distance=None, expand=None, offset=None, min_length=None, bridge_subtype=None, overpassing_subtype=None):
    """CalculateBridgeOffsets_topographic(in_bridge_features, in_overpassing_features, reference_scale, {search_distance}, {expand}, {offset}, {min_length}, {bridge_subtype}, {overpassing_subtype})

        Calculates the offsets necessary to properly display bridges at a
        given location.Offsets can be calculated for either line or point
        bridge features.
        For a line bridge feature, an offset will be calculated for the width
        of a bridge based on the overpassing feature that runs through the
        bridge. For point bridges, offsets include the following:

        * The rotation angle of a bridge based on its overpassing feature

        * The position of the bridge if the original position is not
        coincident with the overpassing feature

     INPUTS:
      in_bridge_features (Layer):
          The feature layer that contains bridge features for which symbol
          offsets will be updated. Symbolize the bridge features layer with
          proper bridge features and enable attribute-driven symbology on it.
      in_overpassing_features (Layer):
          The feature layer that contains the features overpassing the bridges.
      reference_scale (Long):
          The scale at which symbols appear at their intended size.
      search_distance {Linear Unit}:
          The distance, calculated in map units, by which this tool will buffer
          point bridge features when identifying the overpassing features. This
          parameter is only available for point bridges. The default is 0
          meters.
      expand {Boolean}:
          Specifies whether marker layers on overpassing symbols will be
          included when analyzing widths.

          * EXPAND-Marker layers on overpassing symbols will be included when
          analyzing widths.

          * NO_EXPAND-Marker layers on overpassing symbols will not be included.
          This is the default.
      offset {Linear Unit}:
          An offset added to the bridge width. The default is 0 points.
      min_length {Linear Unit}:
          The minimum length of a line bridge. The default is 1.35
          millimeters.If the length of the bridge is less than the minimum
          length, it will
          be expanded to minimum length.
      bridge_subtype {String}:
          The subtype of the feature class from the in_bridge_features parameter
          that will be modified by this operation.
      overpassing_subtype {String}:
          The subtype of the feature class in the in_overpassing_features
          parameter that will be used in this operation."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateBridgeOffsets_topographic(*gp_fixargs((in_bridge_features, in_overpassing_features, reference_scale, search_distance, expand, offset, min_length, bridge_subtype, overpassing_subtype), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MakeMasksFromRules_topographic', None)
def MakeMasksFromRules(in_map=None, rule_file=None, out_feature_dataset=None):
    """MakeMasksFromRules_topographic(in_map, rule_file, out_feature_dataset)

        Creates polygon masks for features based on color rules.A product file
        installer is available for ArcGIS Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined XML
        masking rule files that can be used for cartographic production.Learn
        more about Defense Mapping product files and Production Mapping
        product files.

     INPUTS:
      in_map (Map):
          The input map containing symbolized features.
      rule_file (File):
          The XML file containing rules that define how features should be
          masked based on colors and symbol parts.

     OUTPUTS:
      out_feature_dataset (Feature Dataset):
          The output feature dataset. The tool will create a feature dataset
          containing polygon feature classes that will be used for masking. The
          spatial reference for the feature dataset will be taken from the map
          for which masks are generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeMasksFromRules_topographic(*gp_fixargs((in_map, rule_file, out_feature_dataset), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ThinSpotHeights_topographic', None)
def ThinSpotHeights(in_features=None, area_of_interest=None, elevation_field=None, invisibility_field=None, high_low_spots=None, search_distance=None, max_spots=None, input_contours=None, contour_code_field=None, depression_code_value=None):
    """ThinSpotHeights_topographic(in_features, area_of_interest, elevation_field, invisibility_field, {high_low_spots}, {search_distance}, {max_spots}, {input_contours}, {contour_code_field}, {depression_code_value;depression_code_value...})

        Generalizes spot heights for a given area of interest in accordance
        with product specifications.

     INPUTS:
      in_features (Feature Layer):
          A point feature layer or feature class representing the spot heights
          for a given area of interest.
      area_of_interest (Layer):
          The selected feature in the area of interest (AOI) that is used to
          identify input features to process. There should be one and only one
          selected AOI.
      elevation_field (Field):
          The elevation field in Input Features to use for the spot height.
      invisibility_field (Field):
          The field where the visibility attribute will be written.
      high_low_spots {Field}:
          The field that will be used to identify the highest and lowest spots.
      search_distance {Linear Unit}:
          The minimum distance between spot heights. For example, if the search
          distance is 3,000 meters, there will be at least 3,000 meters between
          a chosen spot height and the next chosen spot height. The default
          value will be 1,300 meters, as this is the optimal value for 50K
          sheets.
      max_spots {Long}:
          The number of spot heights will not exceed this number.
      input_contours {Feature Layer}:
          Input contours used to identify if point features are in depressions
          or tops.
      contour_code_field {Field}:
          The field in the database that contains the domain value for index
          contour, intermediate contour, depression contour, and depression
          intermediate contour. It is a string value of the field, such as HQC.
      depression_code_value {Long}:
          Used to identify depression code values. A depression refers to an
          elevation completely surrounded by higher-elevation contour lines."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ThinSpotHeights_topographic(*gp_fixargs((in_features, area_of_interest, elevation_field, invisibility_field, high_low_spots, search_distance, max_spots, input_contours, contour_code_field, depression_code_value), True)))
        return retval
    except Exception as e:
        raise e


# Cartography\Features toolset
@gptooldoc('GenerateAdjoiningSheetsFeatures_topographic', None)
def GenerateAdjoiningSheetsFeatures(in_feature_dataset=None, area_of_interest=None, land_features=None, scale=None, clip_aoi_to_sheets=None):
    """GenerateAdjoiningSheetsFeatures_topographic(in_feature_dataset, area_of_interest, {land_features}, {scale}, {clip_aoi_to_sheets})

        Generates features necessary for display in a typical topographic map
        adjoining sheets diagram.Features generated include: sheet polygons
        for labeling, sheet lines
        for symbolizing sheets from different series uniquely, coastal
        polygons for displaying open water with coastal polylines for
        displaying shoreline, and a calculated area of interest (AOI) for
        generating a feature grid for the diagram.

     INPUTS:
      in_feature_dataset (Feature Dataset):
          An existing feature dataset that will contain the ASG_ feature
          classes. The tool will create these feature classes if they do not
          exist.
      area_of_interest (Feature Layer):
          A feature layer with a single selected feature used to identify the
          center and surrounding AOIs. Adjoining sheets features will be created
          from the selected AOI and the intersecting AOIs as required.
      land_features {Feature Layer}:
          Land features used to generate adjoining sheets features in the
          ASG_COAST_A and ASG_COAST_L feature classes in the target feature
          dataset.
      scale {String}:
          Defines a factor by which the extent of the area_of_interest is
          expanded. The expanded extent is used to select adjoining areas of
          interest. Data from the adjoining areas of interest is included in the
          adjoining sheets diagram.

          * 1:25000-Uses specification MIL-T-89301A as a guide to determine how
          to expand the width and height of the extent of the area_of_interest.

          * 1:50000-Uses specification MIL-T-89301A to determine how to expand
          the width and height of the extent of the area_of_interest. This is
          the default.

          * 1:100000-Uses specification MIL-T-89306 to determine how to expand
          the width and height of the extent of the area_of_interest.
      clip_aoi_to_sheets {Boolean}:
          Determines if the AOI created for the extent of the adjoining sheets
          diagram will be clipped to the extents of the sheets to be displayed.
          If set to CLIP_AOI, the AOI for the adjoining sheets diagram will be
          modified from its originally calculated rectangular shape to include
          any irregular map sheet extents that will be included or excluded in
          the diagram.

          * CLIP_AOI-The AOI feature will be clipped by the sheets to be
          displayed in the adjoining sheet diagram and may have an irregular
          shape. This is the default.

          * DONT_CLIP_AOI-The AOI feature will not be clipped and will retain
          its originally calculated rectangular shape. This may result in
          partial sheets being displayed in the adjoining sheets diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateAdjoiningSheetsFeatures_topographic(*gp_fixargs((in_feature_dataset, area_of_interest, land_features, scale, clip_aoi_to_sheets), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateElevationGuideFeatures_topographic', None)
def GenerateElevationGuideFeatures(in_feature_dataset=None, area_of_interest=None, in_rasters=None, hydro_exclusion_features=None, spot_height_features=None, hydro_line_features=None, hydro_area_features=None, contour_interval=None, bands_minarea=None, smooth_tolerance=None, number_of_bands=None, height_field=None, search_distance=None, hydroline_minlength=None, hydroline_minspacing=None, hydroarea_minlength=None, hydroarea_minwidth=None):
    """GenerateElevationGuideFeatures_topographic(in_feature_dataset, area_of_interest, in_rasters;in_rasters..., {hydro_exclusion_features}, {spot_height_features}, {hydro_line_features;hydro_line_features...}, {hydro_area_features;hydro_area_features...}, {contour_interval}, {bands_minarea}, {smooth_tolerance}, {number_of_bands}, {height_field}, {search_distance}, {hydroline_minlength}, {hydroline_minspacing}, {hydroarea_minlength}, {hydroarea_minwidth})

        Creates data required for an elevation guide diagram surround element
        as required by various supported map product specifications. This tool
        leverages existing banding and thinning tools to generate output
        elevation band features, spot height features, and hydrology features.

     INPUTS:
      in_feature_dataset (Feature Dataset):
          An existing feature dataset that will contain the EGB feature classes.
          Data created for the elevation guide box is maintained in these
          feature classes in this feature dataset.
      area_of_interest (Layer):
          A feature layer with a single selected feature that defines a
          processing extent for banding operations and a clipping extent for
          spot heights, input hydro areas, and lines.
      in_rasters (Raster Layer / Mosaic Layer):
          One or more rasters used to create elevation bands and supply
          elevation values to features created by the tool.
      hydro_exclusion_features {Feature Layer}:
          A feature layer that defines a large water body area to exclude from
          the elevation band area computation.
      spot_height_features {Feature Layer}:
          Feature layer or class that contains spot heights.
      hydro_line_features {Feature Layer}:
          Hydrology line features used to generate the output of a thinned
          hydrology dataset. Only the output features are generalized through
          this thinning process.
      hydro_area_features {Feature Layer}:
          Hydrology area features used to generate the thinned hydrology
          dataset. Only the output features are generalized through this
          thinning process.
      contour_interval {Long}:
          The contour interval used to determine the closest available contour
          when calculating the elevation band area. Elevation bands are created
          with their limits aligned to the chosen contour interval, except low
          and high values, which will represent their actual calculated values.

          * 10-A contour interval of 10.

          * 20-A contour interval of 20. This is the default.

          * 40-A contour interval of 40.

          * 80-A contour interval of 80.
      bands_minarea {Double}:
          The minimum area for output polygons. Features smaller than
          this value will be removed. The default is 0.00016 square decimal
          degrees. If you are creating an output dataset with a projected
          coordinate
          system, this value should reflect the square units of that coordinate
          system-for example, square meters for a UTM dataset. Otherwise, the
          default value may result in an empty output dataset.
      smooth_tolerance {Linear Unit}:
          The tolerance used by the smoothing algorithm. The larger the value,
          the more generalized the output band features. The default is 0.002
          decimal degrees.
      number_of_bands {Long}:
          The number of elevation bands generated by the tool.

          * 1-One elevation band will be generated.

          * 2-Two elevation bands will be generated.

          * 3-Three elevation bands will be generated.

          * 4-Four elevation bands will be generated.
      height_field {Field}:
          The field that identifies the elevation values of the spot height
          features. It is these values that will be evaluated during the
          thinning process.
      search_distance {Linear Unit}:
          The minimum distance between spot heights. The default is 0 Meters.
      hydroline_minlength {Linear Unit}:
          The minimum length used to eliminate hydrographic features. The tool
          will thin hydro features that have a length less than this number.
          This value is used when generalizing Input Hydro Lines and Areas.
      hydroline_minspacing {Linear Unit}:
          Indicates the shortest distance between a hydrographic segment that is
          sensible to display at the output scale. If the spacing between two
          parallel trending features is smaller than this value, one of the
          features will be set as invisible. It defines a sense of the density
          of the resulting thinned hydrography. It should correspond to the
          distance between two parallel trending features that is visually
          significant to include at the final scale. When the density of
          features is too high (that is, the features are too closely spaced),
          at least one feature will be hidden. This can result in important
          features or features longer than the hydroline_minlength being hidden.
      hydroarea_minlength {Linear Unit}:
          The length used to split and classify hydrographic polygons as short
          or long. Polygons will be split at any location where the edge-to-edge
          distance is equal to the hydroarea_minlength.
      hydroarea_minwidth {Linear Unit}:
          The width used to split and classify hydrographic polygons as narrow
          or wide. Polygons will be split at any location where the edge-to-edge
          distance is equal to the hydroarea_minwidth."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateElevationGuideFeatures_topographic(*gp_fixargs((in_feature_dataset, area_of_interest, in_rasters, hydro_exclusion_features, spot_height_features, hydro_line_features, hydro_area_features, contour_interval, bands_minarea, smooth_tolerance, number_of_bands, height_field, search_distance, hydroline_minlength, hydroline_minspacing, hydroarea_minlength, hydroarea_minwidth), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateSpotHeights_topographic', None)
def GenerateSpotHeights(in_contour_features=None, in_raster=None, target_spot_features=None, contour_height_field=None, spot_height_field=None, spot_height_subtype=None, area_of_interest=None):
    """GenerateSpotHeights_topographic(in_contour_features, in_raster;in_raster..., target_spot_features, contour_height_field, spot_height_field, {spot_height_subtype}, {area_of_interest})

        Creates elevation point features based on contour tops and
        depressions. Elevation points are created in each top and depression.
        Point height values are populated based on a digital elevation model.

     INPUTS:
      in_contour_features (Feature Layer):
          Contours from which spot heights are computed.
      in_raster (Raster Layer / Mosaic Layer):
          Rasters used to derive the highest or lowest elevations in contour
          tops or depressions.
      target_spot_features (Feature Layer):
          An existing point feature layer or feature class in which spot heights
          are created.
      contour_height_field (Field):
          The field in the input contours that contains elevation values. The
          field type must be numeric.
      spot_height_field (Field):
          The field in the output spot heights to which elevation values are
          written.
      spot_height_subtype {String}:
          Spot height subtype value assigned to new spot height features that
          are created.
      area_of_interest {Feature Layer}:
          The extent where spot heights will be created. The area of interest
          (AOI) is the outer extent of all selected polygons in the feature
          layer. If none are selected, the extent of the raster will be used.
          This parameter does not accept point layers as valid input."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateSpotHeights_topographic(*gp_fixargs((in_contour_features, in_raster, target_spot_features, contour_height_field, spot_height_field, spot_height_subtype, area_of_interest), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateTopographicContours_topographic', None)
def GenerateTopographicContours(in_rasters=None, area_of_interest=None, contour_features=None, elevation_field=None, contour_subtype=None, scale=None, resample_raster=None, contour_interval=None, base_contour=None, z_factor=None, zero_contour=None, code_field=None, index_interval=None, index_code=None, intermediate_code=None, depression_code=None, depression_intermediate_code=None, raster_smooth_tolerance=None, minimum_length=None, contour_smooth_tolerance=None):
    """GenerateTopographicContours_topographic(in_rasters;in_rasters..., area_of_interest, contour_features, elevation_field, {contour_subtype}, {scale}, {resample_raster}, {contour_interval}, {base_contour}, {z_factor}, {zero_contour}, {code_field}, {index_interval}, {index_code}, {intermediate_code}, {depression_code}, {depression_intermediate_code}, {raster_smooth_tolerance}, {minimum_length}, {contour_smooth_tolerance})

        Creates and smooths contours from an input raster.

     INPUTS:
      in_rasters (Raster Layer / Mosaic Layer):
          The input raster layers used to derive the contour lines.
      area_of_interest (Feature Layer):
          A feature layer used to clip the input raster before processing. A
          buffer is created before clipping the raster, which results in larger
          output contours that extend beyond the selected AOI. The feature layer
          must have only one selected feature.
      contour_features (Feature Layer):
          An existing line feature class or feature layer. Contours will be
          appended to this feature class.
      elevation_field (Field):
          The field from the input contours that will store the contour
          elevation value. This field defaults to ZV2 or ZVH if a field with
          either of those names exists in the contour feature class.
      contour_subtype {String}:
          The subtype to which contours will be written if the input contours
          have subtypes.
      scale {String}:
          Specifies the scale that will be used to optimize contours (the scale
          of the cartographic product that will be printed). Choosing the scale
          will set the defaults of other parameters to values that are
          appropriate for the output scale. The default value is the 1:50,000
          cartographic product scale.

          * 1:5,000-The 1:5,000 cartographic product scale will be used.

          * 1:10,000-The 1:10,000 cartographic product scale will be used.

          * 1:12,500-The 1:12,500 cartographic product scale will be used.

          * 1:25,000-The 1:25,000 cartographic product scale will be used.

          * 1:50,000-The 1:50,000 cartographic product scale will be used. This
          is the default.

          * 1:100,000-The 1:100,000 cartographic product scale will be used.

          * 1:250,000-The 1:250,000 cartographic product scale will be used.

          * 1:500,000-The 1:500,000 cartographic product scale will be used.

          * 1:1,000,000-The 1:1,000,000 cartographic product scale will be used.
      resample_raster {Boolean}:
          Specifies whether the input raster will be resampled before creating
          contours.

          * RESAMPLE_RASTER-The input raster will be resampled before creating
          contours. This is the default.

          * NO_RESAMPLE_RASTER-The input raster will not be resampled when
          creating contours.
      contour_interval {Double}:
          The interval, or distance, between contour lines. This can be any
          positive number. The default is set by the scale value. If this
          parameter is left blank, the default scale value will be used.
      base_contour {Double}:
          Contours are generated above and below this value to cover the entire
          value range of the input raster. The default is 0.
      z_factor {Double}:
          The unit conversion factor used when generating contours. The default
          value is 1.The contour lines are generated based on the z-values in
          the input
          raster, which are often measured in units of meters or feet. With the
          default value of 1, the contours will be in the same units as the
          z-values of the input raster. To create contours in a unit other than
          that of the z-values, set an appropriate value for the z-factor. It is
          not necessary that the ground x,y and surface z-units be consistent
          for this tool.For example, if the elevation values in your input
          raster are in feet,
          but you want the contours to be generated in meters, set the z-factor
          to 0.3048 (1 foot = 0.3048 meters).
      zero_contour {Boolean}:
          Specifies whether a zero contour will be created. A zero contour
          represents sea level. Zero contours, when generated along a coastline,
          may be created inside a water body. Specify ZERO_CONTOUR if you want
          contours generated on land areas that are at or below sea level.

          * ZERO_CONTOUR-A zero contour will be created.

          * NO_ZERO_CONTOUR-A zero contour will not be created. This is the
          default.
      code_field {Field}:
          The field from the input contour feature class where the appropriate
          code will be stored. The field defaults to the HQC field if it exists
          in the input contour feature class.
      index_interval {Long}:
          The interval, or distance, between index contour lines. For example,
          if the contour interval is 20 meters and you want index contours every
          100 meters, specify 100. The default is set by the scale value.
      index_code {String}:
          The code value to be stored in the Contour Code Field (code_field in
          Python) when an index contour is identified. The default code will be
          1 if the HQC field exists in the input contour feature class.
      intermediate_code {String}:
          The code value to be stored in the Contour Code Field (code_field in
          Python) when an intermediate contour is identified. The default code
          will be 2 if the HQC field exists in the input contour feature class.
      depression_code {String}:
          The code value to be stored in the Contour Code Field (code_field in
          Python) when a depression contour is identified. The default code will
          be 5 if the HQC field exists in the input contour feature class.
      depression_intermediate_code {String}:
          The code value to be stored in the Contour Code Field (code_field in
          Python) when a depression intermediate contour is identified. The
          default code will be 61 if the HQC field exists in the input contour
          feature class.
      raster_smooth_tolerance {Double}:
          The amount of smoothing to apply to the input raster before creating
          the contour lines.
      minimum_length {Linear Unit}:
          The minimum length for an individual contour line. The default value
          is set by the scale value. If the value is set to 0 or left blank, no
          contours will be removed from the output contours based on their short
          length.
      contour_smooth_tolerance {Linear Unit}:
          The amount of smoothing to apply to the contour lines. The larger the
          value, the more generalized the contours. The default value is set by
          the scale value. If this parameter is set to 0 or left blank, no
          smoothing will be applied to the output contours."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateTopographicContours_topographic(*gp_fixargs((in_rasters, area_of_interest, contour_features, elevation_field, contour_subtype, scale, resample_raster, contour_interval, base_contour, z_factor, zero_contour, code_field, index_interval, index_code, intermediate_code, depression_code, depression_intermediate_code, raster_smooth_tolerance, minimum_length, contour_smooth_tolerance), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('IdentifyContours_topographic', None)
def IdentifyContours(in_contour_features=None, in_rasters=None, contour_height_field=None, contour_code_field=None, contour_index_interval=None, index_code=None, intermediate_code=None, depression_code=None, depression_intermediate_code=None):
    """IdentifyContours_topographic(in_contour_features, in_rasters;in_rasters..., contour_height_field, contour_code_field, {contour_index_interval}, {index_code}, {intermediate_code}, {depression_code}, {depression_intermediate_code})

        Identifies types of contours and applies hypsographic codes to input
        features.

     INPUTS:
      in_contour_features (Feature Layer):
          The input contours that will be updated with the specified contour
          codes.
      in_rasters (Raster Layer / Mosaic Layer):
          The rasters used to derive elevations of points inside contours to
          correctly identify the types of contours.
      contour_height_field (Field):
          The field in the input contour feature class that contains elevation
          values. This field type must be numeric.
      contour_code_field (Field):
          The field in the input contour feature class that will be updated with
          the appropriate domain code.
      contour_index_interval {Long}:
          The interval or distance between index contour lines. The default is
          100.
      index_code {String}:
          The value used to populate the contour_code_field parameter when index
          contours are identified. The default is 1.
      intermediate_code {String}:
          The value used to populate the contour_code_field parameter when
          intermediate contours are identified. The default is 2.
      depression_code {String}:
          The value used to populate the contour_code_field parameter when
          depression contours are identified. The default is 5.
      depression_intermediate_code {String}:
          The value used to populate the contour_code_field parameter when
          depression intermediate contours are identified. The default is 6."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.IdentifyContours_topographic(*gp_fixargs((in_contour_features, in_rasters, contour_height_field, contour_code_field, contour_index_interval, index_code, intermediate_code, depression_code, depression_intermediate_code), True)))
        return retval
    except Exception as e:
        raise e


# Cartography\Layout toolset
@gptooldoc('GenerateProductLayout_topographic', None)
def GenerateProductLayout(geodatabase=None, aoi_layer=None, product=None, version=None, output_location=None, rasters=None, template=None):
    """GenerateProductLayout_topographic(geodatabase, aoi_layer, product, version, output_location, {rasters;rasters...}, {template})

        Automates the process of producing a layout or map based on a standard
        specification.A product file installer is available for ArcGIS
        Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined
        layout PAGX templates that can be used for cartographic
        production.Learn more about Defense Mapping product files and
        Production Mapping
        product files.

     INPUTS:
      geodatabase (Workspace):
          The input geodatabase that contains the features for the final map
          product. The schema of the workspace must match the schema of the
          product selected.
      aoi_layer (Feature Layer):
          A polygon feature layer that describes the processing extent. The
          feature layer must have only one feature selected or must be a feature
          class with only one feature.
      product (String):
          The list of supported map products.
      version (String):
          The list of supported versions for the selected product.
      output_location (Folder):
          The full folder path to which the output .pagx file will be written.
      rasters {Raster Layer / Mosaic Layer}:
          The input rasters used if the product requires an elevation guide
          surround element to calculate the elevation bands and spot height
          features. If you specify more than one raster, the rasters must have
          the same cell size, band number, and pixel type. If no raster is
          specified, the tool will not process the elevation guide data frame
          and will give a warning.
      template {Layout}:
          The layout template to be used. If no layout template is specified,
          the default layout template for the product will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateProductLayout_topographic(*gp_fixargs((geodatabase, aoi_layer, product, version, output_location, rasters, template), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MakeGridsAndGraticulesLayer_topographic', None)
def MakeGridsAndGraticulesLayer(in_grid_xml=None, area_of_interest=None, target_feature_dataset=None, out_layer_name=None, grid_name=None, configure_layout=None, layout=None, map_frame=None, reference_scale=None, rotation=None, mask_size=None, xy_tolerance=None, primary_coordinate_system=None, ancillary_coordinate_system_1=None, ancillary_coordinate_system_2=None, ancillary_coordinate_system_3=None, ancillary_coordinate_system_4=None):
    """MakeGridsAndGraticulesLayer_topographic(in_grid_xml, area_of_interest, target_feature_dataset, out_layer_name, {grid_name}, {configure_layout}, {layout}, {map_frame}, {reference_scale}, {rotation}, {mask_size}, {xy_tolerance}, {primary_coordinate_system}, {ancillary_coordinate_system_1}, {ancillary_coordinate_system_2}, {ancillary_coordinate_system_3}, {ancillary_coordinate_system_4})

        Creates a grouped layer of feature classes depicting grid, graticule,
        and border features using predefined cartographic specifications. Grid
        layers are ideal for advanced grid definitions that are scale and
        extent specific.Each grid layer can be composed of a mask (polygon),
        clip (polygon),
        segments (line), gridlines (line), ticks (line), endpoints (point),
        points (point), and annotation feature classes. These components are
        stored as features in corresponding feature classes. These feature
        classes are saved in a specified feature dataset in a geodatabase.
        There are seven feature classes that store the basic components of a
        grid. Each feature class is named with a three-letter prefix that
        helps identify the grid component the feature class holds. These
        feature classes/components are as follows:

        * ANO_ is the annotation feature class.

        * CLP_ is the clip feature class.

        * EPT_ is the endpoints feature class.

        * GLN_ is the gridlines feature class.

        * MSK_ is the masks feature class.

        * PNT_ is the points feature class.

        * SEG_ is the segments feature class.

        * TKS_ is the ticks feature class.
        These feature classes can hold information for multiple grids. An
        eighth feature class (GRD_) contains organizational information, such
        as map name and grid types that are used to organize your grids.The
        grid definition template is stored in a predefined XML file. This
        file stores specification properties for each grid, such as the
        number, color, and line weight of gridlines. When the definition
        template is applied, features are created according to the
        specification based on the current extent or extent of a selected
        feature (area of interest), scale, and coordinate systems.A product
        file installer is available for ArcGIS Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined
        layout PAGX templates that can be used for cartographic
        production.Learn more about Defense Mapping product files and
        Production Mapping
        product files.

     INPUTS:
      in_grid_xml (File):
          The XML grid definition template that stores the specification's
          graphic properties for each grid layer. In addition to the graphic
          properties, which cannot be altered before execution, the definition
          has specific default values, exposed as parameters, that can be
          modified before execution.
      area_of_interest (Feature Layer / Extent):
          The polygon feature layer or geographic extent used to determine the
          area over which the grid features are created.
      target_feature_dataset (Feature Dataset):
          The feature dataset that will store the grid features. Grid-specific
          feature classes will be created if they do not already exist. If they
          already exist, and a grid with the same name and type as the one being
          created also exists, it will be overwritten.
      grid_name {String / Field}:
          The name used to uniquely identify the grid. You can use a unique name
          for the grid or choose a field from the input area of interest feature
          layer.
      configure_layout {Boolean}:
          Adjusts the map, map frame, and layout settings to ensure they match
          the grid layer. The map's coordinate system as well as the map frame's
          scale, rotation, size, and extent can be altered to enforce
          consistency. This setting requires that a map frame is chosen from the
          map_frame parameter.

          * CONFIGURE_LAYOUT-The data frame and layout are configured using grid
          settings.

          * NO_CONFIGURE_LAYOUT-The data frame and layout are not configured.
          This is the default.
      layout {Layout}:
          The layout that contains the map frame to which the grid will be added
          when the configure_layout parameter is enabled. The layout can be in
          the current project or from an existing layout file.
      map_frame {String}:
          The map frame that will be updated. The map associated with the map
          frame can also be updated.
      reference_scale {Double}:
          The scale at which the grid is created and should be viewed.
          When the reference scale from the XML grid definition file is defined
          as Use Environment, the reference scale is derived in the following
          order:

          * The geoprocessing Reference Scale environment setting

          * The active data frame's reference scale

          * The active data frame's scale

          * The value from the XML grid definition file
      rotation {Double}:
          The rotation angle for the grid components. Rotation is used to
          create annotation features that are aligned with the page. Unless
          otherwise specified, rotation is calculated using the area of interest
          feature. When the rotation type from the XML grid definition file is
          defined as Use Environment, the rotation is derived in the following
          order:

          * The active data frame's rotation

          * The value from the XML grid definition file
      mask_size {Linear Unit}:
          The mask is a polygon feature that forms an outer ring around the
          extent of the neatline and is used to mask data that falls in the area
          reserved for coordinate labels. Mask size defines the width of the
          polygon mask feature in map or page units. The data frame may need to
          be resized to fit around the edge of the mask while including the
          coordinate labels.
      xy_tolerance {Linear Unit}:
          The minimum distance between geodatabase features, expressed in linear
          units. This value defaults to the value set in the grid XML. You can
          set higher values for data with less coordinate accuracy and lower
          values for data with extremely high accuracy. Features that fall
          within the set x,y tolerance will be considered coincident.
      primary_coordinate_system {Spatial Reference}:
          The primary coordinate system used to create grid features. The final
          product or data frame should use the same coordinate system. This
          coordinate system must be a projected coordinate system. When
          the primary coordinate system in the XML grid definition
          file is defined as Use Environment, the default primary coordinate
          system is derived in the following order:

          * The geoprocessing Cartographic Coordinate System environment setting

          * The active data frame's coordinate system if it is a projected
          coordinate system

          * The Fixed value from the XML grid definition file
      ancillary_coordinate_system_1 {Spatial Reference}:
          The first of up to four ancillary coordinate systems used to create
          grid features. The grid template XML file specifies the number of
          ancillary grids.
      ancillary_coordinate_system_2 {Spatial Reference}:
          The second of up to four ancillary coordinate systems used to create
          grid features. The grid template XML file specifies the number of
          ancillary grids.
      ancillary_coordinate_system_3 {Spatial Reference}:
          The third of up to four ancillary coordinate systems used to create
          grid features. The grid template XML file specifies the number of
          ancillary grids.
      ancillary_coordinate_system_4 {Spatial Reference}:
          The fourth of up to four ancillary coordinate systems used to create
          grid features. The grid template XML file specifies the number of
          ancillary grids.

     OUTPUTS:
      out_layer_name (Group Layer):
          The name of the group layer that will be created to contain the
          symbolized grid and graticule feature classes. The group layer can be
          composed of the following layers for grid elements:

          * Mask (polygon)

          * Clip (polygon)

          * Segments (line)

          * Gridlines (line)

          * Ticks (line)

          * Endpoints (point)

          * Points (point)

          * Annotation
          This is a temporary layer that you must save in the project or as a
          layer file."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeGridsAndGraticulesLayer_topographic(*gp_fixargs((in_grid_xml, area_of_interest, target_feature_dataset, out_layer_name, grid_name, configure_layout, layout, map_frame, reference_scale, rotation, mask_size, xy_tolerance, primary_coordinate_system, ancillary_coordinate_system_1, ancillary_coordinate_system_2, ancillary_coordinate_system_3, ancillary_coordinate_system_4), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PopulateMapSheetInfo_topographic', None)
def PopulateMapSheetInfo(in_layout=None, area_of_interest=None, lookup_table=None):
    """PopulateMapSheetInfo_topographic(in_layout, area_of_interest, lookup_table)

        Populates text in graphic elements on a map layout.Text is populated
        with feature attribute values from a selected area
        of interest (AOI) feature in the map. The tool searches each graphic
        element for tagged (<tag></tag>) text. It compares tagged text to
        values in the PopMapInfo table. Any matching values are replaced in
        the graphic element with an attribute value from the selected AOI
        feature.The PopMapInfo table, similar to a lookup table, maintains the
        relationship between feature attributes and tagged text strings. The
        table contains the Field_Name and DM_Tag fields, which control the
        mapping between feature attributes and graphic elements. For example,
        the table maps the Sheet attribute to text with the SHEET tag
        (<dm021>text</dm021>). All text within the tag will be updated;
        therefore, the tool can be run as needed when feature attributes are
        updated. Custom Field_Name and DM_Tag fields can be added to the table
        to allow for use of new feature attributes and associated graphic
        elements.Defense Mapping map templates often use graphic elements with
        bracketed ([ ]) text to indicate text that should be updated to meet
        the product specification. However, brackets are not required by the
        Populate Map Sheet Info tool.

     INPUTS:
      in_layout (Layout):
          The input layout that contains graphic elements with tagged text
          strings to be updated.
      area_of_interest (Feature Layer):
          A feature layer with a selection set containing one AOI feature. This
          parameter only accepts only polygon features. The tool writes
          attribute values from this feature to tagged text strings in defense-
          specific graphic elements.
      lookup_table (Table View):
          An input table that contains the Field_Name and DM_Tag fields."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PopulateMapSheetInfo_topographic(*gp_fixargs((in_layout, area_of_interest, lookup_table), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Features toolset
@gptooldoc('CalculateDefaultValues_topographic', None)
def CalculateDefaultValues(in_datasets=None):
    """CalculateDefaultValues_topographic(in_datasets;in_datasets...)

        Replaces null values in a feature class or table with the default
        values from the geodatabase feature class.

     INPUTS:
      in_datasets (Table View / Feature Layer / Dataset):
          The feature classes and/or tables whose null values will be replaced
          with the default values from the data model."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDefaultValues_topographic(*gp_fixargs((in_datasets,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CalculateMetrics_topographic', None)
def CalculateMetrics(in_features=None, in_metric_types=None, in_length_attributes=None, in_width_attributes=None, in_area_attributes=None, in_angle_attributes=None, in_elevation_attributes=None, in_precision=None):
    """CalculateMetrics_topographic(in_features;in_features..., in_metric_types;in_metric_types..., {in_length_attributes}, {in_width_attributes}, {in_area_attributes}, {in_angle_attributes}, {in_elevation_attributes}, {in_precision})

        Populates metrics for features in a geodatabase. Metrics include
        length, width, area, and elevation attributes.

     INPUTS:
      in_features (Feature Layer):
          The features on which metrics will be calculated.
      in_metric_types (String):
          Specifies the types of metrics to calculate, including angle of
          orientation, area, elevation, length, and width.

          * ANGLE_OF_ORIENTATION-Calculate angle of orientation metrics

          * AREA-Calculate area metrics

          * ELEVATION-Calculate elevation metrics

          * LENGTH-Calculate length metrics

          * WIDTH-Calculate width metrics
      in_length_attributes {String}:
          A comma-delimited string of field names from which the length metrics
          will be calculated. The default is LEG,LEN,LEN_,LGN,LZN. You can add
          the names of other length metric fields; if the fields exist in Input
          Features, they will be computed.
      in_width_attributes {String}:
          A comma-delimited string of field names from which the width metrics
          will be calculated. The default is WID,WID_,WGP. You can add the names
          of other width metric fields; if the fields exist in Input Features,
          they will be computed.
      in_area_attributes {String}:
          A comma-delimited string of field names from which the area metrics
          will be calculated. The default is ARA,ARE,ARE_. You can add the names
          of other area metric fields; if the fields exist in Input Features,
          they will be computed.
      in_angle_attributes {String}:
          A comma-delimited string of field names from which the angle of
          orientation metrics will be calculated. The default is AOO,DOF,FEO.
          You can add the names of other angle of orientation metric fields; if
          the fields exist in Input Features, they will be computed.
      in_elevation_attributes {String}:
          A comma-delimited string of field names from which the elevation
          metrics will be calculated. The default is ZV2,ZVH. You can add the
          names of other elevation metric fields; if the fields exist in Input
          Features, they will be computed.
      in_precision {Long}:
          The precision of the metrics written to the target attributes."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateMetrics_topographic(*gp_fixargs((in_features, in_metric_types, in_length_attributes, in_width_attributes, in_area_attributes, in_angle_attributes, in_elevation_attributes, in_precision), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveCutbackVertices_topographic', None)
def RemoveCutbackVertices(in_features=None, minimum_angle=None, removal_method=None, skip_coincident_vertices=None):
    """RemoveCutbackVertices_topographic(in_features, minimum_angle, {removal_method}, {skip_coincident_vertices})

        Removes unwanted cutbacks for polyline and polygon feature classes or
        layers.Cutbacks are high-angle turns that cause features to turn back
        toward
        themselves. These angles affect polyline and polygon features and can
        be caused during an editing session. For example, through a digitizing
        error, a river feature may have a short segment (less than one meter)
        that turns back toward itself and back in the original direction
        again.

     INPUTS:
      in_features (Feature Layer):
          The polyline or polygon feature class from which the tool will remove
          cutback vertices. This feature class (or layer) will be modified.
      minimum_angle (Double):
          The minimum angle threshold value (in degrees). The angle value should
          be within the range of 0-180. If the angle formed by a vertex and its
          two neighboring points is below the specified minimum angle, the
          vertex is a candidate for cutback removal.
      removal_method {String}:
          Indicates whether cutbacks should be removed one at a time or all at
          once.

          * SEQUENTIAL-Cutbacks will be checked sequentially for a feature.
          After a cutback is removed, the change in geometry is taken into
          consideration when determining cutbacks in the remaining vertices of a
          feature. This is the default.

          * ALL-Cutbacks will be checked for all vertices at once.
      skip_coincident_vertices {Boolean}:
          Indicates whether to Remove Cutback Vertices when the vertex is
          snapped to another feature within the same feature class.

          * SKIP_COINCIDENT-Vertices that have angles less than the
          minimum_angle will not be removed from the feature geometry if they
          are snapped to other features.

          * REMOVE_COINCIDENT-Cutback points will be deleted without considering
          whether they are snapped to other features. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveCutbackVertices_topographic(*gp_fixargs((in_features, minimum_angle, removal_method, skip_coincident_vertices), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RepairSelfIntersection_topographic', None)
def RepairSelfIntersection(in_features=None, repair_type=None, max_length=None, repair_at_end_point=None):
    """RepairSelfIntersection_topographic(in_features, repair_type, {max_length}, {repair_at_end_point})

        Repairs self-intersecting line or polygon features. The portion
        between the feature and the intersection points are either deleted or
        split into a new feature.

     INPUTS:
      in_features (Feature Layer):
          The polyline or polygon feature class from which this tool will repair
          self-intersections.
      repair_type (String):
          Indicates whether the tool will delete or split self-intersections.

          * DELETE-Self-intersections will be deleted. This is the default.

          * SPLIT-Self-intersections will be split at the intersection point and
          retained.
      max_length {Linear Unit}:
          The maximum length of the segment between the points of self-
          intersection. Only segments shorter than the specified maximum length
          are deleted.
      repair_at_end_point {Boolean}:
          Indicates whether this tool will remove, or avoid removing, any self-
          intersections whose end point is snapped on itself.

          * REPAIR_ENDS-Self-intersections will be removed.

          * IGNORE_ENDS-Any feature that has an end point that snaps to itself
          will not be removed. An example is a cul-de-sac. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RepairSelfIntersection_topographic(*gp_fixargs((in_features, repair_type, max_length, repair_at_end_point), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SplitFeatures_topographic', None)
def SplitFeatures(cutting_features=None, target_features=None, use_target_z=None):
    """SplitFeatures_topographic(cutting_features, target_features;target_features..., use_target_z)

        Splits features on input feature classes for any number of polyline or
        polygon target feature classes using the cutting features and inserts
        points on the cutting feature.

     INPUTS:
      cutting_features (Feature Layer):
          The cutting feature used to split the target features where they
          intersect the target feature class geometries.
      target_features (Feature Layer):
          The features that will be divided by the cutting features.
      use_target_z (Boolean):
          Specifies the source of the z-value from the source or target.

          * USE_TARGET_Z-Uses the z-value from the source or target.

          * DONT_USE_TARGET_Z-Does not use the z-value. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SplitFeatures_topographic(*gp_fixargs((cutting_features, target_features, use_target_z), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateGeoNames_topographic', None)
def UpdateGeoNames(in_features=None, in_geonames_features=None, in_geonames_table=None, named_feature_id_field=None, name_id_field=None, name_field=None):
    """UpdateGeoNames_topographic(in_features;in_features..., in_geonames_features, in_geonames_table, named_feature_id_field, name_id_field, name_field)

        Updates the name field on input features based on the information from
        GeoNames_FeaturesP and GEONAMES_TABLE.

     INPUTS:
      in_features (Feature Layer):
          The input features that will be updated. Each in_features value should
          have field names matching the values specified for the
          named_feature_id_field, name_id_field, and name_field parameters.
      in_geonames_features (Feature Layer):
          The input GeoNames features that identify unique named feature
          locations.
      in_geonames_table (Table View):
          A table containing name records related to the input GeoNames
          features.
      named_feature_id_field (Field):
          The field storing GeoNames named feature identifier values. These
          values should not be null or empty on the input features.
      name_id_field (Field):
          The field to store GeoNames name identifier values.
      name_field (Field):
          The field to store GeoNames name values."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateGeoNames_topographic(*gp_fixargs((in_features, in_geonames_features, in_geonames_table, named_feature_id_field, name_id_field, name_field), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Generalization toolset
@gptooldoc('EliminatePolygon_topographic', None)
def EliminatePolygon(in_features=None, surrounding_features=None, min_area=None):
    """EliminatePolygon_topographic(in_features, surrounding_features;surrounding_features..., {min_area})

        Eliminates a polygon by merging it with the polygon from the
        surrounding features that it shares the longest boundary with.

     INPUTS:
      in_features (Feature Layer):
          The feature layers that contain the polygons to be deleted.
      surrounding_features (Feature Layer):
          The polygon features that the Input Features are compared against. If
          the feature is smaller than the Minimum Area, it becomes part of the
          input features.
      min_area {Areal Unit}:
          Polygons smaller than the Minimum Area will be deleted. If the Minimum
          Area is left blank, all features or a selection set from the Input
          Features will be considered for elimination."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EliminatePolygon_topographic(*gp_fixargs((in_features, surrounding_features, min_area), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportGeneralizedData_topographic', None)
def ExportGeneralizedData(input_geodatabase=None, target_geodatabase=None, rule_file=None, data_theme=None, export_visible_features=None):
    """ExportGeneralizedData_topographic(input_geodatabase, target_geodatabase, rule_file, data_theme, {export_visible_features})

        Exports data generalized by the ArcGIS Production Mapping theme-based
        generalization models into a production schema using generalization
        rules defined in a Microsoft Excel spreadsheet.A product file
        installer is available for ArcGIS Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined
        generalization XLSX rule files.Learn more about Defense Mapping
        product files and Production Mapping
        product files.

     INPUTS:
      input_geodatabase (Workspace):
          The geodatabase containing data in the generalization schema.
      target_geodatabase (Workspace):
          The geodatabase where the generalized data will be loaded.
      rule_file (File):
          The Excel file containing the generalization rules. This file defines
          features participating in the generalization process and determines
          the data that will be loaded and how it is organized. An example rule
          file is provided in the product file downloads for Defense Mapping and
          Production Mapping.
      data_theme (String):
          A theme that specifies the type of data to be generalized.
          Available themes are automatically populated from the Generalization
          Rule File parameter. The values provided in the example rule file are
          as follows:

          * TRANS-A data theme that groups features in a transportation network
          such as roads and railways.

          * STRUCTURE-A data theme that groups structural features such as
          buildings.

          * HYDRO-A data theme that groups water features such as lakes and
          rivers.

          * SOE-A skin of the earth data theme that groups polygon features that
          cover the entire surface of the earth with no holes or gaps. It can
          consist of water, vegetation, land, and artificial features.

          * GENERAL-A data theme that groups features other than those defined
          by another theme.
      export_visible_features {Boolean}:
          Specifies whether features with a value of 1 in the visibility field
          will be exported to the target database.

          * EXPORT_VISIBLE-Features with the visibility field set to 1 will not
          be exported.

          * EXPORT_ALL-All features will be exported, regardless of the value in
          the visibility field. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportGeneralizedData_topographic(*gp_fixargs((input_geodatabase, target_geodatabase, rule_file, data_theme, export_visible_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FillGaps_topographic', None)
def FillGaps(input_features=None, max_gap_area=None, fill_option=None, fill_unenclosed_gaps=None, max_gap_distance=None):
    """FillGaps_topographic(input_features;input_features..., max_gap_area, {fill_option}, {fill_unenclosed_gaps}, {max_gap_distance})

        Fills gaps between polygon features that participate in a topology
        where the coincident boundaries are evident.Many types of polygon
        features should have coincident boundaries with
        other features. Coincident boundaries may be important for features
        within a single polygon feature class, such as parcels, or between
        features in different feature classes, such as lakes and surrounding
        vegetation. A gap between the features exists when there is space
        between the boundaries of two or more features.

     INPUTS:
      input_features (Feature Layer):
          A list of input polygon feature classes or layers to be analyzed for
          gaps.
      max_gap_area (Areal Unit):
          The maximum area that can be considered a gap. Areas larger than this
          threshold will not be filled.
      fill_option {String}:
          Specifies how enclosed and unenclosed gaps are filled.

          * FILL_BY_LENGTH-Fills gaps by adding a gap's geometry to the polygon
          with the longest shared edge. This is the default.

          * FILL_BY_ORDER-Fills sequentially according to the order of the Input
          Polygon Features list.
      fill_unenclosed_gaps {Boolean}:
          Specifies if the tool will fill unenclosed gaps.

          * SKIP_UNENCLOSED_GAPS-Fills only enclosed gaps while skipping
          unenclosed ones. This is the default.

          * FILL_ALL-Fills both enclosed and unenclosed gaps.
      max_gap_distance {Linear Unit}:
          The maximum distance between features in which a gap can be filled.
          Used only when the fill_unenclosed_gaps parameter is set to
          SKIP_UNENCLOSED_GAPS."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FillGaps_topographic(*gp_fixargs((input_features, max_gap_area, fill_option, fill_unenclosed_gaps, max_gap_distance), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('IdentifyNarrowPolygons_topographic', None)
def IdentifyNarrowPolygons(in_features=None, out_feature_class=None, min_width=None, min_length=None, taper_length=None, connecting_features=None):
    """IdentifyNarrowPolygons_topographic(in_features, out_feature_class, min_width, min_length, {taper_length}, {connecting_features;connecting_features...})

        Splits a polygon based on its width and classifies each portion as
        narrow or wide based on its width and length.

     INPUTS:
      in_features (Feature Layer):
          The features to be split.
      min_width (Linear Unit):
          The width used to split and classify polygons as narrow or wide.
          Polygons will be split at any location where the edge-to-edge distance
          is equal to the Minimum Width.
      min_length (Linear Unit):
          The length used to classify the split polygons as short or long.
      taper_length {Linear Unit}:
          The distance the end of the split feature will extend to provide a
          more natural break.
      connecting_features {Feature Layer}:
          The features that will be used to refine the tapering of wide areas.
          The polygons will be tapered toward the touch point or the shared
          boundary of a connecting feature.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class containing the results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.IdentifyNarrowPolygons_topographic(*gp_fixargs((in_features, out_feature_class, min_width, min_length, taper_length, connecting_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportGeneralizationData_topographic', None)
def ImportGeneralizationData(input_geodatabase=None, target_geodatabase=None, rule_file=None, data_theme=None):
    """ImportGeneralizationData_topographic(input_geodatabase, target_geodatabase, rule_file, data_theme)

        Imports data from a production schema to a themed generalization
        database using generalization rules defined in a Microsoft Excel
        spreadsheet.A product file installer is available for ArcGIS
        Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined
        generalization XLSX rule files.Learn more about Defense Mapping
        product files and Production Mapping
        product files.

     INPUTS:
      input_geodatabase (Workspace):
          The geodatabase containing data in a production schema.
      target_geodatabase (Workspace):
          The target geodatabase where the data optimized for generalization
          will be loaded.
      rule_file (File):
          The Excel file containing the generalization rules. This file defines
          features participating in the generalization process and determines
          the data that will be loaded and how it is organized. An example rule
          file is provided in the product file downloads for Defense Mapping and
          Production Mapping.
      data_theme (String):
          A theme that specifies the type of data to be generalized.
          Available themes are automatically populated from the Generalization
          Rule File parameter. The values provided in the example rule file are
          as follows:

          * TRANS-A data theme that groups features in a transportation network
          such as roads and railways.

          * STRUCTURE-A data theme that groups structural features such as
          buildings.

          * HYDRO-A data theme that groups water features such as lakes and
          rivers.

          * SOE-A skin of the earth data theme that groups polygon features that
          cover the entire surface of the earth with no holes or gaps. It can
          consist of water, vegetation, land, and artificial features.

          * GENERAL-A data theme that groups features other than those defined
          by another theme."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportGeneralizationData_topographic(*gp_fixargs((input_geodatabase, target_geodatabase, rule_file, data_theme), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PolygonToCenterline_topographic', None)
def PolygonToCenterline(in_features=None, out_feature_class=None, connecting_features=None):
    """PolygonToCenterline_topographic(in_features, out_feature_class, {connecting_features;connecting_features...})

        Creates centerlines from polygon features. This tool is useful for
        creating centerlines from hydrographic polygons for use at smaller
        scales.

     INPUTS:
      in_features (Feature Layer):
          The polygon features that will be used to create the centerline.
      connecting_features {Feature Layer}:
          The features to be used to ensure connectivity of the centerline with
          other features in a network. The centerline will link to the point or
          the shared boundary wherever a feature from a connecting feature class
          touches the input feature.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class for the centerlines."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PolygonToCenterline_topographic(*gp_fixargs((in_features, out_feature_class, connecting_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RemoveSmallLines_topographic', None)
def RemoveSmallLines(in_features=None, minimum_length=None, maximum_angle=None, in_intersecting_features=None, recursive=None, split_input_lines=None):
    """RemoveSmallLines_topographic(in_features, minimum_length, {maximum_angle}, {in_intersecting_features;in_intersecting_features...}, {recursive}, {split_input_lines})

        Removes lines that are shorter than a specified minimum length and do
        not connect to other features on one end.

     INPUTS:
      in_features (Feature Layer):
          The features that will have small lines eliminated.
      minimum_length (Linear Unit):
          The minimum length for input lines. Features shorter than this
          distance will be deleted.
      maximum_angle {Long}:
          Any line below the minimum length that is within the defined angle of
          a consecutive line segment will be kept.
      in_intersecting_features {Feature Layer}:
          Additional intersecting features that the input features can be
          compared against when determining whether the feature is a small line.
      recursive {Boolean}:
          Indicates the method used to remove small lines on the line features.

          * NON_RECURSIVE-All the small lines on lines are deleted. The
          remaining lines are not analyzed to see if they are small lines. This
          is the default.

          * RECURSIVE-The small lines are deleted from the lines and the
          remaining lines are analyzed to see if they are considered small
          lines. If they do not meet the minimum_length value, they are
          considered small lines and deleted.
      split_input_lines {Boolean}:
          Splits the input line feature at all intersections before determining
          which small lines to remove.

          * SPLIT-All lines in the input feature class are split at
          intersections to ensure topological integrity. The length of the split
          features, not the original feature geometries, will be considered when
          applying the minimum length value to determine small lines. This is
          the default.

          * NO_SPLIT-Does not split lines before determining which lines to
          remove. Uses the length of the input feature geometries when applying
          the minimum length value to determine small lines."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RemoveSmallLines_topographic(*gp_fixargs((in_features, minimum_length, maximum_angle, in_intersecting_features, recursive, split_input_lines), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ThinHydrologyLines_topographic', None)
def ThinHydrologyLines(in_features=None, invisibility_field=None, min_length=None, min_spacing=None, hierarchy_field=None, intersecting_features=None, unsplit_lines=None, use_angles=None):
    """ThinHydrologyLines_topographic(in_features, invisibility_field, min_length, {min_spacing}, {hierarchy_field}, {intersecting_features;intersecting_features...}, {unsplit_lines}, {use_angles})

        Generates a simplified hydrographic line network for display at a
        smaller scale. The resulting hydrographic network maintains the main
        arteries while thinning less significant features based on hierarchy,
        length, and spacing between features.

     INPUTS:
      in_features (Feature Layer):
          The hydrography line feature to be thinned.
      invisibility_field (Field):
          Features that participate in the thinned hydrography collection will
          have a value of 0. Those that are extraneous have a value of 1. A
          layer definition query can be used to display the results.
      min_length (Linear Unit):
          An indication of the shortest hydrographic segment that is sensible to
          display at the output scale. It defines a sense of the resolution or
          granularity of the resulting thinned hydrography. It should correspond
          to a length that is visually significant to include at the final
          scale. The results of this tool are a balanced compromise between the
          requirements posed by hierarchy, minimum length, minimum spacing,
          angle of connecting features, and directionality of the hydro
          geometry. Therefore, the minimum length value cannot necessarily be
          measured directly in the resulting feature set.
      min_spacing {Linear Unit}:
          An indication of the shortest distance between a hydrographic segment
          that is sensible to display at the output scale. If the spacing
          between two parallel trending features is smaller than this value, one
          of the features will be set as invisible. It defines a sense of the
          density of the resulting thinned hydrography. It should correspond to
          the distance between two parallel trending features that is visually
          significant to include at the final scale. When the density of
          features is too high (that is, the features are too closely spaced),
          at least one feature will be hidden. This can result in important
          features or features longer than the min_length being hidden.An
          indication of the shortest distance between a hydrographic segment
          that is sensible to display at the output scale. If the spacing
          between two parallel trending features is smaller than this value, one
          of the features will be set as invisible. It defines a sense of the
          density of the resulting thinned hydrography. It should correspond to
          the distance between two parallel trending features that is visually
          significant to include at the final scale. When the density of
          features is too high (that is, the features are too closely spaced),
          at least one feature will be hidden. This can result in important
          features or features longer than the Minimum Length being hidden.
      hierarchy_field {Field}:
          This field contains the hierarchical ranking of feature importance,
          where 1 is very important, and larger integers reflect decreasing
          importance. A value of 0 forces the feature to remain visible in the
          final results. It identifies the relative importance of features to
          help establish which features are significant. For optimal results,
          use no more than five levels of hierarchy. Input features with
          Hierarchy = 0 are considered locked and will remain visible, along
          with adjacent features necessary for connectivity.
      intersecting_features {Feature Layer}:
          If a segment is snapped to features in the provided layers, it will
          not be removed. An example would be a small river segment snapped to a
          lake. Even if the segment is under the min_length, it would need to
          remain to ensure that it remains connected to the water body into
          which it flows.
      unsplit_lines {Boolean}:
          This will merge any split features in the in_features to help ensure
          that the main waterway is preserved. If set to NO_UNSPLIT_LINES, the
          ends of the waterway may be removed due to them being under the
          min_length.

          * UNSPLIT_LINES-Features that are closed on both end points will be
          merged before thinning to preserve main hydrographic arteries that
          traverse a long distance. This is the default.

          * NO_UNSPLIT_LINES-Features will remain split before the thinning
          process.
      use_angles {Boolean}:
          If set to USE_ANGLES, the angles between waterway branches will be
          used to help determine the main waterway; the highest angle will be
          used. If disabled, the longest branch will be considered part of the
          main waterway.

          * USE_ANGLES-In junctions with 3 or more waterways, features that are
          closer together in angle will be kept.

          * NO_USE_ANGLES-In junctions with 3 or more waterways, features that
          are longer will be kept. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ThinHydrologyLines_topographic(*gp_fixargs((in_features, invisibility_field, min_length, min_spacing, hierarchy_field, intersecting_features, unsplit_lines, use_angles), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Geodatabase toolset
@gptooldoc('ExportMetadata_topographic', None)
def ExportMetadata(in_cell_features=None, export_location=None):
    """ExportMetadata_topographic(in_cell_features, export_location)

        Exports Multinational Geospatial Co-production Program (MGCP) metadata
        datasets (Cell, Subregion, and Source feature classes) to an XML file.

     INPUTS:
      in_cell_features (Feature Layer):
          The MGCP Cell feature layer to export.
      export_location (Folder):
          The directory where the metadata XML files will be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportMetadata_topographic(*gp_fixargs((in_cell_features, export_location), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExtractDataByFeature_topographic', None)
def ExtractDataByFeature(in_datasets=None, target_gdb=None, reuse_schema=None, filter_feature=None, filter_type=None, checkout_replica=None, replica_name=None, expand_feature_classes_and_tables=None, get_related_data=None):
    """ExtractDataByFeature_topographic(in_datasets;in_datasets..., target_gdb, {reuse_schema}, {filter_feature}, {filter_type}, {checkout_replica}, {replica_name}, {expand_feature_classes_and_tables}, {get_related_data})

        Extracts features from multiple input feature classes into a target
        database.This tool can extract all features, the schema only, or
        features that
        match a filter. Features can be filtered based on a polygon feature.
        The Target Geodatabase parameter can be a database containing input
        schema, or it can be an empty database in which the tool will create a
        schema that matches the input dataset.

     INPUTS:
      in_datasets (Value Table):
          A value table of rows that contain a dataset to extract and a filter
          option for that dataset. Specifying a filter option allows you to
          control how rows are replicated in each dataset. The following are
          filter options:

          * Dataset-Extracts the schema of the dataset to the child workspace

          * Rows Option-Specifies whether to extract all rows, schema
          only, or by filtering criteria.

          * All Rows-Extracts all rows of the dataset to the child workspace.

          * Schema Only-Extracts the schema of the dataset to the child
          workspace.

          * Use Filters-If a feature layer is specified for the Filter Feature
          Layer parameter, the tool extracts features that either intersect or
          are contained by features in the Filter Feature Layer.
      target_gdb (Workspace / GeoDataServer):
          The workspace into which data will be extracted.
      reuse_schema {Boolean}:
          Specifies whether to reuse a geodatabase that contains the schema of
          the data you want to extract. This reduces the amount of time required
          to extract the data. This option is only supported for file
          geodatabases.

          * REUSE-The schema is reused.

          * DO_NOT_REUSE-The schema is not reused. This is the default.
      filter_feature {Feature Layer}:
          A feature layer with one selected feature used to limit the extent of
          the data that will be extracted.
      filter_type {String}:
          Specifies the spatial relationship between Filter Feature Layer and
          Input Datasets using Intersects, Contains, or Clip. The spatial
          relationship is applied to data in an extent defined by the area of
          interest (AOI) specified in the Filter Feature Layer parameter.

          * INTERSECTS-Features in the Input Datasets parameter that intersect
          features in the Filter Feature Layer parameter will be extracted.

          * CONTAINS-Features in the Input Datasets parameter that are contained
          by the selected feature in the Filter Feature Layer parameter will be
          extracted.

          * CLIP-Features in the Input Datasets parameter that intersect
          features in the Filter Feature Layer parameter will be extracted, and
          the features will be split at the AOI boundary and only those within
          the AOI will be kept.
      checkout_replica {Boolean}:
          Specifies whether the data will be checked out, replicated, edited,
          and checked back in one time.

          * CHECKOUT_REPLICA-The replica will be checked out.

          * DO_NOT_CHECKOUT_REPLICA-The replica will not be checked out. This is
          the default.
      replica_name {String}:
          The name of the replica to check out.
      expand_feature_classes_and_tables {String}:
          Specifies whether expanded feature classes and tables-such as those in
          networks, topologies, or relationship classes-will be added.

          * USE_DEFAULTS-The expanded feature classes and tables related to the
          feature classes and tables in the replica will be added. The default
          for feature classes is to replicate all features intersecting the
          spatial filter. If no spatial filter has been provided, all features
          are included. The default for tables is to replicate the schema only.

          * ADD_WITH_SCHEMA_ONLY-Only the schema for the expanded feature
          classes and tables will be added.

          * ALL_ROWS-All rows for expanded feature classes and tables will be
          added.

          * DO_NOT_ADD-No expanded feature classes and tables will be added.
          This is the default.
      get_related_data {Boolean}:
          Specifies whether rows related to existing rows in the replica will be
          replicated. For example, consider a feature (f1) inside the
          replication filter and a related feature (f2) from another class
          outside the filter. Feature f2 is included in the replica if you
          choose to get related data.

          * DO_NOT_GET_RELATED-Related data will not be replicated. This is the
          default.

          * GET_RELATED-Related data will be replicated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtractDataByFeature_topographic(*gp_fixargs((in_datasets, target_gdb, reuse_schema, filter_feature, filter_type, checkout_replica, replica_name, expand_feature_classes_and_tables, get_related_data), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeoNamesToGeodatabase_topographic', None)
def GeoNamesToGeodatabase(in_source=None, in_feature_class=None, in_allow_duplicates=None, in_table=None):
    """GeoNamesToGeodatabase_topographic(in_source, in_feature_class, in_allow_duplicates, in_table)

        Loads GeoNames data into a feature class and table. The feature class
        is composed of point features, and the table contains fields with
        information concerning the naming conventions used for the features.
        The feature class contains the Unique Feature Identifier (UFI) and
        Unique Name Identifier (UNI), which match the same fields in the
        GeoNames table.

     INPUTS:
      in_source (Text File / Shapefile):
          Path to the source file containing GeoNames information. This needs to
          be a properly formatted GeoNames file.
      in_feature_class (Feature Class):
          The GeoNames feature class; this feature class should be in the
          working database.
      in_allow_duplicates (Boolean):
          Allows duplicate features in the GeoNames feature class.

          * ALLOW_DUPLICATES-Allows the tool to import features even if there is
          already an entry in the GeoNames feature class and table.

          * DON'T_ALLOW_DUPLICATES-Prevents the tool from importing features if
          there is another feature with the same geometry and attributes in the
          GeoNames feature class or GeoNames table. This is the default.
      in_table (Table):
          The GeoNames table. This table should be in the working database."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeoNamesToGeodatabase_topographic(*gp_fixargs((in_source, in_feature_class, in_allow_duplicates, in_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GeodatabaseToShape_topographic', None)
def GeodatabaseToShape(in_features=None, output_folder=None, coded_value_domain_export_mode=None, conversion_method=None, create_empties=None):
    """GeodatabaseToShape_topographic(in_features;in_features..., output_folder, coded_value_domain_export_mode, conversion_method, create_empties)

        Exports one or more feature classes in a geodatabase to shapefiles
        using one of three modes: defense, generic, and Multinational
        Geospatial Co-Production Program (MGCP).Each mode controls how the
        output shapefiles are named. The defense
        and MGCP export modes follow Defense Mapping data model requirements.
        The generic mode uses the same logic as the Feature Class To Feature
        Class tool.

     INPUTS:
      in_features (Feature Layer):
          The features used to create the shapefiles.
      output_folder (Folder):
          The folder that will contain the output shapefiles.
      coded_value_domain_export_mode (String):
          Indicates what method will be used to export coded domain values.

          * DESCRIPTIONS-Coded domain values will be exported using their
          descriptions rather than raw values.

          * VALUES-Coded domain values will be exported as raw values. This is
          the default.

          * VALUES_AND_DESCRIPTIONS-Coded domain values will be exported as raw
          values and string descriptions
      conversion_method (String):
          Indicates which conversion method will be applied.

          * DEFENSE_BY_FEATURECLASS-Creates a shapefile based on the feature
          class name and removes trailing underscores from fields.

          * DEFENSE_BY_SUBTYPE-Creates a shapefile based on subtype name,
          exports attributes applicable to that subtype, and removes trailing
          underscores from fields. This is the default.

          * GENERIC_BY_FEATURECLASS-Creates a shapefile for each feature class
          selected. The shapefile name matches the feature class name.

          * GENERIC_BY_SUBTYPE-Creates a shapefile for each subtype of the
          feature class selected. The shapefile name matches the subtype name.

          * MGCP-Creates a shapefile based on the feature class subtype. The
          shapefile is named using the geometry type and feature code. For
          example, the River subtype in the WatrcrsL feature class would be
          exported to a shapefile called LBH140.
      create_empties (Boolean):
          Indicates that the tool will create empty shapefiles if the input
          feature classes are also empty.

          * CREATE_EMPTIES-Create empty shapefiles if the corresponding input
          feature classes are empty.

          * NO_CREATE_EMPTIES-Do not create empty shapefiles if the
          corresponding input feature classes are empty. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GeodatabaseToShape_topographic(*gp_fixargs((in_features, output_folder, coded_value_domain_export_mode, conversion_method, create_empties), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportMetadata_topographic', None)
def ImportMetadata(files=None, in_cell_features=None):
    """ImportMetadata_topographic(files;files..., in_cell_features)

        Imports Multinational Geospatial Co-production Program (MGCP) metadata
        into an MGCP database to perform maintenance on cells and subregions.

     INPUTS:
      files (File):
          The XML files that contain the metadata to import.
      in_cell_features (Feature Layer):
          The Cell feature class where the metadata will be imported."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportMetadata_topographic(*gp_fixargs((files, in_cell_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LoadData_topographic', None)
def LoadData(in_cross_reference=None, in_sources=None, in_target=None, in_dataset_map_defs=None, row_level_errors=None):
    """LoadData_topographic(in_cross_reference, in_sources;in_sources..., in_target, {in_dataset_map_defs;in_dataset_map_defs...}, {row_level_errors})

        Moves features from one schema to another by loading data from a
        source to a target workspace. Data mapping rules described in a cross-
        reference database are applied during loading.Data that matches the
        schema defined in the cross-reference database
        for the source is appended to the target workspace. The cross-
        reference database contains a DatasetMapping table that lists pairs of
        source and target dataset names. Each source and target name pair can
        have a WHERE clause and a subtype. The WHERE clause defines a subset
        of features in the source to append to the target. Subtype identifies
        a subtype in the target feature class into which features are loaded.A
        product file installer is available for ArcGIS Production Mapping
        and ArcGIS Defense Mapping. The product files contain predefined
        cross-reference geodatabases that can be used for loading data.

     INPUTS:
      in_cross_reference (Workspace):
          The path to a cross-reference database.
      in_sources (Workspace):
          A list of workspaces that contain the source features to load into the
          target workspace.
      in_target (Workspace):
          The target workspace that contains the schema referenced in the cross-
          reference database. Source features are loaded into this workspace.
      in_dataset_map_defs {String}:
          The source to target feature class mapping list. The format of this
          string is id | SourceDataset | TargetDataset | WhereClause | Subtype.
      row_level_errors {Boolean}:
          Specifies whether the tool will log errors that occur while inserting
          new rows into feature classes and tables in the in_target parameter.

          * ROW_LEVEL_ERROR_LOGGING-Errors that occur during individual row-
          level inserts will be logged. This is the default.

          * NO_ROW_LEVEL_ERROR_LOGGING-Errors that occur during individual row-
          level inserts will not be logged."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LoadData_topographic(*gp_fixargs((in_cross_reference, in_sources, in_target, in_dataset_map_defs, row_level_errors), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UnzipCellAndImport_topographic', None)
def UnzipCellAndImport(Root_Folder=None, Target_Geodatabase=None):
    """UnzipCellAndImport_topographic(Root_Folder, Target_Geodatabase)

        Unzips and imports compressed Multinational Geospatial Co-production
        Program (MGCP) 1-degree-by-1-degree cell packages (*.zip) into a
        target geodatabase.

     INPUTS:
      Root_Folder (Folder):
          The root folder that contains one or more compressed shapefile cell
          packages in a .zip file.
      Target_Geodatabase (Workspace):
          The geodatabase where the unzipped shapefiles will be imported."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UnzipCellAndImport_topographic(*gp_fixargs((Root_Folder, Target_Geodatabase), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Topology toolset
@gptooldoc('ExportTopology_topographic', None)
def ExportTopology(topology=None, location=None, file_name=None):
    """ExportTopology_topographic(topology, location, file_name)

        Exports a topology from a geodatabase to an .xml file.The .xml file
        contains a definition of a topology, including feature
        class names, topology ranks, topology rules, and cluster tolerance,
        and can be used by the Import Topology tool to recreate a topology in
        a new feature dataset.

     INPUTS:
      topology (Topology / Topology Layer):
          An existing topology in a geodatabase. All feature classes that
          participate in this topology will be listed in the output .xml file.
      location (Folder):
          The folder in which the .xml file will be written.
      file_name (String):
          The name of the topology .xml file that will be created by the tool."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportTopology_topographic(*gp_fixargs((topology, location, file_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportTopology_topographic', None)
def ImportTopology(in_feature_dataset=None, topology_definition_file=None):
    """ImportTopology_topographic(in_feature_dataset, topology_definition_file)

        Creates a geodatabase topology from a definition .xml file generated
        by the Export Topology tool in the Topographic Production toolbox.Both
        this tool and the Export Topology tool allow you to share and
        create topologies within different geodatabases. The .xml file
        contains a definition of a topology, including feature class names,
        topology ranks, topology rules, and cluster tolerance.

     INPUTS:
      in_feature_dataset (Feature Dataset):
          The feature dataset in which the topology will be created. The feature
          dataset must contain the feature classes listed in the
          topology_definition_file.
      topology_definition_file (File):
          The .xml file that contains the topology definition."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportTopology_topographic(*gp_fixargs((in_feature_dataset, topology_definition_file), True)))
        return retval
    except Exception as e:
        raise e


# Data Management\Validation toolset
@gptooldoc('GAIT_topographic', None)
def GAIT(in_features=None, gait_exe=None, folder=None, schema=None, project=None, format=None, metadata=None, silent=None, reviewer_workspace=None, specfile=None):
    """GAIT_topographic(in_features;in_features..., gait_exe, folder, schema, project, format, metadata, silent, {reviewer_workspace}, {specfile})

        Validates data using the Geospatial Analysis Integrity Tool (GAIT),
        checking geometry, feature codes, attribute values and domains, and
        metadata.

     INPUTS:
      in_features (Table View / Feature Layer):
          The features to validate.
      gait_exe (File):
          The path to the GAIT executable file.
      folder (Folder):
          The shapefile export directory.
      schema (String):
          The data model that corresponds to the data displayed in the input
          feature layer.
      project (String):
          The name of the project. The project contains validation information,
          such as the checks run on the data and the results.
      format (String):
          The set of checks to run on the data. This is specific to the data
          model listed in the attribution schema.
      metadata (String):
          The metadata mapping table that corresponds to the data model of the
          input feature layer and the attribution schema.

          * META_ESRI-Esri metadata

          * META_INGR-Intergraph metadata

          * META_MGCPNGA-MGCP NGA metadata
      silent (Boolean):
          Indicates the amount of output messages to return from GAIT.exe.

          * SILENT-Limit messaging from GAIT.exe. This is the default.

          * VERBOSE-Run GAIT.exe in verbose mode.
      reviewer_workspace {Workspace}:
          The workspace to write the output features. Each shapefile result
          record is written to the reviewer table in this workspace.
      specfile {File}:
          A file that defines custom checks."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GAIT_topographic(*gp_fixargs((in_features, gait_exe, folder, schema, project, format, metadata, silent, reviewer_workspace, specfile), True)))
        return retval
    except Exception as e:
        raise e


# Workflow\Data Management toolset
@gptooldoc('CopyJobFiles_topographic', None)
def CopyJobFiles(job_id=None, source_path=None, target_path=None, archive_source=None, delete_source=None, create_job_folder=None, database_path=None):
    """CopyJobFiles_topographic(job_id, source_path, target_path, {archive_source}, {delete_source}, {create_job_folder}, {database_path})

        Copies Workflow Manager (Classic) job files to and from a local
        machine and a shared directory for processing.This tool is designed to
        be run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The Job ID of the Workflow Manager (Classic) job that will be updated.
      source_path (Folder):
          The path to the folder containing the files to be copied.
      target_path (Folder):
          The path to the location where the files will be copied.
      archive_source {Boolean}:
          Specifies whether the files in the source path will be zipped before
          copying to the target location.

          * ARCHIVE-A .zip file with the contents of the source directory will
          be created and copied to the target location.

          * NO_ARCHIVE-The contents of the source directory will be copied
          directly to the target location. This is the default.
      delete_source {Boolean}:
          Specifies whether the files in the source path will be deleted after
          the files are copied to the target location.

          * DELETE_SOURCE-The source directory and all its contents will be
          deleted after the files are copied.

          * NO_DELETE_SOURCE-The source directory will not be deleted after the
          files are copied. This is the default.
      create_job_folder {Boolean}:
          Specifies whether a folder will be created in the target path for
          containing the copied files.

          * CREATE_JOB_FOLDER-A folder will be created in the target path with
          the name of the chosen job. Files are copied from the source path to
          this new folder.

          * NO_CREATE_JOB_FOLDER-A folder will not be created, and files from
          the source path will be copied directly to the target path. This is
          the default.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyJobFiles_topographic(*gp_fixargs((job_id, source_path, target_path, archive_source, delete_source, create_job_folder, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GetFeaturesByJobAOI_topographic', None)
def GetFeaturesByJobAOI(job_id=None, source_database=None, target_database=None, extract_operation=None, filter_feature=None, filter_type=None, replica_type=None, database_path=None):
    """GetFeaturesByJobAOI_topographic(job_id, source_database, target_database, extract_operation, {filter_feature}, {filter_type}, {replica_type}, {database_path})

        Extracts features from a source geodatabase into a target geodatabase
        based on the Filter Feature Layer parameter (or job AOI).The Target
        Database specified can be a database that includes the
        input schema, or it can be an empty database in which the tool will
        create a schema that matches the Source Database.This tool is designed
        to be run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The job ID of the Workflow Manager (Classic) job that will be updated.
          The default area over which features will be extracted or replicated
          is also determined.
      source_database (Workspace):
          The path to the source database containing features to extract.
      target_database (Workspace):
          The database from which features will be extracted
      extract_operation (String):
          Specifies whether the data will be copied to the target database or
          replicated to the target database.

          * EXTRACT_DATA-A copy of the features will be extracted to the Target
          Database. This is the default.

          * REPLICATE_DATA-The features will be extracted as a replica.
      filter_feature {Layer}:
          A feature layer with one selected feature used to limit the extent of
          the data that will be extracted. If no filter feature is specified,
          the job AOI will be used.
      filter_type {String}:
          Specifies the spatial relationship between Source Database and Filter
          Feature Layer. This parameter is only used if Extract Operation is
          Extract Data.

          * INTERSECTS-Features from the Source Database parameter that
          intersect features in the Filter Feature Layer parameter will be
          extracted. This is the default.

          * CONTAINS-Features from the Source Database parameter that are
          contained in the selected feature in the Filter Feature Layer
          parameter will be extracted.

          * CLIP-Features from the Source Database parameter that intersect
          features in the Filter Feature Layer parameter will be extracted.
          Features are then split at the AOI boundary and only those in the AOI
          boundary will be kept.
      replica_type {String}:
          Specifies the type of replica that will be created. This parameter is
          only used if Extract Operation is Replicate Data.

          * TWO_WAY_REPLICA-Changes can be sent between child and parent
          replicas in both directions.

          * ONE_WAY_REPLICA-Changes are sent from the parent replica to the
          child replica only.

          * CHECK_OUT-Data is replicated, edited, and checked back in one time.
          This is the default.

          * ONE_WAY_CHILD_TO_PARENT_REPLICA-Changes are sent from the child
          replica to the parent replica only.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetFeaturesByJobAOI_topographic(*gp_fixargs((job_id, source_database, target_database, extract_operation, filter_feature, filter_type, replica_type, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateTaskGroupMetrics_topographic', None)
def UpdateTaskGroupMetrics(job_id=None, status_layer=None, status_field=None, database_path=None):
    """UpdateTaskGroupMetrics_topographic(job_id, {status_layer}, {status_field}, {database_path})

        Updates and summarizes task group metrics that are part of the
        standard Topographic Workflow deployment of Workflow Manager
        (Classic).This tool is designed to be run as a step in a Workflow
        Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The job ID of the job that will be updated.
      status_layer {Feature Layer}:
          The feature class containing status polygons that keep track of the
          last time work occurred over an extent. Only use this parameter to
          update a polygon feature class that is not the standard status
          polygons created by the Topographic Workflow.
      status_field {Field}:
          The text or date field in which the last modified date will be stored.
          The parameter is only enable, if a Status Layer value is defined.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateTaskGroupMetrics_topographic(*gp_fixargs((job_id, status_layer, status_field, database_path), True)))
        return retval
    except Exception as e:
        raise e


# Workflow\Properties toolset
@gptooldoc('CopyExtendedProperties_topographic', None)
def CopyExtendedProperties(source_job_id=None, target_job_id=None, property_table_name=None, property_fields=None, database_path=None):
    """CopyExtendedProperties_topographic(source_job_id, target_job_id, property_table_name, property_fields;property_fields..., {database_path})

        Copies extended property values from one job to another job in the
        same Workflow Manager (Classic) repository.This tool is designed to be
        run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      source_job_id (Long):
          The Job ID of the Workflow Manager (Classic) job that contains the
          properties to copy.
      target_job_id (Long):
          The Job ID of the target job that will have its properties updated.
      property_table_name (String):
          The name of the extended properties table that will be updated.
      property_fields (String):
          The properties to be copied from the source job to the target job.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CopyExtendedProperties_topographic(*gp_fixargs((source_job_id, target_job_id, property_table_name, property_fields, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetDataWorkspace_topographic', None)
def SetDataWorkspace(job_id=None, database_path=None):
    """SetDataWorkspace_topographic(job_id, {database_path})

        Sets the data workspace for the chosen job to the appropriate database
        based on the production type of the job.This tool is designed to be
        run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The job ID of the Workflow Manager (Classic) job that will be updated.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetDataWorkspace_topographic(*gp_fixargs((job_id, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetProductionProperties_topographic', None)
def SetProductionProperties(job_id=None, database_path=None):
    """SetProductionProperties_topographic(job_id, {database_path})

        Updates the production properties extended properties table of a
        Workflow Manager (Classic) job based on its production type to ensure
        that the job and any associated tasks use the correct data and
        maps.This tool is designed to be run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The ID of the Workflow Manager (Classic) job that will be updated.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetProductionProperties_topographic(*gp_fixargs((job_id, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateExtendedProperty_topographic', None)
def UpdateExtendedProperty(job_id=None, properties_table_name=None, property_field=None, value=None, increment_value=None, database_path=None):
    """UpdateExtendedProperty_topographic(job_id, properties_table_name, property_field, value, {increment_value}, {database_path})

        Updates an extended property in the identified properties table for
        the chosen job.This tool is designed to be run as a step in a Workflow
        Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The Job ID of the Workflow Manager (Classic) job that will be updated.
      properties_table_name (String):
          The name of the extended properties table that will be updated.
      property_field (String):
          The property to be updated in the extended properties table.
      value (String):
          The value that will be set for the extended property.
      increment_value {Boolean}:
          If a value already exists for the chosen property, this parameter
          specifies whether the increment value will be added to the current
          value or will replace the current value.

          * INCREMENT-The specified value will be added to any existing value
          for the property.

          * REPLACE-The specified value will replace the existing value for the
          property.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateExtendedProperty_topographic(*gp_fixargs((job_id, properties_table_name, property_field, value, increment_value, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdatePropertyCount_topographic', None)
def UpdatePropertyCount(job_id=None, properties_table_name=None, property_field=None, update_value=None, database_path=None):
    """UpdatePropertyCount_topographic(job_id, properties_table_name, property_field, update_value, {database_path})

        Increases the value in an extended property by the update value each
        time the tool is executed so that metrics are recorded.This tool has
        been replaced by the Update Extended Property tool. and
        will be deprecated in the next release.This tool is designed to be run
        as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The ID of the Workflow Manager (Classic) job that will be updated.
      properties_table_name (String):
          The name of the extended properties table that will be updated.
      property_field (String):
          The property to be updated in the selected extended properties table.
      update_value (Long):
          The value by which the selected extended property will be increased.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdatePropertyCount_topographic(*gp_fixargs((job_id, properties_table_name, property_field, update_value, database_path), True)))
        return retval
    except Exception as e:
        raise e


# Workflow\Tasks toolset
@gptooldoc('CreateJobForTask_topographic', None)
def CreateJobForTask(job_id=None, database_path=None):
    """CreateJobForTask_topographic(job_id, {database_path})

        Automatically creates a Workflow Manager (Classic) job for a task.This
        tool is designed to be run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The job ID of the Workflow Manager (Classic) job that will be the
          parent to the newly created child job. The Current Task extended
          property value for this job will be used to determine the type of task
          job that will be created.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateJobForTask_topographic(*gp_fixargs((job_id, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('InsertTaskGroup_topographic', None)
def InsertTaskGroup(job_id=None, task_group_id=None, database_path=None):
    """InsertTaskGroup_topographic(job_id, task_group_id, {database_path})

        Adds tasks from the chosen task group to a job when required by
        workflow execution.This tool is designed to be run as a step in a
        Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The ID of the Workflow Manager (Classic) job that will be updated.
          This is the ID for the parent task group job, not the task job.
      task_group_id (Long):
          The ID of the task group that defines the tasks that will be inserted
          into the selected job's task list.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.InsertTaskGroup_topographic(*gp_fixargs((job_id, task_group_id, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetNextTask_topographic', None)
def SetNextTask(job_id=None, database_path=None):
    """SetNextTask_topographic(job_id, {database_path})

        Sets the next task in a workflow from the task list.This tool is
        designed to be run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The ID of the Workflow Manager (Classic) job that will be updated.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetNextTask_topographic(*gp_fixargs((job_id, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetTaskList_topographic', None)
def SetTaskList(job_id=None, database_path=None):
    """SetTaskList_topographic(job_id, {database_path})

        Populates the list of expected tasks for a job based on the selected
        task group.This tool is designed to be run as a step in a Workflow
        Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The ID of the Workflow Manager (Classic) job that will be updated.
      database_path {File}:
          The Workflow Manager (Classic) database connection file (.jtc) that
          contains the job information. If no connection file is specified, the
          current default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetTaskList_topographic(*gp_fixargs((job_id, database_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetTaskStatus_topographic', None)
def SetTaskStatus(job_id=None, parent_id=None, status=None, database_path=None):
    """SetTaskStatus_topographic(job_id, parent_id, status, {database_path})

        Updates the status of a task based on the state of the Workflow
        Manager (Classic) job created for the task.This tool is designed to be
        run as a step in a Workflow Manager
        (Classic) workflow. Running this tool outside of Workflow Manager
        (Classic) does not honor all Workflow Manager (Classic) constraints
        such as job assignment, dependencies, or holds and may cause a job to
        enter an unusable state.This tool is intended for use with the
        Topographic Mapping production
        workflows and will not support an improperly configured Workflow
        Manager (Classic) repository. Sample workflows and instructions for
        configuring Topographic Mapping production workflows are available as
        part of the product file installer.

     INPUTS:
      job_id (Long):
          The job ID of the task job that has a change in status.
      parent_id (Long):
          The job ID of the task group job that is the parent to the task job.
      status (String):
          Specifies the status of the selected task.

          * WORKING-Work has begun for the task.

          * COMPLETE-Work has been completed for the task.
      database_path {File}:
          The Workflow Manager (Classic) database connection file that contains
          the job information. If no connection file is specified, the current
          default Workflow Manager (Classic) database will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetTaskStatus_topographic(*gp_fixargs((job_id, parent_id, status, database_path), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject